@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 # This script can be used to build static libraries for the Windows and Mac
 # versions of Kid3. Linux and BSD users do not need it because the libraries
 # can be installed from their repositories.
@@ -36,21 +36,38 @@
 # from the win32 or macosx directories by starting buildkid3.bat (Windows) or
 # buildkid3.sh (Mac).
 
+# Exit if an error occurs
+set -e
+
 thisdir=$(pwd)
 
 kernel=$(uname)
 test ${kernel:0:5} = "MINGW" && kernel="MINGW"
 
+compiler="gcc"
+
 # Uncomment for debug build
 #ENABLE_DEBUG=--enable-debug
 #CMAKE_BUILD_TYPE_DEBUG="-DCMAKE_BUILD_TYPE=Debug"
 
+if ! which cmake >/dev/null; then
+  echo cmake not found.
+  return
+  exit 1
+fi
+
 if test $kernel = "MINGW"; then
 CMAKE_OPTIONS="-G \"MSYS Makefiles\" -DCMAKE_INSTALL_PREFIX=/usr/local"
 elif test $kernel = "Darwin"; then
 CMAKE_OPTIONS="-G \"Unix Makefiles\""
 fi
 
+if which wget >/dev/null; then
+DOWNLOAD=wget
+else
+DOWNLOAD="curl -skfLO"
+fi
+
 fixcmakeinst() {
   if test -d inst && test $kernel = "MINGW"; then
     cd inst
@@ -76,49 +93,59 @@ test -d source || mkdir source
 cd source
 
 test -f flac_1.2.1-6.diff.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.2.1-6.diff.gz
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.2.1-6.diff.gz
 test -f flac_1.2.1.orig.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.2.1.orig.tar.gz
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.2.1.orig.tar.gz
 
-test -f id3lib3.8.3_3.8.3-14.debian.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/i/id3lib3.8.3/id3lib3.8.3_3.8.3-14.debian.tar.gz
+test -f id3lib3.8.3_3.8.3-15.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/i/id3lib3.8.3/id3lib3.8.3_3.8.3-15.debian.tar.gz
 test -f id3lib3.8.3_3.8.3.orig.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/i/id3lib3.8.3/id3lib3.8.3_3.8.3.orig.tar.gz
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/i/id3lib3.8.3/id3lib3.8.3_3.8.3.orig.tar.gz
 
-test -f libogg_1.2.2~dfsg-1.diff.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/libo/libogg/libogg_1.2.2~dfsg-1.diff.gz
-test -f libogg_1.2.2~dfsg.orig.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/libo/libogg/libogg_1.2.2~dfsg.orig.tar.gz
+test -f libogg_1.3.0-4.diff.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libo/libogg/libogg_1.3.0-4.diff.gz
+test -f libogg_1.3.0.orig.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libo/libogg/libogg_1.3.0.orig.tar.gz
 
-test -f libvorbis_1.3.2-1.diff.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/libv/libvorbis/libvorbis_1.3.2-1.diff.gz
+test -f libvorbis_1.3.2-1.3.diff.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libv/libvorbis/libvorbis_1.3.2-1.3.diff.gz
 test -f libvorbis_1.3.2.orig.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/libv/libvorbis/libvorbis_1.3.2.orig.tar.gz
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libv/libvorbis/libvorbis_1.3.2.orig.tar.gz
 
-#test -f taglib_1.7-1.debian.tar.gz ||
-#wget http://ftp.de.debian.org/debian/pool/main/t/taglib/taglib_1.7-1.debian.tar.gz
-test -f taglib-1.7.1.tar.gz ||
-wget http://developer.kde.org/~wheeler/files/src/taglib-1.7.1.tar.gz
+test -f taglib_1.8-1.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/t/taglib/taglib_1.8-1.debian.tar.gz
+test -f taglib_1.8.orig.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/t/taglib/taglib_1.8.orig.tar.gz
 
-test -f zlib_1.2.6.dfsg-2.debian.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.6.dfsg-2.debian.tar.gz
-test -f zlib_1.2.6.dfsg.orig.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.6.dfsg.orig.tar.gz
+test -f zlib_1.2.7.dfsg-13.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.7.dfsg-13.debian.tar.gz
+test -f zlib_1.2.7.dfsg.orig.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.7.dfsg.orig.tar.gz
 
-test -f libav_0.8.1.orig.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_0.8.1.orig.tar.gz
-test -f libav_0.8.1-4.debian.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_0.8.1-4.debian.tar.gz
+# With the new libav 9.1, some M4A fingerprints are not recognized,
+# so we'll stick with the old.
+libav_version=0.8.5
+if test "$libav_version" = "0.8.5"; then
+test -f libav_0.8.5.orig.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_0.8.5.orig.tar.gz
+test -f libav_0.8.5-1.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_0.8.5-1.debian.tar.gz
+else
+test -f libav_9.1.orig.tar.xz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_9.1.orig.tar.xz
+test -f libav_9.1-3.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_9.1-3.debian.tar.gz
+fi
 
-test -f chromaprint_0.6.orig.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_0.6.orig.tar.gz
-test -f chromaprint_0.6-1.debian.tar.gz ||
-wget http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_0.6-1.debian.tar.gz
+test -f chromaprint_0.7.orig.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_0.7.orig.tar.gz
+test -f chromaprint_0.7-1.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_0.7-1.debian.tar.gz
 
 #test -f mp4v2_1.9.1+svn479~dfsg0.orig.tar.bz2 ||
-#wget http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_1.9.1+svn479~dfsg0.orig.tar.bz2
+#$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_1.9.1+svn479~dfsg0.orig.tar.bz2
 #test -f mp4v2_1.9.1+svn479~dfsg0-3.debian.tar.gz ||
-#wget http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_1.9.1+svn479~dfsg0-3.debian.tar.gz
+#$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_1.9.1+svn479~dfsg0-3.debian.tar.gz
 
 # Create patch files
 
@@ -263,268 +290,91 @@ diff -ru id3lib-3.8.3.orig/include/id3/globals.h id3lib-3.8.3/include/id3/global
  #  define LINKOPTION_USE_DYNAMIC    3 //if your project links id3lib dynamic
 EOF
 
-test -f taglib-mp4-uinttypes.patch ||
-cat >taglib-mp4-uinttypes.patch <<"EOF"
-diff --git a/taglib/mp4/mp4item.cpp b/taglib/mp4/mp4item.cpp
-index 7dcf594..7d95079 100644
---- a/taglib/mp4/mp4item.cpp
-+++ b/taglib/mp4/mp4item.cpp
-@@ -45,6 +45,9 @@ public:
-     bool m_bool;
-     int m_int;
-     IntPair m_intPair;
-+    uchar m_byte;
-+    uint m_uint;
-+    long long m_longlong;
-   };
-   StringList m_stringList;
-   MP4::CoverArtList m_coverArtList;
-@@ -91,6 +94,24 @@ MP4::Item::Item(int value)
-   d->m_int = value;
- }
- 
-+MP4::Item::Item(uchar value)
-+{
-+  d = new ItemPrivate;
-+  d->m_byte = value;
-+}
-+
-+MP4::Item::Item(uint value)
-+{
-+  d = new ItemPrivate;
-+  d->m_uint = value;
-+}
-+
-+MP4::Item::Item(long long value)
-+{
-+  d = new ItemPrivate;
-+  d->m_longlong = value;
-+}
-+
- MP4::Item::Item(int value1, int value2)
- {
-   d = new ItemPrivate;
-@@ -122,6 +143,24 @@ MP4::Item::toInt() const
-   return d->m_int;
- }
- 
-+uchar
-+MP4::Item::toByte() const
-+{
-+  return d->m_byte;
-+}
-+
-+TagLib::uint
-+MP4::Item::toUInt() const
-+{
-+  return d->m_uint;
-+}
-+
-+long long
-+MP4::Item::toLongLong() const
-+{
-+  return d->m_longlong;
-+}
-+
- MP4::Item::IntPair
- MP4::Item::toIntPair() const
- {
-diff --git a/taglib/mp4/mp4item.h b/taglib/mp4/mp4item.h
-index 3158b4d..243a099 100644
---- a/taglib/mp4/mp4item.h
-+++ b/taglib/mp4/mp4item.h
-@@ -47,12 +47,18 @@ namespace TagLib {
-       ~Item();
- 
-       Item(int value);
-+      Item(uchar value);
-+      Item(uint value);
-+      Item(long long value);
-       Item(bool value);
-       Item(int first, int second);
-       Item(const StringList &value);
-       Item(const CoverArtList &value);
- 
-       int toInt() const;
-+      uchar toByte() const;
-+      uint toUInt() const;
-+      long long toLongLong() const;
-       bool toBool() const;
-       IntPair toIntPair() const;
-       StringList toStringList() const;
-diff --git a/taglib/mp4/mp4tag.cpp b/taglib/mp4/mp4tag.cpp
-index d7933db..a2f5d1f 100644
---- a/taglib/mp4/mp4tag.cpp
-+++ b/taglib/mp4/mp4tag.cpp
-@@ -68,12 +68,23 @@ MP4::Tag::Tag(TagLib::File *file, MP4::Atoms *atoms)
-     else if(atom->name == "trkn" || atom->name == "disk") {
-       parseIntPair(atom, file);
+test -f id3lib-fix-utf16-stringlists.patch ||
+cat >id3lib-fix-utf16-stringlists.patch <<EOF
+diff -ru id3lib-3.8.3.orig/src/io_helpers.cpp id3lib-3.8.3/src/io_helpers.cpp
+--- id3lib-3.8.3.orig/src/io_helpers.cpp	2012-08-26 19:52:21.523825799 +0200
++++ id3lib-3.8.3/src/io_helpers.cpp	2012-08-26 19:53:02.060028394 +0200
+@@ -373,10 +373,17 @@
+     //}
+     // Right code
+     unsigned char *pdata = (unsigned char *) data.c_str();
++    unicode_t lastCh = BOM;
+     for (size_t i = 0; i < size; i += 2)
+     {
+       unicode_t ch = (pdata[i] << 8) | pdata[i+1];
++      if (lastCh == 0 && ch != BOM)
++      {
++        // Last character was NULL, so start next string with BOM.
++        writer.writeChars((const unsigned char*) &BOM, 2);
++      }
+       writer.writeChars((const unsigned char*) &ch, 2);
++      lastCh = ch;
      }
--    else if(atom->name == "cpil" || atom->name == "pgap" || atom->name == "pcst") {
-+    else if(atom->name == "cpil" || atom->name == "pgap" || atom->name == "pcst" ||
-+            atom->name == "hdvd") {
-       parseBool(atom, file);
-     }
-     else if(atom->name == "tmpo") {
-       parseInt(atom, file);
-     }
-+    else if(atom->name == "tvsn" || atom->name == "tves" || atom->name == "cnID" ||
-+            atom->name == "sfID" || atom->name == "atID" || atom->name == "geID") {
-+      parseUInt(atom, file);
-+    }
-+    else if(atom->name == "plID") {
-+      parseLongLong(atom, file);
-+    }
-+    else if(atom->name == "stik" || atom->name == "rtng" || atom->name == "akID") {
-+      parseByte(atom, file);
-+    }
-     else if(atom->name == "gnre") {
-       parseGnre(atom, file);
-     }
-@@ -138,6 +149,33 @@ MP4::Tag::parseInt(MP4::Atom *atom, TagLib::File *file)
- }
- 
- void
-+MP4::Tag::parseUInt(MP4::Atom *atom, TagLib::File *file)
-+{
-+  ByteVectorList data = parseData(atom, file);
-+  if(data.size()) {
-+    d->items.insert(atom->name, data[0].toUInt());
-+  }
-+}
-+
-+void
-+MP4::Tag::parseLongLong(MP4::Atom *atom, TagLib::File *file)
-+{
-+  ByteVectorList data = parseData(atom, file);
-+  if(data.size()) {
-+    d->items.insert(atom->name, data[0].toLongLong());
-+  }
-+}
-+
-+void
-+MP4::Tag::parseByte(MP4::Atom *atom, TagLib::File *file)
-+{
-+  ByteVectorList data = parseData(atom, file);
-+  if(data.size()) {
-+    d->items.insert(atom->name, (uchar)data[0].at(0));
-+  }
-+}
-+
-+void
- MP4::Tag::parseGnre(MP4::Atom *atom, TagLib::File *file)
- {
-   ByteVectorList data = parseData(atom, file);
-@@ -263,6 +301,30 @@ MP4::Tag::renderInt(const ByteVector &name, MP4::Item &item)
- }
- 
- ByteVector
-+MP4::Tag::renderUInt(const ByteVector &name, MP4::Item &item)
-+{
-+  ByteVectorList data;
-+  data.append(ByteVector::fromUInt(item.toUInt()));
-+  return renderData(name, 0x15, data);
-+}
-+
-+ByteVector
-+MP4::Tag::renderLongLong(const ByteVector &name, MP4::Item &item)
-+{
-+  ByteVectorList data;
-+  data.append(ByteVector::fromLongLong(item.toLongLong()));
-+  return renderData(name, 0x15, data);
-+}
-+
-+ByteVector
-+MP4::Tag::renderByte(const ByteVector &name, MP4::Item &item)
-+{
-+  ByteVectorList data;
-+  data.append(ByteVector(1, item.toByte()));
-+  return renderData(name, 0x15, data);
-+}
-+
-+ByteVector
- MP4::Tag::renderIntPair(const ByteVector &name, MP4::Item &item)
- {
-   ByteVectorList data;
-@@ -339,12 +401,22 @@ MP4::Tag::save()
-     else if(name == "disk") {
-       data.append(renderIntPairNoTrailing(name.data(String::Latin1), i->second));
-     }
--    else if(name == "cpil" || name == "pgap" || name == "pcst") {
-+    else if(name == "cpil" || name == "pgap" || name == "pcst" || name == "hdvd") {
-       data.append(renderBool(name.data(String::Latin1), i->second));
-     }
-     else if(name == "tmpo") {
-       data.append(renderInt(name.data(String::Latin1), i->second));
-     }
-+    else if(name == "tvsn" || name == "tves" || name == "cnID" ||
-+            name == "sfID" || name == "atID" || name == "geID") {
-+      data.append(renderUInt(name.data(String::Latin1), i->second));
-+    }
-+    else if(name == "plID") {
-+      data.append(renderLongLong(name.data(String::Latin1), i->second));
-+    }
-+    else if(name == "stik" || name == "rtng" || name == "akID") {
-+      data.append(renderByte(name.data(String::Latin1), i->second));
-+    }
-     else if(name == "covr") {
-       data.append(renderCovr(name.data(String::Latin1), i->second));
-     }
-diff --git a/taglib/mp4/mp4tag.h b/taglib/mp4/mp4tag.h
-index 3e6d667..d0ff728 100644
---- a/taglib/mp4/mp4tag.h
-+++ b/taglib/mp4/mp4tag.h
-@@ -71,6 +71,9 @@ namespace TagLib {
-         void parseText(Atom *atom, TagLib::File *file, int expectedFlags = 1);
-         void parseFreeForm(Atom *atom, TagLib::File *file);
-         void parseInt(Atom *atom, TagLib::File *file);
-+        void parseByte(Atom *atom, TagLib::File *file);
-+        void parseUInt(Atom *atom, TagLib::File *file);
-+        void parseLongLong(Atom *atom, TagLib::File *file);
-         void parseGnre(Atom *atom, TagLib::File *file);
-         void parseIntPair(Atom *atom, TagLib::File *file);
-         void parseBool(Atom *atom, TagLib::File *file);
-@@ -83,6 +86,9 @@ namespace TagLib {
-         TagLib::ByteVector renderFreeForm(const String &name, Item &item);
-         TagLib::ByteVector renderBool(const ByteVector &name, Item &item);
-         TagLib::ByteVector renderInt(const ByteVector &name, Item &item);
-+        TagLib::ByteVector renderByte(const ByteVector &name, Item &item);
-+        TagLib::ByteVector renderUInt(const ByteVector &name, Item &item);
-+        TagLib::ByteVector renderLongLong(const ByteVector &name, Item &item);
-         TagLib::ByteVector renderIntPair(const ByteVector &name, Item &item);
-         TagLib::ByteVector renderIntPairNoTrailing(const ByteVector &name, Item &item);
-         TagLib::ByteVector renderCovr(const ByteVector &name, Item &item);
+     // End patch
+   }
+
 EOF
 
-test -f taglib-itunes-id3v22.patch ||
-cat >taglib-itunes-id3v22.patch <<"EOF"
-diff --git a/taglib/mpeg/id3v2/id3v2framefactory.cpp b/taglib/mpeg/id3v2/id3v2framefactory.cpp
-index 40e454e..b6bc34a 100644
---- a/taglib/mpeg/id3v2/id3v2framefactory.cpp
-+++ b/taglib/mpeg/id3v2/id3v2framefactory.cpp
-@@ -310,6 +310,7 @@ bool FrameFactory::updateFrame(Frame::Header *header) const
-     convertFrame("TBP", "TBPM", header);
-     convertFrame("TCM", "TCOM", header);
-     convertFrame("TCO", "TCON", header);
-+    convertFrame("TCP", "TCMP", header);
-     convertFrame("TCR", "TCOP", header);
-     convertFrame("TDY", "TDLY", header);
-     convertFrame("TEN", "TENC", header);
-@@ -332,7 +333,12 @@ bool FrameFactory::updateFrame(Frame::Header *header) const
-     convertFrame("TRC", "TSRC", header);
-     convertFrame("TRD", "TDRC", header);
-     convertFrame("TRK", "TRCK", header);
-+    convertFrame("TS2", "TSO2", header);
-+    convertFrame("TSA", "TSOA", header);
-+    convertFrame("TSC", "TSOC", header);
-+    convertFrame("TSP", "TSOP", header);
-     convertFrame("TSS", "TSSE", header);
-+    convertFrame("TST", "TSOT", header);
-     convertFrame("TT1", "TIT1", header);
-     convertFrame("TT2", "TIT2", header);
-     convertFrame("TT3", "TIT3", header);
+test -f taglib-xm-file-save.patch ||
+cat >taglib-xm-file-save.patch <<"EOF"
+diff -ru taglib-1.8.orig/taglib/xm/xmfile.cpp taglib-1.8/taglib/xm/xmfile.cpp
+--- taglib-1.8.orig/taglib/xm/xmfile.cpp	2012-09-06 20:03:15.000000000 +0200
++++ taglib-1.8/taglib/xm/xmfile.cpp	2012-09-22 08:55:07.052052207 +0200
+@@ -443,7 +443,7 @@
+       return false;
+ 
+     uint len = std::min(22UL, instrumentHeaderSize - 4U);
+-    if(i > lines.size())
++    if(i >= lines.size())
+       writeString(String::null, len);
+     else
+       writeString(lines[i], len);
 EOF
 
+test -f taglib-msvc.patch ||
+cat >taglib-msvc.patch <<"EOF"
+diff -ru taglib-1.8.orig/CMakeLists.txt taglib-1.8/CMakeLists.txt
+--- taglib-1.8.orig/CMakeLists.txt	Thu Sep  6 20:03:15 2012
++++ taglib-1.8/CMakeLists.txt	Fri Feb 22 06:41:36 2013
+@@ -31,6 +31,10 @@
+ set(LIB_INSTALL_DIR "${EXEC_INSTALL_PREFIX}/lib${LIB_SUFFIX}" CACHE PATH "The subdirectory relative to the install prefix where libraries will be installed (default is /lib${LIB_SUFFIX})" FORCE)
+ set(INCLUDE_INSTALL_DIR "${CMAKE_INSTALL_PREFIX}/include" CACHE PATH "The subdirectory to the header prefix" FORCE)
+ 
++if(MSVC)
++  add_definitions(/Zc:wchar_t-)
++endif(MSVC)
++
+ if(APPLE)
+ 	option(BUILD_FRAMEWORK "Build an OS X framework" OFF)
+ 	set(FRAMEWORK_INSTALL_DIR "/Library/Frameworks" CACHE STRING "Directory to install frameworks to.")
+EOF
+
+test -f taglib-no-id3-duplication.patch ||
+cat >taglib-no-id3-duplication.patch <<"EOF"
+diff --git a/taglib/mpeg/mpegfile.cpp b/taglib/mpeg/mpegfile.cpp
+index c73da41..af53ac1 100644
+--- a/taglib/mpeg/mpegfile.cpp
++++ b/taglib/mpeg/mpegfile.cpp
+@@ -203,15 +203,6 @@ bool MPEG::File::save(int tags, bool stripOthers, int id3v2Version)
+     return false;
+   }
+ 
+-  // Create the tags if we've been asked to.  Copy the values from the tag that
+-  // does exist into the new tag, except if the existing tag is to be stripped.
+-
+-  if((tags & ID3v2) && ID3v1Tag() && !(stripOthers && !(tags & ID3v1)))
+-    Tag::duplicate(ID3v1Tag(), ID3v2Tag(true), false);
+-
+-  if((tags & ID3v1) && d->tag[ID3v2Index] && !(stripOthers && !(tags & ID3v2)))
+-    Tag::duplicate(ID3v2Tag(), ID3v1Tag(true), false);
+-
+   bool success = true;
+ 
+   if(ID3v2 & tags) {
+EOF
+
+if test "$libav_version" = "0.8.5"; then
 test -f libav_sws.patch ||
 cat >libav_sws.patch <<"EOF"
 --- cmdutils.c.org      2011-09-17 13:36:43.000000000 -0700
@@ -542,6 +392,7 @@ cat >libav_sws.patch <<"EOF"
  
      if (!(p = strchr(opt, ':')))
 EOF
+fi
 
 cd ..
 
@@ -550,29 +401,32 @@ cd ..
 
 # zlib
 
-if ! test -d zlib-1.2.6.dfsg; then
-tar xzf source/zlib_1.2.6.dfsg.orig.tar.gz
-cd zlib-1.2.6.dfsg/
-tar xzf ../source/zlib_1.2.6.dfsg-2.debian.tar.gz
-for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+if ! test -d zlib-1.2.7; then
+tar xzf source/zlib_1.2.7.dfsg.orig.tar.gz
+cd zlib-1.2.7/
+tar xzf ../source/zlib_1.2.7.dfsg-13.debian.tar.gz || true
+echo Can be ignored: Cannot create symlink to debian.series
+for f in $(cat debian/patches/debian.series); do patch -p1 <debian/patches/$f; done
 cd ..
 fi
 
 # libogg
 
-if ! test -d libogg-1.2.2~dfsg; then
-tar xzf source/libogg_1.2.2~dfsg.orig.tar.gz
-cd libogg-1.2.2~dfsg/
-gunzip -c ../source/libogg_1.2.2~dfsg-1.diff.gz | patch -p1
+if ! test -d libogg-1.3.0; then
+tar xzf source/libogg_1.3.0.orig.tar.gz
+cd libogg-1.3.0/
+gunzip -c ../source/libogg_1.3.0-4.diff.gz | patch -p1
 cd ..
 fi
 
 # libvorbis
 
-if ! test -d libvorbis-1.3.2.orig; then
+if ! test -d libvorbis-1.3.2; then
 tar xzf source/libvorbis_1.3.2.orig.tar.gz
 cd libvorbis-1.3.2/
-gunzip -c ../source/libvorbis_1.3.2-1.diff.gz | patch -p1
+gunzip -c ../source/libvorbis_1.3.2-1.3.diff.gz | patch -p1
+test -f win32/VS2008/libogg.vsprops.orig || mv win32/VS2008/libogg.vsprops win32/VS2008/libogg.vsprops.orig
+sed 's/Value="1.1.4"/Value="1.3.0"/' win32/VS2008/libogg.vsprops.orig >win32/VS2008/libogg.vsprops
 cd ..
 fi
 
@@ -597,41 +451,64 @@ fi
 if ! test -d id3lib-3.8.3; then
 tar xzf source/id3lib3.8.3_3.8.3.orig.tar.gz
 cd id3lib-3.8.3/
-tar xzf ../source/id3lib3.8.3_3.8.3-14.debian.tar.gz
+tar xzf ../source/id3lib3.8.3_3.8.3-15.debian.tar.gz
 for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
 patch -p1 <../source/id3lib-3.8.3_mingw.patch
+patch -p1 <../source/id3lib-fix-utf16-stringlists.patch
+test -f makefile.win32.orig || mv makefile.win32 makefile.win32.orig
+sed 's/-W3 -WX -GX/-W3 -EHsc/; s/-MD -D "WIN32" -D "_DEBUG"/-MDd -D "WIN32" -D "_DEBUG"/' makefile.win32.orig >makefile.win32
 cd ..
 fi
 
 # taglib
 
-if ! test -d taglib-1.7.1; then
-tar xzf source/taglib-1.7.1.tar.gz
-cd taglib-1.7.1/
-#tar xzf ../source/taglib_1.7-1.debian.tar.gz
-#for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
-patch -p1 <../source/taglib-mp4-uinttypes.patch
-patch -p1 <../source/taglib-itunes-id3v22.patch
+if ! test -d taglib-1.8; then
+tar xzf source/taglib_1.8.orig.tar.gz
+cd taglib-1.8/
+tar xzf ../source/taglib_1.8-1.debian.tar.gz
+for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+patch -p1 <../source/taglib-xm-file-save.patch
+patch -p1 <../source/taglib-msvc.patch
+patch -p1 <../source/taglib-no-id3-duplication.patch
 cd ..
 fi
 
 # libav
 
-if ! test -d libav-0.8.1; then
-tar xzf source/libav_0.8.1.orig.tar.gz
-cd libav-0.8.1/
-tar xzf ../source/libav_0.8.1-4.debian.tar.gz
-for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+if test "$libav_version" = "0.8.5"; then
+if ! test -d libav-0.8.5; then
+tar xzf source/libav_0.8.5.orig.tar.gz
+cd libav-0.8.5/
+tar xzf ../source/libav_0.8.5-1.debian.tar.gz
+oldifs=$IFS
+IFS='
+'
+for f in $(cat debian/patches/series); do
+  if test "${f:0:1}" != "#"; then
+    patch -p1 <debian/patches/$f
+  fi
+done
+IFS=$oldifs
 patch -p0 <../source/libav_sws.patch
 cd ..
 fi
+else
+if ! test -d libav-9.1; then
+unxz -c source/libav_9.1.orig.tar.xz | tar x
+cd libav-9.1/
+tar xzf ../source/libav_9.1-3.debian.tar.gz
+for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+cd ..
+fi
+fi
 
 # chromaprint
 
-if ! test -d chromaprint-0.6; then
-tar xzf source/chromaprint_0.6.orig.tar.gz
-cd chromaprint-0.6/
-tar xzf ../source/chromaprint_0.6-1.debian.tar.gz
+if ! test -d chromaprint-0.7; then
+tar xzf source/chromaprint_0.7.orig.tar.gz
+cd chromaprint-0.7/
+tar xzf ../source/chromaprint_0.7-1.debian.tar.gz
+for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
 cd ..
 fi
 
@@ -649,9 +526,78 @@ fi
 
 test -d bin || mkdir bin
 
+if test "$compiler" = "msvc"; then
+
+# libogg
+
+cd libogg-1.3.0/
+$COMSPEC /c "\"\"%VS90COMNTOOLS%vsvars32.bat\"\" && msbuild win32\VS2008\libogg_static.sln /p:Configuration=Debug;Platform=Win32"
+$COMSPEC /c "\"\"%VS90COMNTOOLS%vsvars32.bat\"\" && msbuild win32\VS2008\libogg_static.sln /p:Configuration=Release;Platform=Win32"
+mkdir -p inst/include/ogg inst/lib/Debug inst/lib/Release
+cp win32/VS2008/Win32/Debug/libogg_static.lib inst/lib/Debug/
+cp win32/VS2008/Win32/Release/libogg_static.lib inst/lib/Release/
+cp include/ogg/*.h inst/include/ogg/
+cd inst
+tar czf ../../bin/libogg-1.3.0.tgz include lib
+cd ../..
+
+# libvorbis
+
+cd libvorbis-1.3.2/
+$COMSPEC /c "\"\"%VS90COMNTOOLS%vsvars32.bat\"\" && msbuild win32\VS2008\vorbis_static.sln /p:Configuration=Debug;Platform=Win32"
+$COMSPEC /c "\"\"%VS90COMNTOOLS%vsvars32.bat\"\" && msbuild win32\VS2008\vorbis_static.sln /p:Configuration=Release;Platform=Win32"
+mkdir -p inst/include/vorbis inst/lib/Debug inst/lib/Release
+cp win32/VS2008/Win32/Debug/*.lib inst/lib/Debug/
+cp win32/VS2008/Win32/Release/*.lib inst/lib/Release/
+cp include/vorbis/*.h inst/include/vorbis/
+cd inst
+tar czf ../../bin/libvorbis-1.3.2.tgz include lib
+cd ../..
+
+# id3lib
+
+cd id3lib-3.8.3/
+test -f config.h || cp config.h.win32 config.h
+$COMSPEC /c "\"\"%VS90COMNTOOLS%vsvars32.bat\"\" && nmake -f makefile.win32 DEBUG=1"
+$COMSPEC /c "\"\"%VS90COMNTOOLS%vsvars32.bat\"\" && nmake -f makefile.win32"
+mkdir -p inst/include inst/lib/Debug inst/lib/Release
+cp -a include/id3* inst/include
+cp id3libd.lib inst/lib/Debug/id3lib.lib
+cp id3lib.lib inst/lib/Release/
+cd inst
+tar czf ../../bin/id3lib-3.8.3.tgz include lib
+cd ../..
+
+# taglib
+
+cd taglib-1.8/
+test -f taglib.sln || cmake -G "Visual Studio 9 2008" -DWITH_ASF=ON -DWITH_MP4=ON -DENABLE_STATIC=ON -DCMAKE_INSTALL_PREFIX=
+mkdir -p instd
+DESTDIR=instd cmake --build . --config Debug --target install
+mkdir -p inst
+DESTDIR=inst cmake --build . --config Release --target install
+mv inst/lib inst/Release
+mv instd/lib inst/Debug
+mkdir -p inst/lib
+mv inst/Debug inst/Release inst/lib/
+rm -rf instd
+cd inst
+tar czf ../../bin/taglib-1.8.tgz include lib
+cd ../..
+
+# Install to root directory
+
+BUILDROOT=../libs-msvc
+test -d $BUILDROOT || mkdir $BUILDROOT
+for f in bin/*.tgz; do
+  tar xzf $f -C $BUILDROOT
+done
+
+else
+
 # zlib
 
-cd zlib-1.2.6.dfsg/
+cd zlib-1.2.7/
 if test $kernel = "MINGW"; then
 make -f win32/Makefile.gcc
 make install -f win32/Makefile.gcc INCLUDE_PATH=`pwd`/inst/usr/local/include LIBRARY_PATH=`pwd`/inst/usr/local/lib BINARY_PATH=`pwd`/inst/usr/local/bin
@@ -662,26 +608,26 @@ mkdir -p inst/usr/local
 make install -f Makefile.inst prefix=`pwd`/inst/usr/local
 fi
 cd inst
-tar czf ../../bin/zlib-1.2.6.tgz usr
+tar czf ../../bin/zlib-1.2.7.tgz usr
 cd ../..
 
 # libogg
 
-cd libogg-1.2.2~dfsg/
+cd libogg-1.3.0/
 test -f Makefile || ./configure --enable-shared=no --enable-static=yes $ENABLE_DEBUG
 make
-mkdir inst
+mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
-tar czf ../../bin/libogg-1.2.2.tgz usr
+tar czf ../../bin/libogg-1.3.0.tgz usr
 cd ../..
 
 # libvorbis
 
 cd libvorbis-1.3.2/
-test -f Makefile || ./configure --enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-1.2.2~dfsg/inst/usr/local $ENABLE_DEBUG
+test -f Makefile || ./configure --enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-1.3.0/inst/usr/local $ENABLE_DEBUG
 make
-mkdir inst
+mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
 tar czf ../../bin/libvorbis-1.3.2.tgz usr
@@ -690,13 +636,13 @@ cd ../..
 # libflac
 
 cd flac-1.2.1/
-configure_args="--enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-1.2.2~dfsg/inst/usr/local $ENABLE_DEBUG"
+configure_args="--enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-1.3.0/inst/usr/local $ENABLE_DEBUG"
 if test $kernel = "Darwin"; then
   configure_args="$configure_args --disable-asm-optimizations"
 fi
 test -f Makefile || ./configure $configure_args
 make
-mkdir inst
+mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
 tar czf ../../bin/flac-1.2.1.tgz usr
@@ -708,7 +654,7 @@ cd id3lib-3.8.3/
 autoconf
 test -f Makefile || CPPFLAGS=-I/usr/local/include LDFLAGS=-L/usr/local/lib ./configure --enable-shared=no --enable-static=yes $ENABLE_DEBUG
 SED=sed make
-mkdir inst
+mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
 tar czf ../../bin/id3lib-3.8.3.tgz usr
@@ -716,24 +662,28 @@ cd ../..
 
 # taglib
 
-cd taglib-1.7.1/
+cd taglib-1.8/
 test -f Makefile || eval cmake -DWITH_ASF=ON -DWITH_MP4=ON -DINCLUDE_DIRECTORIES=/usr/local/include -DLINK_DIRECTORIES=/usr/local/lib -DENABLE_STATIC=ON -DCMAKE_VERBOSE_MAKEFILE=ON $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
 make
-mkdir inst
+mkdir -p inst
 make install DESTDIR=`pwd`/inst
 fixcmakeinst
 cd inst
-tar czf ../../bin/taglib-1.7.1.tgz usr
+tar czf ../../bin/taglib-1.8.tgz usr
 cd ../..
 
 # libav
 
-cd libav-0.8.1
+if test "$libav_version" = "0.8.5"; then
+cd libav-0.8.5
 # configure needs yasm and pr
 # On msys, make >= 3.81 is needed.
 # Most options taken from
 # http://oxygene.sk/lukas/2011/04/minimal-audio-only-ffmpeg-build-with-mingw32/
 # Disable-sse avoids a SEGFAULT under MinGW.
+# Later versions (tested with libav-HEAD-5d2be71) do not have
+# --enable-ffmpeg and additionally need --disable-mmx --disable-mmxext.
+# The two --disable-hwaccel were added for MinGW-builds GCC 4.7.2.
 ./configure \
 	--enable-memalign-hack \
 	--disable-shared \
@@ -809,23 +759,120 @@ cd libav-0.8.1
 	--enable-decoder=pcm_u16le \
 	--enable-decoder=pcm_u24be \
 	--enable-decoder=pcm_u24le \
-	--enable-decoder=rawvideo
+	--enable-decoder=rawvideo \
+	--disable-hwaccel=h264_dxva2 \
+	--disable-hwaccel=mpeg2_dxva2
 make
-mkdir inst
+mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
-tar czf ../../bin/libav-0.8.1.tgz usr
+tar czf ../../bin/libav-0.8.5.tgz usr
 cd ../..
+else
+cd libav-9.1
+# configure needs yasm and pr
+# On msys, make >= 3.81 is needed.
+# Most options taken from
+# http://oxygene.sk/lukas/2011/04/minimal-audio-only-ffmpeg-build-with-mingw32/
+# Disable-sse avoids a SEGFAULT under MinGW.
+# Later versions (tested with libav-HEAD-5d2be71) do not have
+# --enable-ffmpeg and additionally need --disable-mmx --disable-mmxext.
+# The two --disable-hwaccel were added for MinGW-builds GCC 4.7.2.
+./configure \
+	--enable-memalign-hack \
+	--disable-shared \
+	--enable-static \
+	--disable-debug \
+	--disable-avdevice \
+	--disable-avfilter \
+	--disable-pthreads \
+	--disable-swscale \
+	--disable-network \
+	--disable-muxers \
+	--disable-demuxers \
+	--disable-sse \
+	--enable-rdft \
+	--enable-demuxer=aac \
+	--enable-demuxer=ac3 \
+	--enable-demuxer=ape \
+	--enable-demuxer=asf \
+	--enable-demuxer=flac \
+	--enable-demuxer=matroska_audio \
+	--enable-demuxer=mp3 \
+	--enable-demuxer=mpc \
+	--enable-demuxer=mov \
+	--enable-demuxer=mpc8 \
+	--enable-demuxer=ogg \
+	--enable-demuxer=tta \
+	--enable-demuxer=wav \
+	--enable-demuxer=wv \
+	--disable-bsfs \
+	--disable-filters \
+	--disable-parsers \
+	--enable-parser=aac \
+	--enable-parser=ac3 \
+	--enable-parser=mpegaudio \
+	--disable-protocols \
+	--enable-protocol=file \
+	--disable-indevs \
+	--disable-outdevs \
+	--disable-encoders \
+	--disable-decoders \
+	--enable-decoder=aac \
+	--enable-decoder=ac3 \
+	--enable-decoder=alac \
+	--enable-decoder=ape \
+	--enable-decoder=flac \
+	--enable-decoder=mp1 \
+	--enable-decoder=mp2 \
+	--enable-decoder=mp3 \
+	--enable-decoder=mpc7 \
+	--enable-decoder=mpc8 \
+	--enable-decoder=tta \
+	--enable-decoder=vorbis \
+	--enable-decoder=wavpack \
+	--enable-decoder=wmav1 \
+	--enable-decoder=wmav2 \
+	--enable-decoder=pcm_alaw \
+	--enable-decoder=pcm_dvd \
+	--enable-decoder=pcm_f32be \
+	--enable-decoder=pcm_f32le \
+	--enable-decoder=pcm_f64be \
+	--enable-decoder=pcm_f64le \
+	--enable-decoder=pcm_s16be \
+	--enable-decoder=pcm_s16le \
+	--enable-decoder=pcm_s16le_planar \
+	--enable-decoder=pcm_s24be \
+	--enable-decoder=pcm_daud \
+	--enable-decoder=pcm_s24le \
+	--enable-decoder=pcm_s32be \
+	--enable-decoder=pcm_s32le \
+	--enable-decoder=pcm_s8 \
+	--enable-decoder=pcm_u16be \
+	--enable-decoder=pcm_u16le \
+	--enable-decoder=pcm_u24be \
+	--enable-decoder=pcm_u24le \
+	--enable-decoder=rawvideo \
+	--disable-hwaccel=h264_dxva2 \
+	--disable-hwaccel=mpeg2_dxva2
+make
+mkdir -p inst
+make install DESTDIR=`pwd`/inst
+cd inst
+tar czf ../../bin/libav-9.1.tgz usr
+cd ../..
+fi
 
 # chromaprint
 
-cd chromaprint-0.6/
-test -f Makefile || eval cmake -DBUILD_EXAMPLES=ON -DBUILD_SHARED_LIBS=OFF -DEXTRA_LIBS=-lz -DFFMPEG_ROOT=$thisdir/libav-0.8.1/inst/usr/local $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
-mkdir inst
+# The zlib library path was added for MinGW-builds GCC 4.7.2.
+cd chromaprint-0.7/
+test -f Makefile || eval cmake -DBUILD_EXAMPLES=ON -DBUILD_SHARED_LIBS=OFF -DEXTRA_LIBS=\"-L$thisdir/zlib-1.2.7/inst/usr/local/lib -lz\" -DFFMPEG_ROOT=$thisdir/libav-$libav_version/inst/usr/local $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
+mkdir -p inst
 make install DESTDIR=`pwd`/inst
 fixcmakeinst
 cd inst
-tar czf ../../bin/chromaprint-0.6.tgz usr
+tar czf ../../bin/chromaprint-0.7.tgz usr
 cd ../..
 
 # mp4v2
@@ -859,16 +906,20 @@ elif test $kernel = "Darwin"; then
   sudo chmod go+w ${BUILDROOT}usr/local
 fi
 
-tar xzf bin/zlib-1.2.6.tgz -C $BUILDROOT
-tar xzf bin/libogg-1.2.2.tgz -C $BUILDROOT
+tar xzf bin/zlib-1.2.7.tgz -C $BUILDROOT
+tar xzf bin/libogg-1.3.0.tgz -C $BUILDROOT
 tar xzf bin/libvorbis-1.3.2.tgz -C $BUILDROOT
 tar xzf bin/flac-1.2.1.tgz -C $BUILDROOT
 tar xzf bin/id3lib-3.8.3.tgz -C $BUILDROOT
-tar xzf bin/taglib-1.7.1.tgz -C $BUILDROOT
-tar xzf bin/libav-0.8.1.tgz -C $BUILDROOT
-tar xzf bin/chromaprint-0.6.tgz -C $BUILDROOT
+tar xzf bin/taglib-1.8.tgz -C $BUILDROOT
+tar xzf bin/libav-${libav_version}.tgz -C $BUILDROOT
+tar xzf bin/chromaprint-0.7.tgz -C $BUILDROOT
 #tar xzf bin/mp4v2-1.9.1+svn479.tgz -C $BUILDROOT
 
 if test $kernel = "Darwin"; then
   sudo chmod go-w ${BUILDROOT}usr/local
 fi
+
+fi
+
+echo "Built successfully."
