@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Jul 2011
  *
- * Copyright (C) 2011-2012  Urs Fleisch
+ * Copyright (C) 2011-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -27,20 +27,22 @@
 #include "configstore.h"
 #include "config.h"
 #ifndef CONFIG_USE_KDE
+#include <QApplication>
 #include "shortcutsmodel.h"
 #endif
 
-MiscConfig ConfigStore::s_miscCfg("General Options");
-ImportConfig ConfigStore::s_genCfg("General Options");
-FormatConfig ConfigStore::s_fnFormatCfg("FilenameFormat");
-FormatConfig ConfigStore::s_id3FormatCfg("Id3Format");
-FreedbConfig ConfigStore::s_freedbCfg("Freedb");
-FreedbConfig ConfigStore::s_trackTypeCfg("TrackType");
-DiscogsConfig ConfigStore::s_discogsCfg("Discogs");
-AmazonConfig ConfigStore::s_amazonCfg("Amazon");
-MusicBrainzConfig ConfigStore::s_musicBrainzCfg("MusicBrainz");
-FilterConfig ConfigStore::s_filterCfg("Filter");
-PlaylistConfig ConfigStore::s_playlistCfg("Playlist");
+MiscConfig ConfigStore::s_miscCfg(QLatin1String("General Options"));
+ImportConfig ConfigStore::s_genCfg(QLatin1String("General Options"));
+BatchImportConfig ConfigStore::s_batchImportCfg(QLatin1String("BatchImport"));
+FormatConfig ConfigStore::s_fnFormatCfg(QLatin1String("FilenameFormat"));
+FormatConfig ConfigStore::s_id3FormatCfg(QLatin1String("Id3Format"));
+FreedbConfig ConfigStore::s_freedbCfg(QLatin1String("Freedb"));
+FreedbConfig ConfigStore::s_trackTypeCfg(QLatin1String("TrackType"));
+DiscogsConfig ConfigStore::s_discogsCfg(QLatin1String("Discogs"));
+AmazonConfig ConfigStore::s_amazonCfg(QLatin1String("Amazon"));
+MusicBrainzConfig ConfigStore::s_musicBrainzCfg(QLatin1String("MusicBrainz"));
+FilterConfig ConfigStore::s_filterCfg(QLatin1String("Filter"));
+PlaylistConfig ConfigStore::s_playlistCfg(QLatin1String("Playlist"));
 
 /**
  * Constructor.
@@ -50,8 +52,10 @@ ConfigStore::ConfigStore()
 #ifdef CONFIG_USE_KDE
   m_config = new KConfig;
 #else
-  m_config = new Kid3Settings(QSettings::UserScope, "kid3.sourceforge.net", "Kid3");
-  m_config->beginGroup("/kid3");
+  m_config = new Kid3Settings(
+        QSettings::UserScope, QLatin1String("kid3.sourceforge.net"),
+        QLatin1String("Kid3"), qApp);
+  m_config->beginGroup(QLatin1String("/kid3"));
   m_shortcutsModel = new ShortcutsModel;
 #endif
 }
@@ -61,7 +65,9 @@ ConfigStore::ConfigStore()
  */
 ConfigStore::~ConfigStore()
 {
-#ifndef CONFIG_USE_KDE
+#ifdef CONFIG_USE_KDE
+  delete m_config;
+#else
   delete m_shortcutsModel;
 #endif
   // m_config is not deleted because this could lead to a crash on Mac OS.
@@ -76,6 +82,7 @@ void ConfigStore::writeToConfig()
   s_fnFormatCfg.writeToConfig(m_config);
   s_id3FormatCfg.writeToConfig(m_config);
   s_genCfg.writeToConfig(m_config);
+  s_batchImportCfg.writeToConfig(m_config);
   s_freedbCfg.writeToConfig(m_config);
   s_trackTypeCfg.writeToConfig(m_config);
   s_discogsCfg.writeToConfig(m_config);
@@ -96,6 +103,7 @@ void ConfigStore::readFromConfig()
   s_fnFormatCfg.readFromConfig(m_config);
   s_id3FormatCfg.readFromConfig(m_config);
   s_genCfg.readFromConfig(m_config);
+  s_batchImportCfg.readFromConfig(m_config);
   s_freedbCfg.readFromConfig(m_config);
   s_trackTypeCfg.readFromConfig(m_config);
   s_discogsCfg.readFromConfig(m_config);
