@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2007  Urs Fleisch
+ * Copyright (C) 2003-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -33,6 +33,7 @@
 #include "kid3api.h"
 
 class QString;
+class QLocale;
 class FrameCollection;
 
 /**
@@ -84,6 +85,13 @@ public:
    */
   void formatFrames(FrameCollection& frames) const;
 
+  /**
+   * Format frames if format while editing is switched on.
+   *
+   * @param frames frames
+   */
+  void formatFramesIfEnabled(FrameCollection& frames) const;
+
   /**
    * Persist configuration.
    *
@@ -98,6 +106,18 @@ public:
    */
   virtual void readFromConfig(Kid3Settings* config);
 
+  /**
+   * Get name of locale to use for string conversions.
+   * @return locale name
+   */
+  QString getLocaleName() const { return m_localeName; }
+
+  /**
+   * Set name of locale to use for string conversions.
+   * @param localeName locale name
+   */
+  void setLocaleName(const QString& localeName);
+
   /** true to enable formating in line edits */
   bool m_formatWhileEditing;
   /** Case conversion option */
@@ -106,7 +126,20 @@ public:
   bool m_strRepEnabled;
   /** Mapping for string replacement */
   QMap<QString, QString> m_strRepMap;
+
 private:
+  /** Locale to use for case conversion */
+  QString m_localeName;
+
+  /** Returns a lowercase copy of @a str. */
+  QString toLower(const QString& str) const;
+
+  /** Returns an uppercase copy of @a str. */
+  QString toUpper(const QString& str) const;
+
+  /** Locale to use for string conversions */
+  const QLocale* m_locale;
+
   /** true if it is a file formatter */
   bool m_filenameFormatter;
 };
