@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Jan 2004
  *
- * Copyright (C) 2004-2007  Urs Fleisch
+ * Copyright (C) 2004-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -45,7 +45,8 @@ public:
   /** The ID3v2 version used for new tags. */
   enum Id3v2Version {
     ID3v2_3_0 = 0,
-    ID3v2_4_0 = 1
+    ID3v2_4_0 = 1,
+    ID3v2_3_0_TAGLIB = 2
   };
 
   /** Encoding used for ID3v2 frames. */
@@ -245,6 +246,8 @@ public:
   QString m_textEncodingV1;
   /** text encoding used for new ID3v2 tags */
   int m_textEncoding;
+  /** frames which are displayed for Tag 2 even if not present */
+  quint64 m_quickAccessFrames;
   /** number of digits in track number */
   int m_trackNumberDigits;
   /** true to play file on double click */
@@ -263,6 +266,12 @@ public:
   QString m_browser;
   /** true to show only custom genres in combo boxes */
   bool m_onlyCustomGenres;
+  /** true to open last opened file on startup */
+  bool m_loadLastOpenedFile;
+  /** path to last opened file */
+  QString m_lastOpenedFile;
+  /** default file name to save cover art */
+  QString m_defaultCoverFileName;
 #ifndef CONFIG_USE_KDE
   /** mainwindow geometry */
   QByteArray m_geometry;
