@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2006
  *
- * Copyright (C) 2006-2007  Urs Fleisch
+ * Copyright (C) 2006-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -42,9 +42,9 @@
  */
 ServerImporterConfig::ServerImporterConfig(const QString& grp, bool cgiPathUsed,
                                            bool additionalTagsUsed) :
-  GeneralConfig(grp), m_windowWidth(-1), m_windowHeight(-1),
+  GeneralConfig(grp),
   m_cgiPathUsed(cgiPathUsed), m_additionalTagsUsed(additionalTagsUsed),
-  m_additionalTags(true), m_coverArt(true)
+  m_standardTags(true), m_additionalTags(true), m_coverArt(true)
 {
 }
 
@@ -52,9 +52,10 @@ ServerImporterConfig::ServerImporterConfig(const QString& grp, bool cgiPathUsed,
  * Constructor.
  * Used to create temporary configuration.
  */
-ServerImporterConfig::ServerImporterConfig() : GeneralConfig("Temporary"),
-  m_windowWidth(-1), m_windowHeight(-1), m_cgiPathUsed(false),
-  m_additionalTagsUsed(false), m_additionalTags(false), m_coverArt(false) {}
+ServerImporterConfig::ServerImporterConfig() : GeneralConfig(QLatin1String("Temporary")),
+  m_cgiPathUsed(false),
+  m_additionalTagsUsed(false), m_standardTags(false), m_additionalTags(false),
+  m_coverArt(false) {}
 
 /**
  * Destructor.
@@ -74,22 +75,22 @@ void ServerImporterConfig::writeToConfig(Kid3Settings* config) const
   if (m_cgiPathUsed)
     cfg.writeEntry("CgiPath", m_cgiPath);
   if (m_additionalTagsUsed) {
+    cfg.writeEntry("StandardTags", m_standardTags);
     cfg.writeEntry("AdditionalTags", m_additionalTags);
     cfg.writeEntry("CoverArt", m_coverArt);
   }
-  cfg.writeEntry("WindowWidth", m_windowWidth);
-  cfg.writeEntry("WindowHeight", m_windowHeight);
+  cfg.writeEntry("WindowGeometry", m_windowGeometry);
 #else
-  config->beginGroup("/" + m_group);
-  config->setValue("/Server", QVariant(m_server));
+  config->beginGroup(QLatin1Char('/') + m_group);
+  config->setValue(QLatin1String("/Server"), QVariant(m_server));
   if (m_cgiPathUsed)
-    config->setValue("/CgiPath", QVariant(m_cgiPath));
+    config->setValue(QLatin1String("/CgiPath"), QVariant(m_cgiPath));
   if (m_additionalTagsUsed) {
-    config->setValue("/AdditionalTags", QVariant(m_additionalTags));
-    config->setValue("/CoverArt", QVariant(m_coverArt));
+    config->setValue(QLatin1String("/StandardTags"), QVariant(m_standardTags));
+    config->setValue(QLatin1String("/AdditionalTags"), QVariant(m_additionalTags));
+    config->setValue(QLatin1String("/CoverArt"), QVariant(m_coverArt));
   }
-  config->setValue("/WindowWidth", QVariant(m_windowWidth));
-  config->setValue("/WindowHeight", QVariant(m_windowHeight));
+  config->setValue(QLatin1String("/WindowGeometry"), QVariant(m_windowGeometry));
   config->endGroup();
 #endif
 }
@@ -107,24 +108,26 @@ void ServerImporterConfig::readFromConfig(Kid3Settings* config)
   if (m_cgiPathUsed)
     m_cgiPath = cfg.readEntry("CgiPath", m_cgiPath);
   if (m_additionalTagsUsed) {
+    m_standardTags = cfg.readEntry("StandardTags",
+                                   m_standardTags);
     m_additionalTags = cfg.readEntry("AdditionalTags",
                                              m_additionalTags);
     m_coverArt = cfg.readEntry("CoverArt", m_coverArt);
   }
-  m_windowWidth = cfg.readEntry("WindowWidth", -1);
-  m_windowHeight = cfg.readEntry("WindowHeight", -1);
+  m_windowGeometry = cfg.readEntry("WindowGeometry", QByteArray());
 #else
-  config->beginGroup("/" + m_group);
-  m_server = config->value("/Server", m_server).toString();
+  config->beginGroup(QLatin1Char('/') + m_group);
+  m_server = config->value(QLatin1String("/Server"), m_server).toString();
   if (m_cgiPathUsed)
-    m_cgiPath = config->value("/CgiPath", m_cgiPath).toString();
+    m_cgiPath = config->value(QLatin1String("/CgiPath"), m_cgiPath).toString();
   if (m_additionalTagsUsed) {
-    m_additionalTags = config->value("/AdditionalTags",
+    m_standardTags = config->value(QLatin1String("/StandardTags"),
+                                   m_standardTags).toBool();
+    m_additionalTags = config->value(QLatin1String("/AdditionalTags"),
                                      m_additionalTags).toBool();
-    m_coverArt = config->value("/CoverArt", m_coverArt).toBool();
+    m_coverArt = config->value(QLatin1String("/CoverArt"), m_coverArt).toBool();
   }
-  m_windowWidth = config->value("/WindowWidth", -1).toInt();
-  m_windowHeight = config->value("/WindowHeight", -1).toInt();
+  m_windowGeometry = config->value(QLatin1String("/WindowGeometry")).toByteArray();
   config->endGroup();
 #endif
 }
