@@ -78,11 +78,8 @@ public:
   /** CGI path used for access */
   QString m_cgiPath;
 
-  /** window width */
-  int m_windowWidth;
-
-  /** window height */
-  int m_windowHeight;
+  /** window geometry */
+  QByteArray m_windowGeometry;
 
   /** true if CgiPath configuration is used */
   bool m_cgiPathUsed;
@@ -90,6 +87,9 @@ public:
   /** true if additional tags configuration is used */
   bool m_additionalTagsUsed;
 
+  /** standard tags imported */
+  bool m_standardTags;
+
   /** additional tags imported */
   bool m_additionalTags;
 
