@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 04 Oct 2005
  *
- * Copyright (C) 2005-2012  Urs Fleisch
+ * Copyright (C) 2005-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -34,7 +34,7 @@
 #include <QDir>
 #include <QImage>
 #include <sys/stat.h>
-#ifdef WIN32
+#ifdef Q_OS_WIN32
 #include <sys/utime.h>
 #else
 #include <utime.h>
@@ -80,13 +80,13 @@ static void getPicture(Frame& frame, const FLAC::Metadata::Picture* pic)
     pic->get_data_length());
   PictureFrame::setFields(
     frame,
-    Frame::Field::TE_ISO8859_1, "",
-    QString::fromAscii(pic->get_mime_type()),
+    Frame::Field::TE_ISO8859_1, QLatin1String(""),
+    QString::fromLatin1(pic->get_mime_type()),
     static_cast<PictureFrame::PictureType>(pic->get_type()),
     QString::fromUtf8(
       reinterpret_cast<const char*>(pic->get_description())),
     ba);
-  frame.setInternalName("Picture");
+  frame.setExtendedType(Frame::ExtendedType(Frame::FT_Picture, QLatin1String("Picture")));
 }
 
 /**
@@ -108,9 +108,9 @@ static void setPicture(const Frame& frame, FLAC::Metadata::Picture* pic)
     pic->set_width(image.width());
     pic->set_height(image.height());
     pic->set_depth(image.depth());
-    pic->set_colors(image.numColors());
+    pic->set_colors(image.colorCount());
   }
-  pic->set_mime_type(mimeType.toAscii());
+  pic->set_mime_type(mimeType.toLatin1());
   pic->set_type(
     static_cast<FLAC__StreamMetadata_Picture_Type>(pictureType));
   pic->set_description(
@@ -190,7 +190,7 @@ void FlacFile::readTags(bool force)
               FLAC::Metadata::Picture* pic =
                 dynamic_cast<FLAC::Metadata::Picture*>(proto);
               if (pic) {
-                Frame frame(Frame::FT_Picture, "", "", pictureNr++);
+                Frame frame(Frame::FT_Picture, QLatin1String(""), QLatin1String(""), pictureNr++);
                 getPicture(frame, pic);
                 m_pictures.push_back(frame);
               }
@@ -397,8 +397,8 @@ bool FlacFile::addFrameV2(Frame& frame)
   if (frame.getType() == Frame::FT_Picture) {
     if (frame.getFieldList().empty()) {
       PictureFrame::setFields(
-        frame, Frame::Field::TE_ISO8859_1, "JPG", "image/jpeg",
-        PictureFrame::PT_CoverFront, "", QByteArray());
+        frame, Frame::Field::TE_ISO8859_1, QLatin1String("JPG"), QLatin1String("image/jpeg"),
+        PictureFrame::PT_CoverFront, QLatin1String(""), QByteArray());
     }
     PictureFrame::setDescription(frame, frame.getValue());
     frame.setIndex(m_pictures.size());
@@ -459,19 +459,6 @@ void FlacFile::getAllFramesV2(FrameCollection& frames)
     frames.insert(*it);
   }
 }
-
-/**
- * Get a list of frame IDs which can be added.
- *
- * @return list with frame IDs.
- */
-QStringList FlacFile::getFrameIds() const
-{
-  QStringList lst(OggFile::getFrameIds());
-  QStringList::iterator it = lst.begin() + Frame::FT_Picture;
-  lst.insert(it, QCM_translate(Frame::getNameFromType(Frame::FT_Picture)));
-  return lst;
-}
 #endif // HAVE_FLAC_PICTURE
 
 /**
@@ -521,7 +508,7 @@ void FlacFile::getDetailInfo(DetailInfo& info) const
 {
   if (m_fileRead && m_fileInfo.valid) {
     info.valid = true;
-    info.format = "FLAC";
+    info.format = QLatin1String("FLAC");
     info.bitrate = m_fileInfo.bitrate / 1000;
     info.sampleRate = m_fileInfo.sampleRate;
     info.channels = m_fileInfo.channels;
@@ -552,7 +539,7 @@ unsigned FlacFile::getDuration() const
  */
 QString FlacFile::getFileExtension() const
 {
-  return ".flac";
+  return QLatin1String(".flac");
 }
 
 
@@ -588,7 +575,7 @@ bool FlacFile::FileInfo::read(FLAC::Metadata::StreamInfo* si)
 TaggedFile* FlacFile::Resolver::createFile(const QString& dn, const QString& fn,
     const QPersistentModelIndex& idx) const
 {
-  if (fn.right(5).toLower() == ".flac")
+  if (fn.right(5).toLower() == QLatin1String(".flac"))
     return new FlacFile(dn, fn, idx);
   else
     return 0;
@@ -601,7 +588,7 @@ TaggedFile* FlacFile::Resolver::createFile(const QString& dn, const QString& fn,
  */
 QStringList FlacFile::Resolver::getSupportedFileExtensions() const
 {
-  return QStringList() << ".flac";
+  return QStringList() << QLatin1String(".flac");
 }
 
 #endif // HAVE_FLAC
