@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2012  Urs Fleisch
+ * Copyright (C) 2003-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -35,7 +35,7 @@
 #include <cstring>
 #include <sys/stat.h>
 #include <id3/tag.h>
-#ifdef WIN32
+#ifdef Q_OS_WIN32
 #include <id3.h>
 #include <sys/utime.h>
 #else
@@ -47,7 +47,7 @@
 #include "attributedata.h"
 #include "qtcompatmac.h"
 
-#ifdef WIN32
+#ifdef Q_OS_WIN32
 /**
  * This will be set for id3lib versions with Unicode bugs.
  * ID3LIB_ symbols cannot be found on Windows ?!
@@ -58,11 +58,26 @@
 #define UNICODE_SUPPORT_BUGGY ((((ID3LIB_MAJOR_VERSION) << 16) + ((ID3LIB_MINOR_VERSION) << 8) + (ID3LIB_PATCH_VERSION)) <= 0x030803)
 #endif
 
+#if defined __GNUC__ && (__GNUC__ * 100 + __GNUC_MINOR__) >= 407
+/** Defined if GCC is used and supports diagnostic pragmas */
+#define GCC_HAS_DIAGNOSTIC_PRAGMA
+#endif
+
+namespace {
+
 /** Text codec for ID3v1 tags, 0 to use default (ISO 8859-1) */
-const QTextCodec* Mp3File::s_textCodecV1 = 0;
+const QTextCodec* s_textCodecV1 = 0;
 
 /** Default text encoding */
-ID3_TextEnc Mp3File::s_defaultTextEncoding = ID3TE_ISO8859_1;
+ID3_TextEnc s_defaultTextEncoding = ID3TE_ISO8859_1;
+
+/**
+ * Get the default text encoding.
+ * @return default text encoding.
+ */
+ID3_TextEnc getDefaultTextEncoding() { return s_defaultTextEncoding; }
+
+}
 
 /**
  * Constructor.
@@ -214,11 +229,19 @@ void Mp3File::deleteFramesV1(const FrameFilter& flt)
       while ((frame = iter->GetNext()) != NULL) {
         m_tagV1->RemoveFrame(frame);
       }
-#ifdef WIN32
+#ifdef Q_OS_WIN32
       /* allocated in Windows DLL => must be freed in the same DLL */
       ID3TagIterator_Delete(reinterpret_cast<ID3TagIterator*>(iter));
 #else
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdelete-non-virtual-dtor"
+/* Is safe because iterator implementation has default destructor */
+#endif
       delete iter;
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic pop
+#endif
 #endif
       markTag1Changed(Frame::FT_UnknownFrame);
       clearTrunctionFlags();
@@ -275,7 +298,7 @@ static QString fixUpUnicode(const unicode_t* str, size_t numChars)
  */
 static QString getString(ID3_Field* field, const QTextCodec* codec = 0)
 {
-  QString text("");
+  QString text(QLatin1String(""));
   if (field != NULL) {
     ID3_TextEnc enc = field->GetEncoding();
     if (enc == ID3TE_UTF16 || enc == ID3TE_UTF16BE) {
@@ -290,7 +313,7 @@ static QString getString(ID3_Field* field, const QTextCodec* codec = 0)
         // object, so I do not use it.
         text = fixUpUnicode(field->GetRawUnicodeText(),
                             field->Size() / sizeof(unicode_t));
-        text.replace('\0', Frame::stringListSeparator());
+        text.replace(QLatin1Char('\0'), Frame::stringListSeparator());
       }
     } else {
       // (ID3TE_IS_SINGLE_BYTE_ENC(enc))
@@ -299,16 +322,16 @@ static QString getString(ID3_Field* field, const QTextCodec* codec = 0)
       if (numItems <= 1) {
         text = codec ?
           codec->toUnicode(field->GetRawText(), field->Size()) :
-          QString(field->GetRawText());
+          QString::fromLatin1(field->GetRawText());
       } else {
         // if there are multiple items, put them into one string
         // separated by a special separator.
         for (size_t itemNr = 0; itemNr < numItems; ++itemNr) {
           if (itemNr == 0) {
-            text = field->GetRawTextItem(0);
+            text = QString::fromLatin1(field->GetRawTextItem(0));
           } else {
             text += Frame::stringListSeparator();
-            text += field->GetRawTextItem(itemNr);
+            text += QString::fromLatin1(field->GetRawTextItem(itemNr));
           }
         }
       }
@@ -333,7 +356,7 @@ static QString getTextField(const ID3_Tag* tag, ID3_FrameID id,
   if (!tag) {
     return QString::null;
   }
-  QString str("");
+  QString str(QLatin1String(""));
   ID3_Field* fld;
   ID3_Frame* frame = tag->Find(id);
   if (frame && ((fld = frame->GetField(ID3FN_TEXT)) != NULL)) {
@@ -372,7 +395,7 @@ static int getTrackNum(const ID3_Tag* tag)
   if (str.isNull()) return -1;
   if (str.isEmpty()) return 0;
   // handle "track/total number of tracks" format
-  int slashPos = str.indexOf('/');
+  int slashPos = str.indexOf(QLatin1Char('/'));
   if (slashPos != -1) {
     str.truncate(slashPos);
   }
@@ -393,7 +416,7 @@ static int getGenreNum(const ID3_Tag* tag)
   if (str.isNull()) return -1;
   if (str.isEmpty()) return 0xff;
   int cpPos = 0, n = 0xff;
-  if ((str[0] == '(') && ((cpPos = str.indexOf(')', 2)) > 1)) {
+  if ((str[0] == QLatin1Char('(')) && ((cpPos = str.indexOf(QLatin1Char(')'), 2)) > 1)) {
     bool ok;
     n = str.mid(1, cpPos - 1).toInt(&ok);
     if (!ok || n > 0xff) {
@@ -556,7 +579,7 @@ static bool setTextField(ID3_Tag* tag, ID3_FrameID id, const QString& text,
         ID3_Field* fld = frame->GetField(ID3FN_TEXT);
         if (fld) {
           ID3_TextEnc enc = tag->HasV2Tag() ?
-            Mp3File::getDefaultTextEncoding() : ID3TE_ISO8859_1;
+            getDefaultTextEncoding() : ID3TE_ISO8859_1;
           if (allowUnicode && enc == ID3TE_ISO8859_1) {
             // check if information is lost if the string is not unicode
             uint i, unicode_size = text.length();
@@ -600,7 +623,7 @@ static bool setYear(ID3_Tag* tag, int num)
     if (num != 0) {
       str.setNum(num);
     } else {
-      str = "";
+      str.clear();
     }
     changed = getTextField(tag, ID3FID_YEAR) != str &&
               setTextField(tag, ID3FID_YEAR, str);
@@ -642,9 +665,9 @@ static bool setGenreNum(ID3_Tag* tag, int num)
   if (num >= 0) {
     QString str;
     if (num != 0xff) {
-      str = QString("(%1)").arg(num);
+      str = QString(QLatin1String("(%1)")).arg(num);
     } else {
-      str = "";
+      str.clear();
     }
     changed = getTextField(tag, ID3FID_CONTENTTYPE) != str &&
               setTextField(tag, ID3FID_CONTENTTYPE, str);
@@ -737,9 +760,9 @@ QString Mp3File::getGenreV1()
   if (num == -1) {
     return QString::null;
   } else if (num == 0xff) {
-    return "";
+    return QLatin1String("");
   } else {
-    return Genres::getName(num);
+    return QString::fromLatin1(Genres::getName(num));
   }
 }
 
@@ -826,7 +849,7 @@ QString Mp3File::getGenreV2()
 {
   int num = getGenreNum(m_tagV2);
   if (num != 0xff && num != -1) {
-    return Genres::getName(num);
+    return QString::fromLatin1(Genres::getName(num));
   } else {
     return getTextField(m_tagV2, ID3FID_CONTENTTYPE);
   }
@@ -842,7 +865,7 @@ void Mp3File::setTitleV1(const QString& str)
   if (getTextField(m_tagV1, ID3FID_TITLE, s_textCodecV1) != str &&
       setTextField(m_tagV1, ID3FID_TITLE, str, false, true, true, s_textCodecV1)) {
     markTag1Changed(Frame::FT_Title);
-    QString s = checkTruncation(str, 1 << Frame::FT_Title);
+    QString s = checkTruncation(str, 1ULL << Frame::FT_Title);
     if (!s.isNull()) setTextField(m_tagV1, ID3FID_TITLE, s, false, true, true, s_textCodecV1);
   }
 }
@@ -857,7 +880,7 @@ void Mp3File::setArtistV1(const QString& str)
   if (getTextField(m_tagV1, ID3FID_LEADARTIST, s_textCodecV1) != str &&
       setTextField(m_tagV1, ID3FID_LEADARTIST, str, false, true, true, s_textCodecV1)) {
     markTag1Changed(Frame::FT_Artist);
-    QString s = checkTruncation(str, 1 << Frame::FT_Artist);
+    QString s = checkTruncation(str, 1ULL << Frame::FT_Artist);
     if (!s.isNull()) setTextField(m_tagV1, ID3FID_LEADARTIST, s, false, true, true, s_textCodecV1);
   }
 }
@@ -872,7 +895,7 @@ void Mp3File::setAlbumV1(const QString& str)
   if (getTextField(m_tagV1, ID3FID_ALBUM, s_textCodecV1) != str &&
       setTextField(m_tagV1, ID3FID_ALBUM, str, false, true, true, s_textCodecV1)) {
     markTag1Changed(Frame::FT_Album);
-    QString s = checkTruncation(str, 1 << Frame::FT_Album);
+    QString s = checkTruncation(str, 1ULL << Frame::FT_Album);
     if (!s.isNull()) setTextField(m_tagV1, ID3FID_ALBUM, s, false, true, true, s_textCodecV1);
   }
 }
@@ -887,7 +910,7 @@ void Mp3File::setCommentV1(const QString& str)
   if (getTextField(m_tagV1, ID3FID_COMMENT, s_textCodecV1) != str &&
       setTextField(m_tagV1, ID3FID_COMMENT, str, false, true, true, s_textCodecV1)) {
     markTag1Changed(Frame::FT_Comment);
-    QString s = checkTruncation(str, 1 << Frame::FT_Comment, 28);
+    QString s = checkTruncation(str, 1ULL << Frame::FT_Comment, 28);
     if (!s.isNull()) setTextField(m_tagV1, ID3FID_COMMENT, s, false, true, true, s_textCodecV1);
   }
 }
@@ -913,7 +936,7 @@ void Mp3File::setTrackNumV1(int num)
 {
   if (setTrackNum(m_tagV1, num)) {
     markTag1Changed(Frame::FT_Track);
-    int n = checkTruncation(num, 1 << Frame::FT_Track);
+    int n = checkTruncation(num, 1ULL << Frame::FT_Track);
     if (n != -1) setTrackNum(m_tagV1, n);
   }
 }
@@ -932,7 +955,7 @@ void Mp3File::setGenreV1(const QString& str)
     }
     // if the string cannot be converted to a number, set the truncation flag
     checkTruncation(num == 0xff && !str.isEmpty() ? 1 : 0,
-                    1 << Frame::FT_Genre, 0);
+                    1ULL << Frame::FT_Genre, 0);
   }
 }
 
@@ -1091,9 +1114,9 @@ bool Mp3File::hasTagV2() const
  */
 void Mp3File::getDetailInfo(DetailInfo& info) const
 {
-  if (getFilename().right(4).toLower() == ".aac") {
+  if (getFilename().right(4).toLower() == QLatin1String(".aac")) {
     info.valid = true;
-    info.format = "AAC";
+    info.format = QLatin1String("AAC");
     return;
   }
 
@@ -1108,26 +1131,26 @@ void Mp3File::getDetailInfo(DetailInfo& info) const
     info.valid = true;
     switch (headerInfo->version) {
       case MPEGVERSION_1:
-        info.format = "MPEG 1 ";
+        info.format = QLatin1String("MPEG 1 ");
         break;
       case MPEGVERSION_2:
-        info.format = "MPEG 2 ";
+        info.format = QLatin1String("MPEG 2 ");
         break;
       case MPEGVERSION_2_5:
-        info.format = "MPEG 2.5 ";
+        info.format = QLatin1String("MPEG 2.5 ");
         break;
       default:
         ; // nothing
     }
     switch (headerInfo->layer) {
       case MPEGLAYER_I:
-        info.format += "Layer 1";
+        info.format += QLatin1String("Layer 1");
         break;
       case MPEGLAYER_II:
-        info.format += "Layer 2";
+        info.format += QLatin1String("Layer 2");
         break;
       case MPEGLAYER_III:
-        info.format += "Layer 3";
+        info.format += QLatin1String("Layer 3");
         break;
       default:
         ; // nothing
@@ -1194,10 +1217,10 @@ unsigned Mp3File::getDuration() const
 QString Mp3File::getFileExtension() const
 {
   QString ext(getFilename().right(4).toLower());
-  if (ext == ".aac" || ext == ".mp2")
+  if (ext == QLatin1String(".aac") || ext == QLatin1String(".mp2"))
     return ext;
   else
-    return ".mp3";
+    return QLatin1String(".mp3");
 }
 
 /**
@@ -1208,7 +1231,7 @@ QString Mp3File::getFileExtension() const
  */
 QString Mp3File::getTagFormatV1() const
 {
-  return hasTagV1() ? QString("ID3v1.1") : QString::null;
+  return hasTagV1() ? QString(QLatin1String("ID3v1.1")) : QString();
 }
 
 /**
@@ -1222,13 +1245,13 @@ QString Mp3File::getTagFormatV2() const
   if (m_tagV2 && m_tagV2->HasV2Tag()) {
     switch (m_tagV2->GetSpec()) {
       case ID3V2_3_0:
-        return "ID3v2.3.0";
+        return QLatin1String("ID3v2.3.0");
       case ID3V2_4_0:
-        return "ID3v2.4.0";
+        return QLatin1String("ID3v2.4.0");
       case ID3V2_2_0:
-        return "ID3v2.2.0";
+        return QLatin1String("ID3v2.2.0");
       case ID3V2_2_1:
-        return "ID3v2.2.1";
+        return QLatin1String("ID3v2.2.1");
       default:
         break;
     }
@@ -1290,7 +1313,7 @@ static const struct TypeStrOfId {
   { Frame::FT_Grouping,       I18N_NOOP("TIT1 - Content group description") },                       /* TIT1 */
   { Frame::FT_Title,          I18N_NOOP("TIT2 - Title/songname/content description") },              /* TIT2 */
   { Frame::FT_Subtitle,       I18N_NOOP("TIT3 - Subtitle/Description refinement") },                 /* TIT3 */
-  { Frame::FT_Other,          I18N_NOOP("TKEY - Initial key") },                                     /* TKEY */
+  { Frame::FT_InitialKey,     I18N_NOOP("TKEY - Initial key") },                                     /* TKEY */
   { Frame::FT_Language,       I18N_NOOP("TLAN - Language(s)") },                                     /* TLAN */
   { Frame::FT_Other,          I18N_NOOP("TLEN - Length") },                                          /* TLEN */
   { Frame::FT_Other,          0 },                                                                   /* TMCL */
@@ -1318,7 +1341,7 @@ static const struct TypeStrOfId {
   { Frame::FT_Other,          0 },                                                                   /* TSOP */
   { Frame::FT_Other,          0 },                                                                   /* TSOT */
   { Frame::FT_Isrc,           I18N_NOOP("TSRC - ISRC (international standard recording code)") },    /* TSRC */
-  { Frame::FT_Other,          I18N_NOOP("TSSE - Software/Hardware and settings used for encoding") },/* TSSE */
+  { Frame::FT_EncoderSettings,I18N_NOOP("TSSE - Software/Hardware and settings used for encoding") },/* TSSE */
   { Frame::FT_Part,           0 },                                                                   /* TSST */
   { Frame::FT_Other,          I18N_NOOP("TXXX - User defined text information") },                   /* TXXX */
   { Frame::FT_Date,           I18N_NOOP("TYER - Year") },                                            /* TYER */
@@ -1327,9 +1350,9 @@ static const struct TypeStrOfId {
   { Frame::FT_Lyrics,         I18N_NOOP("USLT - Unsynchronized lyric/text transcription") },         /* USLT */
   { Frame::FT_Other,          I18N_NOOP("WCOM - Commercial information") },                          /* WCOM */
   { Frame::FT_Other,          I18N_NOOP("WCOP - Copyright/Legal information") },                     /* WCOP */
-  { Frame::FT_Other,          I18N_NOOP("WOAF - Official audio file webpage") },                     /* WOAF */
+  { Frame::FT_WWWAudioFile,   I18N_NOOP("WOAF - Official audio file webpage") },                     /* WOAF */
   { Frame::FT_Website,        I18N_NOOP("WOAR - Official artist/performer webpage") },               /* WOAR */
-  { Frame::FT_Other,          I18N_NOOP("WOAS - Official audio source webpage") },                   /* WOAS */
+  { Frame::FT_WWWAudioSource, I18N_NOOP("WOAS - Official audio source webpage") },                   /* WOAS */
   { Frame::FT_Other,          I18N_NOOP("WORS - Official internet radio station homepage") },        /* WORS */
   { Frame::FT_Other,          I18N_NOOP("WPAY - Payment") },                                         /* WPAY */
   { Frame::FT_Other,          I18N_NOOP("WPUB - Official publisher webpage") },                      /* WPUB */
@@ -1368,6 +1391,9 @@ static ID3_FrameID getId3libFrameIdForType(Frame::Type type)
   // IPLS is mapped to FT_Arranger and FT_Performer
   if (type == Frame::FT_Performer) {
     return ID3FID_INVOLVEDPEOPLE;
+  } else if (type == Frame::FT_CatalogNumber ||
+             type == Frame::FT_ReleaseCountry) {
+    return ID3FID_USERTEXT;
   }
 
   static int typeIdMap[Frame::FT_LastFrame + 1] = { -1, };
@@ -1448,11 +1474,19 @@ static QString getFieldsFromId3Frame(ID3_Frame* id3Frame,
     }
     fields.push_back(field);
   }
-#ifdef WIN32
+#ifdef Q_OS_WIN32
   /* allocated in Windows DLL => must be freed in the same DLL */
   ID3TagIterator_Delete(reinterpret_cast<ID3TagIterator*>(iter));
 #else
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdelete-non-virtual-dtor"
+/* Is safe because iterator implementation has default destructor */
+#endif
   delete iter;
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic pop
+#endif
 #endif
   return text;
 }
@@ -1479,11 +1513,19 @@ static ID3_Frame* getId3v2Frame(ID3_Tag* tag, int index)
       }
       ++i;
     }
-#ifdef WIN32
+#ifdef Q_OS_WIN32
     /* allocated in Windows DLL => must be freed in the same DLL */
     ID3TagIterator_Delete(reinterpret_cast<ID3TagIterator*>(iter));
 #else
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdelete-non-virtual-dtor"
+/* Is safe because iterator implementation has default destructor */
+#endif
     delete iter;
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic pop
+#endif
 #endif
   }
   return result;
@@ -1552,11 +1594,19 @@ void Mp3File::setId3v2Frame(ID3_Frame* id3Frame, const Frame& frame) const
         qDebug("Unknown type %d in field %d", fld.m_value.type(), fld.m_id);
     }
   }
-#ifdef WIN32
+#ifdef Q_OS_WIN32
   /* allocated in Windows DLL => must be freed in the same DLL */
   ID3TagIterator_Delete(reinterpret_cast<ID3TagIterator*>(iter));
 #else
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdelete-non-virtual-dtor"
+/* Is safe because iterator implementation has default destructor */
+#endif
   delete iter;
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic pop
+#endif
 #endif
 }
 
@@ -1594,22 +1644,37 @@ bool Mp3File::setFrameV2(const Frame& frame)
           } else if (id3Frame->GetID() == ID3FID_TRACKNUM) {
             formatTrackNumberIfEnabled(value, true);
           }
-          if (fld->GetEncoding() == ID3TE_ISO8859_1) {
+          bool hasEnc;
+          const ID3_TextEnc enc = fld->GetEncoding();
+          ID3_TextEnc newEnc = static_cast<ID3_TextEnc>(
+                frame.getFieldValue(Frame::Field::ID_TextEnc).toInt(&hasEnc));
+          if (!hasEnc) {
+            newEnc = enc;
+          }
+          if (newEnc != ID3TE_ISO8859_1 && newEnc != ID3TE_UTF16) {
+            // only ISO-8859-1 and UTF16 are allowed for ID3v2.3.0
+            newEnc = ID3TE_UTF16;
+          }
+          if (newEnc == ID3TE_ISO8859_1) {
             // check if information is lost if the string is not unicode
             uint i, unicode_size = value.length();
             const QChar* qcarray = value.unicode();
             for (i = 0; i < unicode_size; i++) {
               char ch = qcarray[i].toLatin1();
               if (ch == 0 || (ch & 0x80) != 0) {
-                ID3_Field* encfld = id3Frame->GetField(ID3FN_TEXTENC);
-                if (encfld) {
-                  encfld->Set(ID3TE_UTF16);
-                }
-                fld->SetEncoding(ID3TE_UTF16);
+                newEnc = ID3TE_UTF16;
                 break;
               }
             }
           }
+          if (enc != newEnc) {
+            ID3_Field* encfld = id3Frame->GetField(ID3FN_TEXTENC);
+            if (encfld) {
+              encfld->Set(newEnc);
+            }
+            fld->SetEncoding(newEnc);
+            markTag2Changed(frame.getType());
+          }
           if (getString(fld) != value) {
             setString(fld, value);
             markTag2Changed(frame.getType());
@@ -1634,7 +1699,7 @@ bool Mp3File::setFrameV2(const Frame& frame)
         } else if (id3Frame->GetID() == ID3FID_CDID &&
                    (fld = id3Frame->GetField(ID3FN_DATA)) != 0) {
           QByteArray newData, oldData;
-          if (AttributeData::isHexString(value, 'F', "+") &&
+          if (AttributeData::isHexString(value, 'F', QLatin1String("+")) &&
               AttributeData(AttributeData::Utf16).toByteArray(value, newData)) {
             oldData = QByteArray((const char *)fld->GetRawBinary(),
                                  (unsigned int)fld->Size());
@@ -1649,7 +1714,7 @@ bool Mp3File::setFrameV2(const Frame& frame)
                    (fld = id3Frame->GetField(ID3FN_DATA)) != 0) {
           QByteArray newData, oldData;
           if (AttributeData::isHexString(value, 'Z')) {
-            newData = (value + '\0').toLatin1();
+            newData = (value + QLatin1Char('\0')).toLatin1();
             oldData = QByteArray((const char *)fld->GetRawBinary(),
                                  (unsigned int)fld->Size());
             if (newData != oldData) {
@@ -1696,7 +1761,15 @@ bool Mp3File::addFrameV2(Frame& frame)
   } else {
     id = getId3libFrameIdForName(frame.getName());
     if (id == ID3FID_NOFRAME) {
-      id = ID3FID_USERTEXT;
+      if (frame.getName() == QLatin1String("AverageLevel") ||
+          frame.getName() == QLatin1String("PeakValue") ||
+          frame.getName().startsWith(QLatin1String("WM/"))) {
+        id = ID3FID_PRIVATE;
+      } else if (frame.getName().startsWith(QLatin1String("iTun"))) {
+        id = ID3FID_COMMENT;
+      } else {
+        id = ID3FID_USERTEXT;
+      }
     }
   }
   if (id != ID3FID_NOFRAME && id != ID3FID_SETSUBTITLE && m_tagV2) {
@@ -1710,15 +1783,51 @@ bool Mp3File::addFrameV2(Frame& frame)
       }
       fld->SetEncoding(enc);
     }
-    if (id == ID3FID_USERTEXT && !frame.getName().startsWith("TXXX")) {
+    if (id == ID3FID_USERTEXT && !frame.getName().startsWith(QLatin1String("TXXX"))) {
+      fld = id3Frame->GetField(ID3FN_DESCRIPTION);
+      if (fld) {
+        QString description;
+        if (frame.getType() == Frame::FT_CatalogNumber) {
+          description = QLatin1String("CATALOGNUMBER");
+        } else if (frame.getType() == Frame::FT_ReleaseCountry) {
+          description = QLatin1String("RELEASECOUNTRY");
+        } else {
+          description = frame.getName();
+        }
+        setString(fld, description);
+      }
+    } else if (id == ID3FID_COMMENT && frame.getType() == Frame::FT_Other) {
       fld = id3Frame->GetField(ID3FN_DESCRIPTION);
       if (fld) {
         setString(fld, frame.getName());
       }
+    } else if (id == ID3FID_PRIVATE && !frame.getName().startsWith(QLatin1String("PRIV"))) {
+      fld = id3Frame->GetField(ID3FN_OWNER);
+      if (fld) {
+        setString(fld, frame.getName());
+        QByteArray data;
+        if (AttributeData(frame.getName()).toByteArray(frame.getValue(), data)) {
+          fld = id3Frame->GetField(ID3FN_DATA);
+          if (fld) {
+            fld->Set(reinterpret_cast<const unsigned char*>(data.data()),
+                     data.size());
+          }
+        }
+      }
+    } else if (id == ID3FID_UNIQUEFILEID) {
+      QByteArray data;
+      if (AttributeData::isHexString(frame.getValue(), 'Z')) {
+        data = (frame.getValue() + QLatin1Char('\0')).toLatin1();
+        fld = id3Frame->GetField(ID3FN_DATA);
+        if (fld) {
+          fld->Set(reinterpret_cast<const unsigned char*>(data.data()),
+                   data.size());
+        }
+      }
     } else if (id == ID3FID_PICTURE) {
       fld = id3Frame->GetField(ID3FN_MIMETYPE);
       if (fld) {
-        setString(fld, "image/jpeg");
+        setString(fld, QLatin1String("image/jpeg"));
       }
       fld = id3Frame->GetField(ID3FN_PICTURETYPE);
       if (fld) {
@@ -1732,7 +1841,7 @@ bool Mp3File::addFrameV2(Frame& frame)
     const char* name;
     getTypeStringForId3libFrameId(id, type, name);
     m_tagV2->AttachFrame(id3Frame);
-    frame.setInternalName(name);
+    frame.setExtendedType(Frame::ExtendedType(type, QString::fromLatin1(name)));
     frame.setIndex(m_tagV2->NumFrames() - 1);
     if (frame.fieldList().empty()) {
       // add field list to frame
@@ -1785,11 +1894,19 @@ void Mp3File::deleteFramesV2(const FrameFilter& flt)
       while ((frame = iter->GetNext()) != NULL) {
         m_tagV2->RemoveFrame(frame);
       }
-#ifdef WIN32
+#ifdef Q_OS_WIN32
       /* allocated in Windows DLL => must be freed in the same DLL */
       ID3TagIterator_Delete(reinterpret_cast<ID3TagIterator*>(iter));
 #else
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdelete-non-virtual-dtor"
+/* Is safe because iterator implementation has default destructor */
+#endif
       delete iter;
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic pop
+#endif
 #endif
       markTag2Changed(Frame::FT_UnknownFrame);
     } else {
@@ -1799,15 +1916,23 @@ void Mp3File::deleteFramesV2(const FrameFilter& flt)
         Frame::Type type;
         const char* name;
         getTypeStringForId3libFrameId(frame->GetID(), type, name);
-        if (flt.isEnabled(type, name)) {
+        if (flt.isEnabled(type, QString::fromLatin1(name))) {
           m_tagV2->RemoveFrame(frame);
         }
       }
-#ifdef WIN32
+#ifdef Q_OS_WIN32
       /* allocated in Windows DLL => must be freed in the same DLL */
       ID3TagIterator_Delete(reinterpret_cast<ID3TagIterator*>(iter));
 #else
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdelete-non-virtual-dtor"
+/* Is safe because iterator implementation has default destructor */
+#endif
       delete iter;
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic pop
+#endif
 #endif
       markTag2Changed(Frame::FT_UnknownFrame);
     }
@@ -1830,7 +1955,7 @@ void Mp3File::getAllFramesV2(FrameCollection& frames)
     const char* name;
     while ((id3Frame = iter->GetNext()) != 0) {
       getTypeStringForId3libFrameId(id3Frame->GetID(), type, name);
-      Frame frame(type, "", name, i++);
+      Frame frame(type, QLatin1String(""), QString::fromLatin1(name), i++);
       frame.setValue(getFieldsFromId3Frame(id3Frame, frame.fieldList()));
       if (id3Frame->GetID() == ID3FID_USERTEXT ||
           id3Frame->GetID() == ID3FID_WWWUSER ||
@@ -1839,8 +1964,14 @@ void Mp3File::getAllFramesV2(FrameCollection& frames)
         if (fieldValue.isValid()) {
           QString description = fieldValue.toString();
           if (!description.isEmpty()) {
-            frame.setInternalName(QString(name) + '\n' + description);
-            frame.setType(Frame::FT_Other);
+            if (description == QLatin1String("CATALOGNUMBER")) {
+              frame.setType(Frame::FT_CatalogNumber);
+            } else if (description == QLatin1String("RELEASECOUNTRY")) {
+              frame.setType(Frame::FT_ReleaseCountry);
+            } else {
+              frame.setExtendedType(Frame::ExtendedType(Frame::FT_Other,
+                  QString::fromLatin1(name) + QLatin1Char('\n') + description));
+            }
           }
         }
       } else if (id3Frame->GetID() == ID3FID_PRIVATE) {
@@ -1853,7 +1984,8 @@ void Mp3File::getAllFramesV2(FrameCollection& frames)
           if ((*it).m_id == Frame::Field::ID_Owner) {
             owner = (*it).m_value.toString();
             if (!owner.isEmpty()) {
-              frame.setInternalName(QString(name) + '\n' + owner);
+              frame.setExtendedType(Frame::ExtendedType(Frame::FT_Other,
+                        QString::fromLatin1(name) + QLatin1Char('\n') + owner));
             }
           } else if ((*it).m_id == Frame::Field::ID_Data) {
             data = (*it).m_value.toByteArray();
@@ -1870,7 +2002,7 @@ void Mp3File::getAllFramesV2(FrameCollection& frames)
         if (fieldValue.isValid()) {
           QString str;
           if (AttributeData(AttributeData::Utf16).toString(fieldValue.toByteArray(), str) &&
-              AttributeData::isHexString(str, 'F', "+")) {
+              AttributeData::isHexString(str, 'F', QLatin1String("+"))) {
             frame.setValue(str);
           }
         }
@@ -1878,7 +2010,7 @@ void Mp3File::getAllFramesV2(FrameCollection& frames)
         QVariant fieldValue = frame.getFieldValue(Frame::Field::ID_Data);
         if (fieldValue.isValid()) {
           QByteArray ba(fieldValue.toByteArray());
-          QString str(ba);
+          QString str(QString::fromLatin1(ba));
           if (ba.size() - str.length() <= 1 &&
               AttributeData::isHexString(str, 'Z')) {
             frame.setValue(str);
@@ -1895,11 +2027,19 @@ void Mp3File::getAllFramesV2(FrameCollection& frames)
       }
       frames.insert(frame);
     }
-#ifdef WIN32
+#ifdef Q_OS_WIN32
     /* allocated in Windows DLL => must be freed in the same DLL */
     ID3TagIterator_Delete(reinterpret_cast<ID3TagIterator*>(iter));
 #else
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdelete-non-virtual-dtor"
+/* Is safe because iterator implementation has default destructor */
+#endif
     delete iter;
+#ifdef GCC_HAS_DIAGNOSTIC_PRAGMA
+#pragma GCC diagnostic pop
+#endif
 #endif
   }
   frames.addMissingStandardFrames();
@@ -1915,8 +2055,8 @@ QStringList Mp3File::getFrameIds() const
   QStringList lst;
   for (int type = Frame::FT_FirstFrame; type <= Frame::FT_LastFrame; ++type) {
     if (type != Frame::FT_Part) {
-      lst.append(QCM_translate(Frame::getNameFromType(
-                                 static_cast<Frame::Type>(type))));
+      lst.append(Frame::ExtendedType(static_cast<Frame::Type>(type), QLatin1String("")).
+                 getTranslatedName());
     }
   }
   for (int i = 0; i <= ID3FID_WWWUSER; ++i) {
@@ -1966,9 +2106,10 @@ TaggedFile* Mp3File::Resolver::createFile(const QString& dn, const QString& fn,
     const QPersistentModelIndex& idx) const
 {
   QString ext = fn.right(4).toLower();
-  if ((ext == ".mp3" || ext == ".mp2" || ext == ".aac")
+  if ((ext == QLatin1String(".mp3") || ext == QLatin1String(".mp2") || ext == QLatin1String(".aac"))
 #ifdef HAVE_TAGLIB
       && ConfigStore::s_miscCfg.m_id3v2Version != MiscConfig::ID3v2_4_0
+      && ConfigStore::s_miscCfg.m_id3v2Version != MiscConfig::ID3v2_3_0_TAGLIB
 #endif
     )
     return new Mp3File(dn, fn, idx);
@@ -1983,7 +2124,7 @@ TaggedFile* Mp3File::Resolver::createFile(const QString& dn, const QString& fn,
  */
 QStringList Mp3File::Resolver::getSupportedFileExtensions() const
 {
-  return QStringList() << ".mp3" << ".mp2" << ".aac";
+  return QStringList() << QLatin1String(".mp3") << QLatin1String(".mp2") << QLatin1String(".aac");
 }
 
 #endif // HAVE_ID3LIB
