@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 12 Sep 2006
  *
- * Copyright (C) 2006-2007  Urs Fleisch
+ * Copyright (C) 2006-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -41,6 +41,11 @@
 /** TagLib version in with 8 bits for major, minor and patch version. */
 #define TAGLIB_VERSION (((TAGLIB_MAJOR_VERSION) << 16) + \
                         ((TAGLIB_MINOR_VERSION) << 8) + (TAGLIB_PATCH_VERSION))
+/* Workaround for the wrong TAGLIB_MINOR_VERSION in TagLib 1.8.0 */
+#if defined HAVE_TAGLIB_ID3V23_SUPPORT && TAGLIB_VERSION == 0x010700
+#undef TAGLIB_VERSION
+#define TAGLIB_VERSION 0x010800
+#endif
 
 /** Convert QString @a s to a TagLib::String. */
 #define QSTRING_TO_TSTRING(s) TagLib::String(s.toUtf8().data(), TagLib::String::UTF8)
@@ -53,6 +58,7 @@ class TagLibFile : public TaggedFile {
 public:
   /** File type resolution. */
   class Resolver : public TaggedFile::Resolver {
+  public:
     /**
      * Create an TagLibFile object if it supports the filename's extension.
      *
@@ -109,6 +115,22 @@ public:
    */
   virtual bool writeTags(bool force, bool* renamed, bool preserve);
 
+  /**
+   * Write tags to file and rename it if necessary.
+   *
+   * @param force    true to force writing even if file was not changed.
+   * @param renamed  will be set to true if the file was renamed,
+   *                 i.e. the file name is no longer valid, else *renamed
+   *                 is left unchanged
+   * @param preserve true to preserve file time stamps
+   * @param id3v2Version ID3v2 version to use, 0 to use existing or preferred,
+   *                     3 to force ID3v2.3.0, 4 to force ID3v2.4.0. Is ignored
+   *                     if TagLib version is less than 1.8.0.
+   *
+   * @return true if ok, false if the file could not be written or renamed.
+   */
+  bool writeTags(bool force, bool* renamed, bool preserve, int id3v2Version);
+
   /**
    * Remove ID3v1 frames.
    *
@@ -550,6 +572,20 @@ private:
    */
   bool makeTagV2Settable();
 
+  /**
+   * Cache technical detail information.
+   */
+  void readAudioProperties();
+
+#if TAGLIB_VERSION >= 0x010800
+  /**
+   * Get tracker name of a module file.
+   *
+   * @return tracker name, null if not found.
+   */
+  QString getTrackerName() const;
+#endif
+
   /**
    * Get the format of a tag.
    *
@@ -580,16 +616,23 @@ private:
   TagLib::FileRef m_fileRef; /**< file reference */
   TagLib::Tag* m_tagV1;      /**< ID3v1 tags */
   TagLib::Tag* m_tagV2;      /**< ID3v2 tags */
+#if TAGLIB_VERSION >= 0x010800
+  int m_id3v2Version;        /**< 3 for ID3v2.3, 4 for ID3v2.4, 0 if none */
+#endif
   bool m_fileRead;           /**< true if file has been read */
 
   /* Cached information updated in readTags() */
   bool m_tagInformationRead;
   bool m_hasTagV1;
   bool m_hasTagV2;
+  bool m_isTagV1Supported;
+  unsigned m_duration;
   TagType m_tagTypeV1;
   TagType m_tagTypeV2;
   QString m_tagFormatV1;
   QString m_tagFormatV2;
+  QString m_fileExtension;
+  DetailInfo m_detailInfo;
 
 #if TAGLIB_VERSION >= 0x010700
   class Pictures : public QList<Frame> {
