@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Oct 2006
  *
- * Copyright (C) 2006-2011  Urs Fleisch
+ * Copyright (C) 2006-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -28,11 +28,12 @@
 #define DISCOGSIMPORTER_H
 
 #include "serverimporter.h"
+#include "kid3api.h"
 
 /**
  * Discogs importer.
  */
-class DiscogsImporter : public ServerImporter
+class KID3_CORE_EXPORT DiscogsImporter : public ServerImporter
 {
 public:
   /**
@@ -99,6 +100,9 @@ public:
    */
   virtual void sendTrackListQuery(
     const ServerImporterConfig* cfg, const QString& cat, const QString& id);
+
+private:
+  QMap<QByteArray, QByteArray> m_discogsHeaders;
 };
 
 #endif
