@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 30 Dec 2008
  *
- * Copyright (C) 2008-2011  Urs Fleisch
+ * Copyright (C) 2008-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -33,15 +33,49 @@
 #include "qtcompatmac.h"
 
 
+/** Time when last request was sent to server */
+#if QT_VERSION >= 0x040700
+QMap<QString, QDateTime> HttpClient::s_lastRequestTime;
+#else
+QMap<QString, QTime> HttpClient::s_lastRequestTime;
+#endif
+/** Minimum interval between two requests to server in ms */
+QMap<QString, int> HttpClient::s_minimumRequestInterval;
+
+/**
+ * Used to initialize the minimum interval for some servers
+ * at static initialization time.
+ *
+ * Rate limit requests to servers, MusicBrainz and Discogs impose a limit of
+ * one request per second
+ * http://musicbrainz.org/doc/XML_Web_Service/Rate_Limiting#Source_IP_address
+ * http://www.discogs.com/developers/accessing.html#rate-limiting
+ */
+static struct MinimumRequestIntervalInitializer {
+  MinimumRequestIntervalInitializer() {
+    HttpClient::s_minimumRequestInterval[QLatin1String("musicbrainz.org")] = 1000;
+    HttpClient::s_minimumRequestInterval[QLatin1String("api.discogs.com")] = 1000;
+    HttpClient::s_minimumRequestInterval[QLatin1String("www.amazon.com")] = 1000;
+    HttpClient::s_minimumRequestInterval[QLatin1String("images.amazon.com")] = 1000;
+    HttpClient::s_minimumRequestInterval[QLatin1String("www.gnudb.org")] = 1000;
+    HttpClient::s_minimumRequestInterval[QLatin1String("gnudb.gnudb.org")] = 1000;
+    HttpClient::s_minimumRequestInterval[QLatin1String("tracktype.org")] = 1000;
+    HttpClient::s_minimumRequestInterval[QLatin1String("api.acoustid.org")] = 1000;
+  }
+} minimumRequestIntervalInitializer;
+
 /**
  * Constructor.
  *
  * @param netMgr  network access manager
  */
 HttpClient::HttpClient(QNetworkAccessManager* netMgr) :
-  QObject(netMgr), m_netMgr(netMgr), m_rcvBodyLen(0)
+  QObject(netMgr), m_netMgr(netMgr), m_rcvBodyLen(0),
+  m_requestTimer(new QTimer(this))
 {
-  setObjectName("HttpClient");
+  setObjectName(QLatin1String("HttpClient"));
+  m_requestTimer->setSingleShot(true);
+  connect(m_requestTimer, SIGNAL(timeout()), this, SLOT(delayedSendRequest()));
 }
 
 /**
@@ -72,7 +106,7 @@ void HttpClient::networkReplyFinished()
     QString msg(i18n("Ready."));
     if (reply->error() != QNetworkReply::NoError) {
       msg = i18n("Error");
-      msg += ": ";
+      msg += QLatin1String(": ");
       msg += reply->errorString();
     }
     emitProgress(msg, data.size(), data.size());
@@ -110,10 +144,36 @@ void HttpClient::networkReplyError(QNetworkReply::NetworkError)
  * @param server host name
  * @param path   path of the URL
  */
-void HttpClient::sendRequest(const QString& server, const QString& path)
+void HttpClient::sendRequest(const QString& server, const QString& path,
+                             const RawHeaderMap& headers)
 {
+  QString host(server);
+  if (host.endsWith(QLatin1String(":80"))) {
+    host.chop(3);
+  }
+  qint64 msSinceLastRequest;
+  int minimumRequestInterval;
+#if QT_VERSION >= 0x040700
+  QDateTime now = QDateTime::currentDateTime();
+  QDateTime lastRequestTime = s_lastRequestTime.value(host);
+#else
+  QTime now = QTime::currentTime();
+  QTime lastRequestTime = s_lastRequestTime.value(host);
+#endif
+  if (lastRequestTime.isValid() &&
+      (minimumRequestInterval = s_minimumRequestInterval.value(host)) > 0 &&
+      (msSinceLastRequest = lastRequestTime.msecsTo(now)) <
+      minimumRequestInterval) {
+    // Delay request to comply with minimum interval
+    m_delayedSendRequestContext.server = server;
+    m_delayedSendRequestContext.path = path;
+    m_delayedSendRequestContext.headers = headers;
+    m_requestTimer->start(minimumRequestInterval - msSinceLastRequest);
+    return;
+  }
+
   m_rcvBodyLen = 0;
-  m_rcvBodyType = "";
+  m_rcvBodyType = QLatin1String("");
   QString proxy, username, password;
   int proxyPort = 0;
   QNetworkProxy::ProxyType proxyType = QNetworkProxy::NoProxy;
@@ -128,13 +188,19 @@ void HttpClient::sendRequest(const QString& server, const QString& path)
   m_netMgr->setProxy(QNetworkProxy(proxyType, proxy, proxyPort,
                                    username, password));
 
-  QString host(server);
-  if (host.endsWith(":80")) {
-    host.chop(3);
-  }
   QUrl url;
-  url.setEncodedUrl(("http://" + host + path).toAscii());
+#if QT_VERSION >= 0x050000
+  url.setUrl(QLatin1String("http://") + host + path);
+#else
+  url.setEncodedUrl((QLatin1String("http://") + host + path).toAscii());
+#endif
   QNetworkRequest request(url);
+  for (RawHeaderMap::const_iterator it =
+         headers.constBegin();
+       it != headers.constEnd();
+       ++it) {
+    request.setRawHeader(it.key(), it.value());
+  }
   QNetworkReply* reply = m_netMgr->get(request);
   m_reply = reply;
   connect(reply, SIGNAL(finished()),
@@ -143,9 +209,20 @@ void HttpClient::sendRequest(const QString& server, const QString& path)
           this, SLOT(networkReplyProgress(qint64,qint64)));
   connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
           this, SLOT(networkReplyError(QNetworkReply::NetworkError)));
+  s_lastRequestTime[host] = now;
   emitProgress(i18n("Request sent..."), 0, 0);
 }
 
+/**
+ * Called to start delayed sendRequest().
+ */
+void HttpClient::delayedSendRequest()
+{
+  sendRequest(m_delayedSendRequestContext.server,
+              m_delayedSendRequestContext.path,
+              m_delayedSendRequestContext.headers);
+}
+
 /**
  * Abort request.
  */
@@ -178,7 +255,7 @@ void HttpClient::emitProgress(const QString& text, int step, int totalSteps)
 void HttpClient::splitNamePort(const QString& namePort,
                                  QString& name, int& port)
 {
-  int colPos = namePort.lastIndexOf(':');
+  int colPos = namePort.lastIndexOf(QLatin1Char(':'));
   if (colPos >= 0) {
     bool ok;
     port = namePort.mid(colPos + 1).toInt(&ok);
