@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 30 Dec 2008
  *
- * Copyright (C) 2008-2011  Urs Fleisch
+ * Copyright (C) 2008-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -31,6 +31,9 @@
 #include <QString>
 #include <QNetworkReply>
 #include <QPointer>
+#include <QMap>
+#include <QDateTime>
+#include <QTimer>
 
 class QByteArray;
 class QNetworkAccessManager;
@@ -42,6 +45,9 @@ class HttpClient : public QObject {
 Q_OBJECT
 
 public:
+  /** Name-value map for raw HTTP headers. */
+  typedef QMap<QByteArray, QByteArray> RawHeaderMap;
+
   /**
    * Constructor.
    *
@@ -59,8 +65,10 @@ public:
    *
    * @param server host name
    * @param path   path of the URL
+   * @param headers optional raw headers to send
    */
-  void sendRequest(const QString& server, const QString& path);
+  void sendRequest(const QString& server, const QString& path,
+                   const RawHeaderMap& headers = RawHeaderMap());
 
   /**
    * Abort request.
@@ -123,6 +131,11 @@ private slots:
    */
   void networkReplyError(QNetworkReply::NetworkError);
 
+  /**
+   * Called to start delayed sendRequest().
+   */
+  void delayedSendRequest();
+
 private:
   /**
    * Emit a progress signal with step/total steps.
@@ -163,6 +176,25 @@ private:
   unsigned long m_rcvBodyLen;
   /** content type */
   QString m_rcvBodyType;
+  /** Timer used to delay requests */
+  QTimer* m_requestTimer;
+  /** Context for delayedSendRequest() */
+  struct {
+    QString server;
+    QString path;
+    RawHeaderMap headers;
+  } m_delayedSendRequestContext;
+
+  friend struct MinimumRequestIntervalInitializer;
+
+  /** Time when last request was sent to server */
+#if QT_VERSION >= 0x040700
+  static QMap<QString, QDateTime> s_lastRequestTime;
+#else
+  static QMap<QString, QTime> s_lastRequestTime;
+#endif
+  /** Minimum interval between two requests to server in ms */
+  static QMap<QString, int> s_minimumRequestInterval;
 };
 
 #endif
