@@ -39,7 +39,7 @@ class TrackDataModel;
 /**
  * Generic baseclass to import from an external source.
  */
-class ServerImporter : public ImportClient
+class KID3_CORE_EXPORT ServerImporter : public ImportClient
 {
   Q_OBJECT
 
@@ -110,6 +110,20 @@ public:
    */
   void clear();
 
+  /**
+   * Get standard tags option.
+   *
+   * @return true if standard tags are enabled.
+   */
+  bool getStandardTags() const { return m_standardTagsEnabled; }
+
+  /**
+   * Set standard tags option.
+   *
+   * @param enable true if standard tags are enabled
+   */
+  void setStandardTags(bool enable) { m_standardTagsEnabled = enable; }
+
   /**
    * Get additional tags option.
    *
@@ -161,6 +175,7 @@ protected:
   TrackDataModel* m_trackDataModel; /**< model with tracks to import */
 
 private:
+  bool m_standardTagsEnabled;
   bool m_additionalTagsEnabled;
   bool m_coverArtEnabled;
 };
@@ -194,6 +209,14 @@ public:
    * @return ID.
    */
   QString getId() const { return data(Qt::UserRole + 2).toString(); }
+
+#ifndef QT_NO_DEBUG
+  /**
+   * Dump an album list.
+   * @param albumModel album list model
+   */
+  static void dumpAlbumList(const QStandardItemModel* albumModel);
+#endif
 };
 
 #endif
