@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Jul 2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -31,6 +31,7 @@
 #include <QUrl>
 #include <QTextStream>
 #include <QNetworkAccessManager>
+#include <QTimer>
 #ifdef CONFIG_USE_KDE
 #include <kapplication.h>
 #else
@@ -42,6 +43,7 @@
 #include "scriptinterface.h"
 #endif
 #include "fileproxymodel.h"
+#include "fileproxymodeliterator.h"
 #include "dirproxymodel.h"
 #include "modeliterator.h"
 #include "trackdatamodel.h"
@@ -60,11 +62,13 @@
 #include "musicbrainzreleaseimporter.h"
 #include "discogsimporter.h"
 #include "amazonimporter.h"
+#include "batchimportprofile.h"
+#include "batchimporter.h"
 #include "qtcompatmac.h"
 #ifdef HAVE_CHROMAPRINT
 #include "musicbrainzclient.h"
 #endif
-#ifdef HAVE_PHONON
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 #include "audioplayer.h"
 #endif
 #ifdef HAVE_ID3LIB
@@ -93,6 +97,7 @@ QString Kid3Application::s_dirName;
 Kid3Application::Kid3Application(QObject* parent) : QObject(parent),
   m_fileSystemModel(new QFileSystemModel(this)),
   m_fileProxyModel(new FileProxyModel(this)),
+  m_fileProxyModelIterator(new FileProxyModelIterator(m_fileProxyModel)),
   m_dirProxyModel(new DirProxyModel(this)),
   m_fileSelectionModel(new QItemSelectionModel(m_fileProxyModel, this)),
   m_trackDataModel(new TrackDataModel(this)),
@@ -106,13 +111,14 @@ Kid3Application::Kid3Application(QObject* parent) : QObject(parent),
   m_downloadClient(new DownloadClient(m_netMgr)),
   m_textExporter(new TextExporter(this)),
   m_dirRenamer(new DirRenamer(this)),
-#ifdef HAVE_PHONON
+  m_batchImporter(new BatchImporter(m_netMgr)),
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   m_player(0),
 #endif
   m_downloadImageDest(ImageForSelectedFiles),
   m_musicBrainzClient(0)
 {
-  setObjectName("Kid3Application");
+  setObjectName(QLatin1String("Kid3Application"));
   m_fileProxyModel->setSourceModel(m_fileSystemModel);
   m_dirProxyModel->setSourceModel(m_fileSystemModel);
 
@@ -134,18 +140,19 @@ Kid3Application::Kid3Application(QObject* parent) : QObject(parent),
 #ifdef HAVE_CHROMAPRINT
   m_musicBrainzClient = new MusicBrainzClient(m_netMgr, m_trackDataModel);
 #endif
+  m_batchImporter->setImporters(m_importers, m_trackDataModel);
 
 #ifdef HAVE_QTDBUS
   if (QDBusConnection::sessionBus().isConnected()) {
-    QString serviceName("net.sourceforge.kid3");
+    QString serviceName(QLatin1String("net.sourceforge.kid3"));
     QDBusConnection::sessionBus().registerService(serviceName);
 #ifndef CONFIG_USE_KDE
-    serviceName += '-';
+    serviceName += QLatin1Char('-');
     serviceName += QString::number(::getpid());
     QDBusConnection::sessionBus().registerService(serviceName);
 #endif
     new ScriptInterface(this);
-    if (!QDBusConnection::sessionBus().registerObject("/Kid3", this)) {
+    if (!QDBusConnection::sessionBus().registerObject(QLatin1String("/Kid3"), this)) {
       qWarning("Registering D-Bus object failed");
     }
   } else {
@@ -185,7 +192,7 @@ void Kid3Application::initFileTypes()
 #endif
 }
 
-#ifdef HAVE_PHONON
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 /**
  * Get audio player.
  * @return audio player.
@@ -213,6 +220,10 @@ Kid3Settings* Kid3Application::getSettings() const
  */
 void Kid3Application::saveConfig()
 {
+  if (ConfigStore::s_miscCfg.m_loadLastOpenedFile) {
+    ConfigStore::s_miscCfg.m_lastOpenedFile =
+        m_fileProxyModel->filePath(currentOrRootIndex());
+  }
   m_configStore->writeToConfig();
   m_configStore->getSettings()->sync();
 }
@@ -227,11 +238,13 @@ void Kid3Application::readConfig()
     ConfigStore::s_miscCfg.m_nameFilter = createFilterString();
   }
   setTextEncodings();
-  if (ConfigStore::s_freedbCfg.m_server == "freedb2.org:80") {
-    ConfigStore::s_freedbCfg.m_server = "www.gnudb.org:80"; // replace old default
+  FrameCollection::setQuickAccessFrames(
+        ConfigStore::s_miscCfg.m_quickAccessFrames);
+  if (ConfigStore::s_freedbCfg.m_server == QLatin1String("freedb2.org:80")) {
+    ConfigStore::s_freedbCfg.m_server = QLatin1String("www.gnudb.org:80"); // replace old default
   }
-  if (ConfigStore::s_trackTypeCfg.m_server == "gnudb.gnudb.org:80") {
-    ConfigStore::s_trackTypeCfg.m_server = "tracktype.org:80"; // replace default
+  if (ConfigStore::s_trackTypeCfg.m_server == QLatin1String("gnudb.gnudb.org:80")) {
+    ConfigStore::s_trackTypeCfg.m_server = QLatin1String("tracktype.org:80"); // replace default
   }
 }
 
@@ -262,7 +275,7 @@ bool Kid3Application::openDirectory(QString dir, bool fileCheck)
   }
 
   QStringList nameFilters(ConfigStore::s_miscCfg.getNameFilterPatterns().
-                          split(' '));
+                          split(QLatin1Char(' ')));
   m_fileProxyModel->setNameFilters(nameFilters);
   m_fileSystemModel->setFilter(QDir::AllEntries | QDir::AllDirs);
   QModelIndex rootIndex = m_fileSystemModel->setRootPath(dir);
@@ -449,7 +462,7 @@ bool Kid3Application::writePlaylist(const PlaylistConfig& cfg)
           if (plItem.getDirName().startsWith(selectedDirPrefix)) {
             inSelectedDir = true;
           } else {
-            selectedDirPrefix = "";
+            selectedDirPrefix = QLatin1String("");
           }
         }
         if (inSelectedDir || noSelection || selectModel->isSelected(index)) {
@@ -464,7 +477,7 @@ bool Kid3Application::writePlaylist(const PlaylistConfig& cfg)
           if (dirName.startsWith(selectedDirPrefix)) {
             inSelectedDir = true;
           } else {
-            selectedDirPrefix = "";
+            selectedDirPrefix = QLatin1String("");
           }
         }
         if (inSelectedDir || noSelection || selectModel->isSelected(index)) {
@@ -573,17 +586,88 @@ void Kid3Application::trackDataModelToFiles(TrackData::TagVersion tagVersion)
  */
 void Kid3Application::downloadImage(const QString& url, DownloadImageDestination dest)
 {
-  QString imgurl(getImageUrl(url));
+  QString imgurl(DownloadClient::getImageUrl(url));
   if (!imgurl.isEmpty()) {
-    int hostPos = imgurl.indexOf("://");
-    if (hostPos > 0) {
-      int pathPos = imgurl.indexOf("/", hostPos + 3);
-      if (pathPos > hostPos) {
-        m_downloadImageDest = dest;
-        m_downloadClient->startDownload(
-          imgurl.mid(hostPos + 3, pathPos - hostPos - 3),
-          imgurl.mid(pathPos));
+    m_downloadImageDest = dest;
+    m_downloadClient->startDownload(imgurl);
+  }
+}
+
+/**
+ * Perform a batch import for the selected directories.
+ * @param profile batch import profile
+ * @param tagVersion import destination tag versions
+ */
+void Kid3Application::batchImport(const BatchImportProfile& profile,
+                                  TrackData::TagVersion tagVersion)
+{
+  m_batchImportProfile = &profile;
+  m_batchImportTagVersion = tagVersion;
+  m_batchImportAlbums.clear();
+  m_batchImportTrackDataList.clear();
+  m_lastProcessedDirName.clear();
+  m_batchImporter->clearAborted();
+  m_batchImporter->emitReportImportEvent(BatchImportProfile::ReadingDirectory,
+                                         QString());
+  // If no directories are selected, process files of the current directory.
+  QList<QPersistentModelIndex> indexes;
+  foreach (const QModelIndex& index, m_fileSelectionModel->selectedIndexes()) {
+    if (m_fileProxyModel->isDir(index)) {
+      indexes.append(index);
+    }
+  }
+  if (indexes.isEmpty()) {
+    indexes.append(m_fileProxyModelRootIndex);
+  }
+
+  connect(m_fileProxyModelIterator, SIGNAL(nextReady(QPersistentModelIndex)),
+          this, SLOT(batchImportNextFile(QPersistentModelIndex)));
+  m_fileProxyModelIterator->start(indexes);
+}
+
+/**
+ * Apply single file to batch import.
+ *
+ * @param index index of file in file proxy model
+ */
+void Kid3Application::batchImportNextFile(const QPersistentModelIndex& index)
+{
+  bool terminated = !index.isValid();
+  if (!terminated) {
+    if (TaggedFile* taggedFile = FileProxyModel::getTaggedFileOfIndex(index)) {
+      taggedFile->readTags(false);
+#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
+      taggedFile = FileProxyModel::readWithTagLibIfId3V24(taggedFile);
+#endif
+      if (taggedFile->getDirname() != m_lastProcessedDirName) {
+        m_lastProcessedDirName = taggedFile->getDirname();
+        if (!m_batchImportTrackDataList.isEmpty()) {
+          m_batchImportAlbums.append(m_batchImportTrackDataList);
+        }
+        m_batchImportTrackDataList.clear();
+        if (m_batchImporter->isAborted()) {
+          terminated = true;
+        }
       }
+      m_batchImportTrackDataList.append(ImportTrackData(*taggedFile,
+                                                      m_batchImportTagVersion));
+    }
+  }
+  if (terminated) {
+    m_fileProxyModelIterator->abort();
+    disconnect(m_fileProxyModelIterator,
+               SIGNAL(nextReady(QPersistentModelIndex)),
+               this, SLOT(batchImportNextFile(QPersistentModelIndex)));
+    if (!m_batchImporter->isAborted()) {
+      if (!m_batchImportTrackDataList.isEmpty()) {
+        m_batchImportAlbums.append(m_batchImportTrackDataList);
+      }
+      m_batchImporter->setFrameFilter(
+            (m_batchImportTagVersion & TrackData::TagV1) != 0
+          ? frameModelV1()->getEnabledFrameFilter(true)
+          : frameModelV2()->getEnabledFrameFilter(true));
+      m_batchImporter->start(m_batchImportAlbums, *m_batchImportProfile,
+                             m_batchImportTagVersion);
     }
   }
 }
@@ -609,9 +693,7 @@ void Kid3Application::formatFileNameIfEnabled(TaggedFile* taggedFile) const
  */
 void Kid3Application::formatFramesIfEnabled(FrameCollection& frames) const
 {
-  if (ConfigStore::s_id3FormatCfg.m_formatWhileEditing) {
-    ConfigStore::s_id3FormatCfg.formatFrames(frames);
-  }
+  ConfigStore::s_id3FormatCfg.formatFramesIfEnabled(frames);
 }
 
 /**
@@ -624,13 +706,13 @@ QString Kid3Application::getFileNameOfSelectedFile()
   QModelIndex index = getFileSelectionModel()->currentIndex();
   QString dirname = FileProxyModel::getPathIfIndexOfDir(index);
   if (!dirname.isNull()) {
-    if (!dirname.endsWith('/')) dirname += '/';
+    if (!dirname.endsWith(QLatin1Char('/'))) dirname += QLatin1Char('/');
     return dirname;
   } else if (TaggedFile* taggedFile =
              FileProxyModel::getTaggedFileOfIndex(index)) {
     return taggedFile->getAbsFilename();
   }
-  return "";
+  return QLatin1String("");
 }
 
 /**
@@ -694,6 +776,68 @@ void Kid3Application::applyId3Format()
   emit selectedFilesUpdated();
 }
 
+/**
+ * Apply text encoding.
+ * Set the text encoding selected in the settings Tags/ID3v2/Text encoding
+ * for all selected files which have an ID3v2 tag.
+ */
+void Kid3Application::applyTextEncoding()
+{
+  emit fileSelectionUpdateRequested();
+  Frame::Field::TextEncoding encoding;
+  switch (ConfigStore::s_miscCfg.m_textEncoding) {
+  case MiscConfig::TE_UTF16:
+    encoding = Frame::Field::TE_UTF16;
+    break;
+  case MiscConfig::TE_UTF8:
+    encoding = Frame::Field::TE_UTF8;
+    break;
+  case MiscConfig::TE_ISO8859_1:
+  default:
+    encoding = Frame::Field::TE_ISO8859_1;
+  }
+  FrameCollection frames;
+  SelectedTaggedFileIterator it(getRootIndex(),
+                                getFileSelectionModel(),
+                                true);
+  while (it.hasNext()) {
+    TaggedFile* taggedFile = it.next();
+    taggedFile->readTags(false);
+    taggedFile->getAllFramesV2(frames);
+    for (FrameCollection::iterator frameIt = frames.begin();
+         frameIt != frames.end();
+         ++frameIt) {
+      Frame& frame = const_cast<Frame&>(*frameIt);
+      Frame::Field::TextEncoding enc = encoding;
+      if (taggedFile->getTagFormatV2() == QLatin1String("ID3v2.3.0")) {
+#ifdef HAVE_TAGLIB
+        // TagLib sets the ID3v2.3.0 frame containing the date internally with
+        // ISO-8859-1, so the encoding cannot be set for such frames.
+        if (dynamic_cast<TagLibFile*>(taggedFile) != 0 &&
+            frame.getType() == Frame::FT_Date &&
+            enc != Frame::Field::TE_ISO8859_1)
+          continue;
+#endif
+        // Only ISO-8859-1 and UTF16 are allowed for ID3v2.3.0.
+        if (enc != Frame::Field::TE_ISO8859_1)
+          enc = Frame::Field::TE_UTF16;
+      }
+      Frame::FieldList& fields = frame.fieldList();
+      for (Frame::FieldList::iterator fieldIt = fields.begin();
+           fieldIt != fields.end();
+           ++fieldIt) {
+        if (fieldIt->m_id == Frame::Field::ID_TextEnc &&
+            fieldIt->m_value.toInt() != enc) {
+          fieldIt->m_value = enc;
+          frame.setValueChanged();
+        }
+      }
+    }
+    taggedFile->setFramesV2(frames);
+  }
+  emit selectedFilesUpdated();
+}
+
 /**
  * Copy tags 1 into copy buffer.
  */
@@ -981,34 +1125,36 @@ void Kid3Application::editFrame(IFrameEditor* frameEditor)
       emit frameModified(taggedFile);
     } else if (!taggedFile) {
       // multiple files selected
-      bool firstFile = true;
-      QString name;
-      SelectedTaggedFileIterator tfit(getRootIndex(),
-                                      getFileSelectionModel(),
-                                      false);
-      while (tfit.hasNext()) {
-        TaggedFile* currentFile = tfit.next();
-        if (firstFile) {
-          firstFile = false;
-          taggedFile = currentFile;
-          m_framelist->setTaggedFile(taggedFile);
-          name = m_framelist->getSelectedName();
-          if (name.isEmpty() ||
-              !frameEditor->editFrameOfTaggedFile(&frame, taggedFile)) {
-            break;
-          }
+      // Get the first selected file by using a temporary iterator.
+      taggedFile = SelectedTaggedFileIterator(
+            getRootIndex(), getFileSelectionModel(), false).peekNext();
+      if (taggedFile) {
+        m_framelist->setTaggedFile(taggedFile);
+        QString name = m_framelist->getSelectedName();
+        if (!name.isEmpty() &&
+            frameEditor->editFrameOfTaggedFile(&frame, taggedFile)) {
           m_framelist->setFrame(frame);
-        }
-        FrameCollection frames;
-        currentFile->getAllFramesV2(frames);
-        for (FrameCollection::const_iterator it = frames.begin();
-             it != frames.end();
-             ++it) {
-          if (it->getName() == name) {
-            currentFile->deleteFrameV2(*it);
-            m_framelist->setTaggedFile(currentFile);
-            m_framelist->pasteFrame();
-            break;
+
+          // Start a new iteration because the file selection model can be
+          // changed by editFrameOfTaggedFile(), e.g. when a file is exported
+          // from a picture frame.
+          SelectedTaggedFileIterator tfit(getRootIndex(),
+                                          getFileSelectionModel(),
+                                          false);
+          while (tfit.hasNext()) {
+            TaggedFile* currentFile = tfit.next();
+            FrameCollection frames;
+            currentFile->getAllFramesV2(frames);
+            for (FrameCollection::const_iterator it = frames.begin();
+                 it != frames.end();
+                 ++it) {
+              if (it->getName() == name) {
+                currentFile->deleteFrameV2(*it);
+                m_framelist->setTaggedFile(currentFile);
+                m_framelist->pasteFrame();
+                break;
+              }
+            }
           }
         }
       }
@@ -1167,7 +1313,7 @@ void Kid3Application::addFrame(const Frame* frame, IFrameEditor* frameEditor)
  */
 void Kid3Application::editOrAddPicture(IFrameEditor* frameEditor)
 {
-  if (m_framelist->selectByName("Picture")) {
+  if (m_framelist->selectByName(QLatin1String("Picture"))) {
     editFrame(frameEditor);
   } else {
     PictureFrame frame;
@@ -1182,24 +1328,24 @@ void Kid3Application::editOrAddPicture(IFrameEditor* frameEditor)
  */
 void Kid3Application::openDrop(QString txt)
 {
-  int lfPos = txt.indexOf('\n');
+  int lfPos = txt.indexOf(QLatin1Char('\n'));
   if (lfPos > 0 && lfPos < (int)txt.length() - 1) {
     txt.truncate(lfPos + 1);
   }
   QUrl url(txt);
   if (!url.path().isEmpty()) {
-#if defined _WIN32 || defined WIN32
+#ifdef Q_OS_WIN32
     QString dir = url.toString();
 #else
     QString dir = url.path().trimmed();
 #endif
-    if (dir.endsWith(".jpg", Qt::CaseInsensitive) ||
-        dir.endsWith(".jpeg", Qt::CaseInsensitive) ||
-        dir.endsWith(".png", Qt::CaseInsensitive)) {
+    if (dir.endsWith(QLatin1String(".jpg"), Qt::CaseInsensitive) ||
+        dir.endsWith(QLatin1String(".jpeg"), Qt::CaseInsensitive) ||
+        dir.endsWith(QLatin1String(".png"), Qt::CaseInsensitive)) {
       PictureFrame frame;
       if (PictureFrame::setDataFromFile(frame, dir)) {
         QString fileName(dir);
-        int slashPos = fileName.lastIndexOf('/');
+        int slashPos = fileName.lastIndexOf(QLatin1Char('/'));
         if (slashPos != -1) {
           fileName = fileName.mid(slashPos + 1);
         }
@@ -1251,7 +1397,7 @@ void Kid3Application::dropUrl(const QString& txt)
 void Kid3Application::imageDownloaded(const QByteArray& data,
                               const QString& mimeType, const QString& url)
 {
-  if (mimeType.startsWith("image")) {
+  if (mimeType.startsWith(QLatin1String("image"))) {
     PictureFrame frame(data, url, PictureFrame::PT_CoverFront, mimeType);
     if (getDownloadImageDestination() == ImageForAllFilesInDirectory) {
       TaggedFileOfDirectoryIterator it(currentOrRootIndex());
@@ -1415,24 +1561,6 @@ void Kid3Application::fetchDirectory(const QModelIndex& index)
   }
 }
 
-/**
- * Fetch entries for all directories if not already fetched.
- * This works like FileList::expandAll(), but without expanding tree view
- * items and independent of the GUI. The processing is done in the background
- * by QFileSystemModel, so the fetched items are not immediately available
- * after calling this method.
- */
-void Kid3Application::fetchAllDirectories()
-{
-  ModelIterator it(getRootIndex());
-  while (it.hasNext()) {
-    QModelIndex index(it.next());
-    if (m_fileProxyModel->canFetchMore(index)) {
-      m_fileProxyModel->fetchMore(index);
-    }
-  }
-}
-
 /**
  * Process change of selection.
  * The GUI is signaled to update the current selection and the controls.
@@ -1448,32 +1576,51 @@ void Kid3Application::fileSelected()
  */
 void Kid3Application::scheduleRenameActions()
 {
-  getDirRenamer()->clearActions();
+  m_dirRenamer->clearActions();
+  m_dirRenamer->clearAborted();
   // If directories are selected, rename them, else process files of the
   // current directory.
-  AbstractTaggedFileIterator* it =
-      new TaggedFileOfSelectedDirectoriesIterator(m_fileSelectionModel);
-  if (!it->hasNext()) {
-    delete it;
-    it = new TaggedFileIterator(getRootIndex());
-  }
-  while (it->hasNext()) {
-    TaggedFile* taggedFile = it->next();
-    taggedFile->readTags(false);
-#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
-    taggedFile = FileProxyModel::readWithTagLibIfId3V24(taggedFile);
-#endif
-    getDirRenamer()->scheduleAction(taggedFile);
-#ifdef CONFIG_USE_KDE
-    kapp->processEvents();
-#else
-    qApp->processEvents();
-#endif
-    if (getDirRenamer()->getAbortFlag()) {
-      break;
+  QList<QPersistentModelIndex> indexes;
+  foreach (const QModelIndex& index, m_fileSelectionModel->selectedIndexes()) {
+    if (m_fileProxyModel->isDir(index)) {
+      indexes.append(index);
     }
   }
-  delete it;
+  if (indexes.isEmpty()) {
+    indexes.append(m_fileProxyModelRootIndex);
+  }
+
+  connect(m_fileProxyModelIterator, SIGNAL(nextReady(QPersistentModelIndex)),
+          this, SLOT(scheduleNextRenameAction(QPersistentModelIndex)));
+  m_fileProxyModelIterator->start(indexes);
+}
+
+/**
+ * Schedule rename action for a file.
+ *
+ * @param index index of file in file proxy model
+ */
+void Kid3Application::scheduleNextRenameAction(const QPersistentModelIndex& index)
+{
+  bool terminated = !index.isValid();
+  if (!terminated) {
+    if (TaggedFile* taggedFile = FileProxyModel::getTaggedFileOfIndex(index)) {
+      taggedFile->readTags(false);
+      taggedFile->readTags(false);
+#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
+      taggedFile = FileProxyModel::readWithTagLibIfId3V24(taggedFile);
+#endif
+      m_dirRenamer->scheduleAction(taggedFile);
+      if (m_dirRenamer->isAborted()) {
+        terminated = true;
+      }
+    }
+  }
+  if (terminated) {
+    m_fileProxyModelIterator->abort();
+    disconnect(m_fileProxyModelIterator, SIGNAL(nextReady(QPersistentModelIndex)),
+               this, SLOT(scheduleNextRenameAction(QPersistentModelIndex)));
+  }
 }
 
 /**
@@ -1485,44 +1632,69 @@ void Kid3Application::applyFilter(FileFilter& fileFilter)
 {
   m_fileProxyModel->disableFilteringOutIndexes();
   setFiltered(false);
-  fileFilter.clearAbortFlag();
+  fileFilter.clearAborted();
+  emit fileFiltered(FileFilter::Started, QString());
 
-  bool ok = true;
-  unsigned numFiles = 0;
-  TaggedFileIterator it(m_fileProxyModelRootIndex);
-  while (it.hasNext()) {
-    TaggedFile* taggedFile = it.next();
+  m_fileFilter = &fileFilter;
+  m_lastProcessedDirName.clear();
+  connect(m_fileProxyModelIterator, SIGNAL(nextReady(QPersistentModelIndex)),
+          this, SLOT(filterNextFile(QPersistentModelIndex)));
+  m_fileProxyModelIterator->start(m_fileProxyModelRootIndex);
+}
 
-    taggedFile->readTags(false);
+/**
+ * Apply single file to file filter.
+ *
+ * @param index index of file in file proxy model
+ */
+void Kid3Application::filterNextFile(const QPersistentModelIndex& index)
+{
+  if (!m_fileFilter)
+    return;
+
+  bool terminated = !index.isValid();
+  if (!terminated) {
+    if (TaggedFile* taggedFile = FileProxyModel::getTaggedFileOfIndex(index)) {
+      taggedFile->readTags(false);
 #if defined HAVE_ID3LIB && defined HAVE_TAGLIB
-    taggedFile = FileProxyModel::readWithTagLibIfId3V24(taggedFile);
+      taggedFile = FileProxyModel::readWithTagLibIfId3V24(taggedFile);
 #endif
-    bool pass = fileFilter.filter(*taggedFile, &ok);
-    if (!ok) {
-      emit fileFiltered(FileFilter::ParseError, QString());
-      break;
-    }
-    emit fileFiltered(
-          pass ? FileFilter::FilePassed : FileFilter::FileFilteredOut,
-          taggedFile->getFilename());
-    if (!pass)
-      m_fileProxyModel->filterOutIndex(taggedFile->getIndex());
+      if (taggedFile->getDirname() != m_lastProcessedDirName) {
+        m_lastProcessedDirName = taggedFile->getDirname();
+        emit fileFiltered(FileFilter::Directory, m_lastProcessedDirName);
+      }
+      bool ok;
+      bool pass = m_fileFilter->filter(*taggedFile, &ok);
+      if (ok) {
+        emit fileFiltered(
+              pass ? FileFilter::FilePassed : FileFilter::FileFilteredOut,
+              taggedFile->getFilename());
+        if (!pass)
+          m_fileProxyModel->filterOutIndex(taggedFile->getIndex());
+      } else {
+        emit fileFiltered(FileFilter::ParseError, QString());
+        terminated = true;
+      }
 
-    if (++numFiles == 8) {
-      numFiles = 0;
-#ifdef CONFIG_USE_KDE
-      kapp->processEvents();
-#else
-      qApp->processEvents();
-#endif
-      if (fileFilter.getAbortFlag())
-        break;
+      if (m_fileFilter->isAborted()) {
+        terminated = true;
+        emit fileFiltered(FileFilter::Aborted, QString());
+      }
     }
   }
+  if (terminated) {
+    if (!m_fileFilter->isAborted()) {
+      emit fileFiltered(FileFilter::Finished, QString());
+    }
 
-  m_fileProxyModel->applyFilteringOutIndexes();
-  setFiltered(!fileFilter.isEmptyFilterExpression());
-  emit fileModified();
+    m_fileProxyModelIterator->abort();
+    m_fileProxyModel->applyFilteringOutIndexes();
+    setFiltered(!m_fileFilter->isEmptyFilterExpression());
+    emit fileModified();
+
+    disconnect(m_fileProxyModelIterator, SIGNAL(nextReady(QPersistentModelIndex)),
+               this, SLOT(filterNextFile(QPersistentModelIndex)));
+  }
 }
 
 /**
@@ -1634,7 +1806,7 @@ void Kid3Application::numberTracks(int nr, int total,
       }
       FrameCollection frames;
       taggedFile->getAllFramesV2(frames);
-      Frame frame(Frame::FT_Track, "", "", -1);
+      Frame frame(Frame::FT_Track, QLatin1String(""), QLatin1String(""), -1);
       FrameCollection::const_iterator it = frames.find(frame);
       if (it != frames.end()) {
         frame = *it;
@@ -1644,7 +1816,7 @@ void Kid3Application::numberTracks(int nr, int total,
         }
       } else {
         frame.setValue(value);
-        frame.setInternalName(Frame::getNameFromType(Frame::FT_Track));
+        frame.setExtendedType(Frame::ExtendedType(Frame::FT_Track));
         taggedFile->setFrameV2(frame);
       }
     }
@@ -1654,7 +1826,7 @@ void Kid3Application::numberTracks(int nr, int total,
   delete it;
 }
 
-#ifdef HAVE_PHONON
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 /**
  * Play audio file.
  */
@@ -1704,50 +1876,6 @@ int Kid3Application::getTotalNumberOfTracksInDir()
   return 0;
 }
 
-/**
- * Get the URL of an image file.
- * The input URL is transformed using the match picture URL table to
- * get the URL of an image file.
- *
- * @param url URL from image drag
- *
- * @return URL of image file, empty if no image URL found.
- */
-QString Kid3Application::getImageUrl(const QString& url)
-{
-  QString imgurl;
-  if (url.startsWith("http://")) {
-    if (url.endsWith(".jpg", Qt::CaseInsensitive) ||
-        url.endsWith(".jpeg", Qt::CaseInsensitive) ||
-        url.endsWith(".png", Qt::CaseInsensitive)) {
-      imgurl = url;
-    }
-    else {
-      for (QMap<QString, QString>::ConstIterator it =
-             ConfigStore::s_genCfg.m_matchPictureUrlMap.begin();
-           it != ConfigStore::s_genCfg.m_matchPictureUrlMap.end();
-           ++it) {
-        QRegExp re(it.key());
-        if (re.exactMatch(url)) {
-          QString pictureUrl(url);
-          imgurl = url;
-          imgurl.replace(re, *it);
-          if (imgurl.indexOf("%25") != -1) {
-            // double URL encoded: first decode
-            imgurl = QUrl::fromPercentEncoding(imgurl.toUtf8());
-          }
-          if (imgurl.indexOf("%2F") != -1) {
-            // URL encoded: decode
-            imgurl = QUrl::fromPercentEncoding(imgurl.toUtf8());
-          }
-          break;
-        }
-      }
-    }
-  }
-  return imgurl;
-}
-
 /**
  * Create a filter string for the file dialog.
  * The filter string contains entries for all supported types.
@@ -1762,37 +1890,37 @@ QString Kid3Application::createFilterString() const
        it != extensions.end();
        ++it) {
     QString text = (*it).mid(1).toUpper();
-    QString pattern = '*' + *it;
+    QString pattern = QLatin1Char('*') + *it;
     if (!allPatterns.isEmpty()) {
-      allPatterns += ' ';
+      allPatterns += QLatin1Char(' ');
     }
     allPatterns += pattern;
 #ifdef CONFIG_USE_KDE
     result += pattern;
-    result += '|';
+    result += QLatin1Char('|');
     result += text;
-    result += " (";
+    result += QLatin1String(" (");
     result += pattern;
-    result += ")\n";
+    result += QLatin1String(")\n");
 #else
     result += text;
-    result += " (";
+    result += QLatin1String(" (");
     result += pattern;
-    result += ");;";
+    result += QLatin1String(");;");
 #endif
   }
 
 #ifdef CONFIG_USE_KDE
   QString allExt = allPatterns;
-  allExt += '|';
+  allExt += QLatin1Char('|');
   allExt += i18n("All Supported Files");
-  allExt += '\n';
-  result = allExt + result + "*|" + i18n("All Files (*)");
+  allExt += QLatin1Char('\n');
+  result = allExt + result + QLatin1String("*|") + i18n("All Files (*)");
 #else
   QString allExt = i18n("All Supported Files");
-  allExt += " (";
+  allExt += QLatin1String(" (");
   allExt += allPatterns;
-  allExt += ");;";
+  allExt += QLatin1String(");;");
   result = allExt + result + i18n("All Files (*)");
 #endif
 
@@ -1806,7 +1934,7 @@ void Kid3Application::setTextEncodings()
 {
 #if defined HAVE_ID3LIB || defined HAVE_TAGLIB
   const QTextCodec* id3v1TextCodec =
-    ConfigStore::s_miscCfg.m_textEncodingV1 != "ISO-8859-1" ?
+    ConfigStore::s_miscCfg.m_textEncodingV1 != QLatin1String("ISO-8859-1") ?
     QTextCodec::codecForName(ConfigStore::s_miscCfg.m_textEncodingV1.toLatin1().data()) : 0;
 #endif
 #ifdef HAVE_ID3LIB
@@ -1836,7 +1964,7 @@ void Kid3Application::convertToId3v24()
     taggedFile->readTags(false);
     if (taggedFile->hasTagV2() && !taggedFile->isChanged()) {
       QString tagFmt = taggedFile->getTagFormatV2();
-      if (tagFmt.length() >= 7 && tagFmt.startsWith("ID3v2.") && tagFmt[6] < '4') {
+      if (tagFmt.length() >= 7 && tagFmt.startsWith(QLatin1String("ID3v2.")) && tagFmt[6] < QLatin1Char('4')) {
 #ifdef HAVE_ID3LIB
         if (dynamic_cast<Mp3File*>(taggedFile) != 0) {
           FrameCollection frames;
@@ -1857,7 +1985,13 @@ void Kid3Application::convertToId3v24()
 
         // Write the file with TagLib, it always writes ID3v2.4 tags
         bool renamed;
-        taggedFile->writeTags(true, &renamed, ConfigStore::s_miscCfg.m_preserveTime);
+        if (TagLibFile* taglibFile = dynamic_cast<TagLibFile*>(taggedFile)) {
+          taglibFile->writeTags(true, &renamed,
+                                ConfigStore::s_miscCfg.m_preserveTime, 4);
+        } else {
+          taggedFile->writeTags(true, &renamed,
+                                ConfigStore::s_miscCfg.m_preserveTime);
+        }
         taggedFile->readTags(true);
       }
     }
@@ -1866,7 +2000,7 @@ void Kid3Application::convertToId3v24()
 }
 #endif
 
-#if defined HAVE_TAGLIB && defined HAVE_ID3LIB
+#if defined HAVE_TAGLIB && (defined HAVE_ID3LIB || defined HAVE_TAGLIB_ID3V23_SUPPORT)
 /**
  * Convert ID3v2.4 to ID3v2.3 tags.
  */
@@ -1881,26 +2015,53 @@ void Kid3Application::convertToId3v23()
     taggedFile->readTags(false);
     if (taggedFile->hasTagV2() && !taggedFile->isChanged()) {
       QString tagFmt = taggedFile->getTagFormatV2();
-      if (tagFmt.length() >= 7 && tagFmt.startsWith("ID3v2.") && tagFmt[6] > '3') {
-        if (dynamic_cast<TagLibFile*>(taggedFile) != 0) {
-          FrameCollection frames;
-          taggedFile->getAllFramesV2(frames);
-          FrameFilter flt;
-          flt.enableAll();
-          taggedFile->deleteFramesV2(flt);
-
-          // The file has to be read with id3lib to write ID3v2.3 tags
-          taggedFile = FileProxyModel::readWithId3Lib(taggedFile);
-
-          // Restore the frames
-          FrameFilter frameFlt;
-          frameFlt.enableAll();
-          taggedFile->setFramesV2(frames.copyEnabledFrames(frameFlt), false);
-        }
-
-        // Write the file with id3lib, it always writes ID3v2.3 tags
+      QString ext = taggedFile->getFileExtension();
+      if (tagFmt.length() >= 7 && tagFmt.startsWith(QLatin1String("ID3v2.")) && tagFmt[6] > QLatin1Char('3') &&
+          (ext == QLatin1String(".mp3") || ext == QLatin1String(".mp2") || ext == QLatin1String(".aac"))) {
+        /*
+         * The ID3v2.3.0 tag is written using TagLib if it supports it.
+         * If id3lib is also available it is used instead unless
+         * MiscConfig::ID3v2_3_0_TAGLIB is selected, so that the behavior
+         * remains compatible. The variable taglibFile is used to select whether
+         * TagLib shall be used or not.
+         */
+#ifdef HAVE_TAGLIB_ID3V23_SUPPORT
+#ifdef HAVE_ID3LIB
+        TagLibFile* taglibFile =
+          ConfigStore::s_miscCfg.m_id3v2Version == MiscConfig::ID3v2_3_0_TAGLIB
+          ? dynamic_cast<TagLibFile*>(taggedFile) : 0;
+#else
+        TagLibFile* taglibFile = dynamic_cast<TagLibFile*>(taggedFile);
+#endif
+#else
+        TagLibFile* taglibFile = 0;
+#endif
         bool renamed;
-        taggedFile->writeTags(true, &renamed, ConfigStore::s_miscCfg.m_preserveTime);
+        if (taglibFile) {
+          taglibFile->writeTags(true, &renamed,
+                                ConfigStore::s_miscCfg.m_preserveTime, 3);
+        } else {
+#ifdef HAVE_ID3LIB
+          if (dynamic_cast<TagLibFile*>(taggedFile) != 0) {
+            FrameCollection frames;
+            taggedFile->getAllFramesV2(frames);
+            FrameFilter flt;
+            flt.enableAll();
+            taggedFile->deleteFramesV2(flt);
+
+            // The file has to be read with id3lib to write ID3v2.3 tags
+            taggedFile = FileProxyModel::readWithId3Lib(taggedFile);
+
+            // Restore the frames
+            FrameFilter frameFlt;
+            frameFlt.enableAll();
+            taggedFile->setFramesV2(frames.copyEnabledFrames(frameFlt), false);
+          }
+
+          // Write the file with id3lib, it always writes ID3v2.3 tags
+          taggedFile->writeTags(true, &renamed, ConfigStore::s_miscCfg.m_preserveTime);
+#endif
+        }
         taggedFile->readTags(true);
       }
     }
