@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Jul 2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -40,6 +40,7 @@ class QItemSelectionModel;
 class QModelIndex;
 class QNetworkAccessManager;
 class FileProxyModel;
+class FileProxyModelIterator;
 class DirProxyModel;
 class TrackDataModel;
 class FrameTableModel;
@@ -53,7 +54,10 @@ class ServerImporter;
 class MusicBrainzClient;
 class TextExporter;
 class DirRenamer;
-#ifdef HAVE_PHONON
+class BatchImportProfile;
+class BatchImporter;
+class IAbortable;
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 class AudioPlayer;
 #endif
 
@@ -93,6 +97,14 @@ public:
   */
   FileProxyModel* getFileProxyModel() { return m_fileProxyModel; }
 
+  /**
+  * Get file proxy model iterator.
+  * @return file proxy model iterator.
+   */
+  FileProxyModelIterator* getFileProxyModelIterator() {
+    return m_fileProxyModelIterator;
+  }
+
  /**
   * Get directory proxy model.
   * @return directory proxy model.
@@ -184,7 +196,13 @@ public:
    */
   DirRenamer* getDirRenamer() { return m_dirRenamer; }
 
-#ifdef HAVE_PHONON
+  /**
+   * Get batch importer.
+   * @return batch importer.
+   */
+  BatchImporter* getBatchImporter() { return m_batchImporter; }
+
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Get audio player.
    * @return audio player.
@@ -471,17 +489,6 @@ public:
    */
   static void setTextEncodings();
 
-  /**
-   * Get the URL of an image file.
-   * The input URL is transformed using the match picture URL table to
-   * get the URL of an image file.
-   *
-   * @param url URL from image drag
-   *
-   * @return URL of image file, empty if no image URL found.
-   */
-  static QString getImageUrl(const QString& url);
-
 public slots:
   /**
    * Revert file modifications.
@@ -507,6 +514,13 @@ public slots:
    */
   void applyId3Format();
 
+  /**
+   * Apply text encoding.
+   * Set the text encoding selected in the settings Tags/ID3v2/Text encoding
+   * for all selected files which have an ID3v2 tag.
+   */
+  void applyTextEncoding();
+
 #ifdef HAVE_TAGLIB
   /**
    * Convert ID3v2.3 to ID3v2.4 tags.
@@ -514,7 +528,7 @@ public slots:
   void convertToId3v24();
 #endif
 
-#if defined HAVE_TAGLIB && defined HAVE_ID3LIB
+#if defined HAVE_TAGLIB && (defined HAVE_ID3LIB || defined HAVE_TAGLIB_ID3V23_SUPPORT)
   /**
    * Convert ID3v2.4 to ID3v2.3 tags.
    */
@@ -711,15 +725,6 @@ public slots:
    */
   void fetchDirectory(const QModelIndex& index);
 
-  /**
-   * Fetch entries for all directories if not already fetched.
-   * This works like FileList::expandAll(), but without expanding tree view
-   * items and independent of the GUI. The processing is done in the background
-   * by QFileSystemModel, so the fetched items are not immediately available
-   * after calling this method.
-   */
-  void fetchAllDirectories();
-
   /**
    * Process change of selection.
    * The GUI is signaled to update the current selection and the controls.
@@ -745,7 +750,15 @@ public slots:
    */
   void applyFilter(const QString& expression);
 
-#ifdef HAVE_PHONON
+  /**
+   * Perform a batch import for the selected directories.
+   * @param profile batch import profile
+   * @param tagVersion import destination tag versions
+   */
+  void batchImport(const BatchImportProfile& profile,
+                   TrackData::TagVersion tagVersion);
+
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Play audio file.
    */
@@ -834,6 +847,28 @@ signals:
    */
   void aboutToPlayAudio();
 
+private slots:
+  /**
+   * Apply single file to file filter.
+   *
+   * @param index index of file in file proxy model
+   */
+  void filterNextFile(const QPersistentModelIndex& index);
+
+  /**
+   * Apply single file to batch import.
+   *
+   * @param index index of file in file proxy model
+   */
+  void batchImportNextFile(const QPersistentModelIndex& index);
+
+  /**
+   * Schedule rename action for a file.
+   *
+   * @param index index of file in file proxy model
+   */
+  void scheduleNextRenameAction(const QPersistentModelIndex& index);
+
 private:
   /**
   * Init file types.
@@ -853,6 +888,7 @@ private:
   /** model of filesystem */
   QFileSystemModel* m_fileSystemModel;
   FileProxyModel* m_fileProxyModel;
+  FileProxyModelIterator* m_fileProxyModelIterator;
   DirProxyModel* m_dirProxyModel;
   QItemSelectionModel* m_fileSelectionModel;
   /** Track data model */
@@ -873,7 +909,9 @@ private:
   TextExporter* m_textExporter;
   /** Directory renamer */
   DirRenamer* m_dirRenamer;
-#ifdef HAVE_PHONON
+  /** Batch importer */
+  BatchImporter* m_batchImporter;
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /** Audio player */
   AudioPlayer* m_player;
 #endif
@@ -895,6 +933,16 @@ private:
   QList<ServerImporter*> m_importers;
   /** Importer for MusicBrainz fingerprints */
   MusicBrainzClient* m_musicBrainzClient;
+
+  /* Context for filterNextFile() */
+  FileFilter* m_fileFilter;
+  QString m_lastProcessedDirName;
+  /* Context for batchImportNextFile() */
+  const BatchImportProfile* m_batchImportProfile;
+  TrackData::TagVersion m_batchImportTagVersion;
+  QList<ImportTrackDataVector> m_batchImportAlbums;
+  ImportTrackDataVector m_batchImportTrackDataList;
+
   /** Current directory */
   static QString s_dirName;
 };
