@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 20 Dec 2007
  *
- * Copyright (C) 2007-2008  Urs Fleisch
+ * Copyright (C) 2007-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -100,6 +100,16 @@ public slots:
    */
   bool importFromFile(int tagMask, const QString& path, int fmtIdx);
 
+  /**
+   * Start an automatic batch import.
+   *
+   * @param tagMask tag mask (bit 0 for tag 1, bit 1 for tag 2)
+   * @param profileName name of batch import profile to use
+   *
+   * @return true if profile found.
+   */
+  bool batchImport(int tagMask, const QString& profileName);
+
   /**
    * Download album cover art into the picture frame of the selected files.
    *
@@ -210,6 +220,11 @@ public slots:
    */
   void applyTagFormat();
 
+  /**
+   * Apply text encoding.
+   */
+  void applyTextEncoding();
+
   /**
    * Set the directory name from the tags.
    *
@@ -244,7 +259,7 @@ public slots:
   void convertToId3v24();
 #endif
 
-#if defined HAVE_TAGLIB && defined HAVE_ID3LIB
+#if defined HAVE_TAGLIB && (defined HAVE_ID3LIB || defined HAVE_TAGLIB_ID3V23_SUPPORT)
   /**
    * Convert ID3v2.4 tags to ID3v2.3.
    */
