@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 25 Aug 2007
  *
- * Copyright (C) 2007  Urs Fleisch
+ * Copyright (C) 2007-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,33 +26,11 @@
 
 #include "frame.h"
 #include <QMap>
+#include <QRegExp>
 #include "pictureframe.h"
 #include "qtcompatmac.h"
 
-/**
- * Constructor.
- */
-Frame::Frame() :
-  m_type(FT_UnknownFrame), m_index(-1), m_valueChanged(false)
-{
-}
-
-/**
- * Constructor.
- */
-Frame::Frame(Type type, const QString& value,
-             const QString& name, int index) :
-  m_type(type), m_index(index), m_valueChanged(false),
-  m_value(value), m_name(name)
-{
-}
-
-/**
- * Destructor.
- */
-Frame::~Frame()
-{
-}
+namespace {
 
 /**
  * Get name of frame from type.
@@ -61,7 +39,7 @@ Frame::~Frame()
  *
  * @return name.
  */
-const char* Frame::getNameFromType(Type type)
+const char* getNameFromType(Frame::Type type)
 {
   static const char* const names[] = {
     I18N_NOOP("Title"),           // FT_Title,
@@ -76,17 +54,23 @@ const char* Frame::getNameFromType(Type type)
     I18N_NOOP("Arranger"),        // FT_Arranger,
     I18N_NOOP("Author"),          // FT_Author,
     I18N_NOOP("BPM"),             // FT_Bpm,
+    I18N_NOOP("Catalog Number"),  // FT_CatalogNumber,
+    I18N_NOOP("Compilation"),     // FT_Compilation,
     I18N_NOOP("Composer"),        // FT_Composer,
     I18N_NOOP("Conductor"),       // FT_Conductor,
     I18N_NOOP("Copyright"),       // FT_Copyright,
     I18N_NOOP("Disc Number"),     // FT_Disc,
     I18N_NOOP("Encoded-by"),      // FT_EncodedBy,
+    I18N_NOOP("Encoder Settings"), // FT_EncoderSettings,
+    I18N_NOOP("Encoding Time"),   // FT_EncodingTime,
     I18N_NOOP("Grouping"),        // FT_Grouping,
+    I18N_NOOP("Initial Key"),     // FT_InitialKey,
     I18N_NOOP("ISRC"),            // FT_Isrc,
     I18N_NOOP("Language"),        // FT_Language,
     I18N_NOOP("Lyricist"),        // FT_Lyricist,
     I18N_NOOP("Lyrics"),          // FT_Lyrics,
     I18N_NOOP("Media"),           // FT_Media,
+    I18N_NOOP("Mood"),            // FT_Mood,
     I18N_NOOP("Original Album"),  // FT_OriginalAlbum,
     I18N_NOOP("Original Artist"), // FT_OriginalArtist,
     I18N_NOOP("Original Date"),   // FT_OriginalDate,
@@ -94,15 +78,23 @@ const char* Frame::getNameFromType(Type type)
     I18N_NOOP("Performer"),       // FT_Performer,
     I18N_NOOP("Picture"),         // FT_Picture,
     I18N_NOOP("Publisher"),       // FT_Publisher,
+    I18N_NOOP("Release Country"), // FT_ReleaseCountry,
     I18N_NOOP("Remixer"),         // FT_Remixer,
+    I18N_NOOP("Sort Album"),      // FT_SortAlbum,
+    I18N_NOOP("Sort Album Artist"), // FT_SortAlbumArtist,
+    I18N_NOOP("Sort Artist"),     // FT_SortArtist,
+    I18N_NOOP("Sort Composer"),   // FT_SortComposer,
+    I18N_NOOP("Sort Name"),       // FT_SortName,
     I18N_NOOP("Subtitle"),        // FT_Subtitle,
-    I18N_NOOP("Website")          // FT_Website,
-                                  // FT_LastFrame = FT_Website
+    I18N_NOOP("Website"),         // FT_Website,
+    I18N_NOOP("WWW Audio File"),  // FT_WWWAudioFile,
+    I18N_NOOP("WWW Audio Source") // FT_WWWAudioSource,
+                                  // FT_LastFrame = FT_WWWAudioSource
   };
   class not_used { int array_size_check[
-      sizeof(names) / sizeof(names[0]) == FT_LastFrame + 1
+      sizeof(names) / sizeof(names[0]) == Frame::FT_LastFrame + 1
       ? 1 : -1 ]; };
-  return type <= FT_LastFrame ? names[type] : "Unknown";
+  return type <= Frame::FT_LastFrame ? names[type] : "Unknown";
 }
 
 /**
@@ -112,36 +104,90 @@ const char* Frame::getNameFromType(Type type)
  *
  * @return type.
  */
-Frame::Type Frame::getTypeFromName(QString name)
+Frame::Type getTypeFromName(QString name)
 {
   static QMap<QString, int> strNumMap;
   if (strNumMap.empty()) {
     // first time initialization
-    for (int i = 0; i <= FT_LastFrame; ++i) {
-      Type type = static_cast<Type>(i);
-      strNumMap.insert(QString(getNameFromType(type)).
-                       remove(' ').toUpper(), type);
+    for (int i = 0; i <= Frame::FT_LastFrame; ++i) {
+      Frame::Type type = static_cast<Frame::Type>(i);
+      strNumMap.insert(QString::fromLatin1(getNameFromType(type)).
+                       remove(QLatin1Char(' ')).toUpper(), type);
     }
   }
   QMap<QString, int>::const_iterator it =
-    strNumMap.find(name.remove(' ').toUpper());
+    strNumMap.find(name.remove(QLatin1Char(' ')).toUpper());
   if (it != strNumMap.end()) {
-    return static_cast<Type>(*it);
+    return static_cast<Frame::Type>(*it);
   }
-  return FT_Other;
+  return Frame::FT_Other;
+}
+
+}
+
+Frame::ExtendedType::ExtendedType(const QString& name) :
+  m_type(getTypeFromName(name)), m_name(name)
+{
+}
+
+Frame::ExtendedType::ExtendedType(Type type) :
+  m_type(type), m_name(QString::fromLatin1(getNameFromType(type)))
+{
 }
 
 /**
- * Get name of frame.
- *
- * @param internal true to get internal (non-general) name
- *
+ * Get name of type.
  * @return name.
  */
-QString Frame::getName(bool internal) const
+QString Frame::ExtendedType::getName() const
+{
+  return m_type != FT_Other ? QString::fromLatin1(getNameFromType(m_type)) : m_name;
+}
+
+/**
+ * Get translated name of type.
+ * @return name.
+ */
+QString Frame::ExtendedType::getTranslatedName() const
+{
+  return m_type != FT_Other ? QCM_translate(getNameFromType(m_type)) : m_name;
+}
+
+
+/**
+ * Constructor.
+ */
+Frame::Frame() :
+  m_index(-1), m_valueChanged(false)
+{
+}
+
+/**
+ * Constructor.
+ */
+Frame::Frame(Type type, const QString& value,
+             const QString& name, int index) :
+  m_extendedType(type, name), m_index(index), m_valueChanged(false),
+  m_value(value)
+{
+}
+
+/**
+ * Constructor.
+ * @param type  type and internal name
+ * @param value value
+ * @param index index inside tag, -1 if unknown
+ */
+Frame::Frame(const ExtendedType& type, const QString& value, int index) :
+  m_extendedType(type), m_index(index), m_valueChanged(false), m_value(value)
+{
+}
+
+/**
+ * Destructor.
+ */
+Frame::~Frame()
 {
-  return !internal && m_type != FT_Other ?
-    QString(getNameFromType(m_type)) : m_name;
 }
 
 /**
@@ -205,7 +251,7 @@ void Frame::setFieldListFromValue()
  */
 int Frame::numberWithoutTotal(const QString& str, bool* ok)
 {
-  int slashPos = str.indexOf("/");
+  int slashPos = str.indexOf(QLatin1Char('/'));
   return slashPos == -1 ?
     str.toInt(ok) :
     str.left(slashPos).toInt(ok);
@@ -274,7 +320,7 @@ bool Frame::isEqual(const Frame& other) const
   return true;
 }
 
-#ifdef DEBUG
+#ifndef QT_NO_DEBUG
 /**
  * Convert frame type to string.
  * @param type frame type
@@ -294,17 +340,23 @@ static const char* frameTypeToString(Frame::Type type)
     "FT_Arranger",
     "FT_Author",
     "FT_Bpm",
+    "FT_CatalogNumber",
+    "FT_Compilation",
     "FT_Composer",
     "FT_Conductor",
     "FT_Copyright",
     "FT_Disc",
     "FT_EncodedBy",
+    "FT_EncoderSettings",
+    "FT_EncodingTime",
     "FT_Grouping",
+    "FT_InitialKey",
     "FT_Isrc",
     "FT_Language",
     "FT_Lyricist",
     "FT_Lyrics",
     "FT_Media",
+    "FT_Mood",
     "FT_OriginalAlbum",
     "FT_OriginalArtist",
     "FT_OriginalDate",
@@ -312,9 +364,17 @@ static const char* frameTypeToString(Frame::Type type)
     "FT_Performer",
     "FT_Picture",
     "FT_Publisher",
+    "FT_ReleaseCountry",
     "FT_Remixer",
+    "FT_SortAlbum",
+    "FT_SortAlbumArtist",
+    "FT_SortArtist",
+    "FT_SortComposer",
+    "FT_SortName",
     "FT_Subtitle",
     "FT_Website",
+    "FT_WWWAudioFile",
+    "FT_WWWAudioSource",
     "FT_Other",
     "FT_UnknownFrame"
   };
@@ -367,7 +427,7 @@ static const char* fieldIdToString(int id)
 static QString variantToString(const QVariant& val)
 {
   if (val.type() == QVariant::ByteArray) {
-    return QString("ByteArray of %1 bytes").arg(val.toByteArray().size());
+    return QString(QLatin1String("ByteArray of %1 bytes")).arg(val.toByteArray().size());
   } else {
     return val.toString();
   }
@@ -379,7 +439,8 @@ static QString variantToString(const QVariant& val)
 void Frame::dump() const
 {
   qDebug("Frame: name=%s, value=%s, type=%s, index=%d, valueChanged=%u",
-         m_name.toLatin1().data(), m_value.toLatin1().data(), frameTypeToString(m_type), m_index,
+         getInternalName().toLatin1().data(), m_value.toLatin1().data(),
+         frameTypeToString(getType()), m_index,
          m_valueChanged);
   qDebug("  fields=");
   for (FieldList::const_iterator it = m_fieldList.begin();
@@ -392,6 +453,14 @@ void Frame::dump() const
 #endif
 
 
+/**
+ * Bit mask containing the bits of all frame types which shall be used as
+ * quick access frames.
+ * This mask has to be handled like FrameFilter::m_enabledFrames.
+ */
+quint64 FrameCollection::s_quickAccessFrames =
+    FrameCollection::DEFAULT_QUICK_ACCESS_FRAMES;
+
 /**
  * Set values which are different inactive.
  *
@@ -442,11 +511,17 @@ void FrameCollection::filterDifferent(FrameCollection& others)
  */
 void FrameCollection::addMissingStandardFrames()
 {
-  for (int i = Frame::FT_FirstFrame; i <= Frame::FT_LastV1Frame; ++i) {
-    Frame frame(static_cast<Frame::Type>(i), QString::null, QString::null, -1);
-    FrameCollection::const_iterator it = find(frame);
-    if (it == end()) {
-      insert(frame);
+  quint64 mask;
+  int i;
+  for (i = Frame::FT_FirstFrame, mask = 1ULL;
+       i <= Frame::FT_LastFrame;
+       ++i, mask <<= 1) {
+    if (s_quickAccessFrames & mask) {
+      Frame frame(static_cast<Frame::Type>(i), QString::null, QString::null, -1);
+      FrameCollection::const_iterator it = find(frame);
+      if (it == end()) {
+        insert(frame);
+      }
     }
   }
 }
@@ -534,6 +609,37 @@ bool FrameCollection::isEmptyOrInactive() const
     getGenre().isEmpty();
 }
 
+/**
+ * Search for a frame only by name.
+ *
+ * @param name the name of the frame to find, a case-insensitive search for
+ *             the first name starting with this string is performed
+ *
+ * @return iterator or end() if not found.
+ */
+FrameCollection::const_iterator FrameCollection::searchByName(
+    const QString& name) const
+{
+  if (name.isEmpty())
+    return end();
+
+  const_iterator it;
+  QString ucName = name.toUpper().remove(QLatin1Char('/'));
+  int len = ucName.length();
+  for (it = begin(); it != end(); ++it) {
+    QString ucFrameName(it->getName().toUpper().remove(QLatin1Char('/')));
+    if (ucName == ucFrameName.left(len)) {
+      break;
+    }
+    int nlPos = ucFrameName.indexOf(QLatin1Char('\n'));
+    if (nlPos > 0 && ucName == ucFrameName.mid(nlPos + 1, len)) {
+      // Description in TXXX, WXXX, COMM, PRIV matches
+      break;
+    }
+  }
+  return it;
+}
+
 /**
  * Find a frame by name.
  *
@@ -545,23 +651,30 @@ bool FrameCollection::isEmptyOrInactive() const
  */
 FrameCollection::const_iterator FrameCollection::findByName(const QString& name) const
 {
-  Frame::Type type = Frame::getTypeFromName(name);
-  Frame frame(type, "", name, -1);
+  Frame frame(Frame::ExtendedType(name), QLatin1String(""), -1);
+  const_iterator it = find(frame);
+  if (it != end()) {
+    return it;
+  }
+  return searchByName(name);
+}
+
+/**
+ * Find a frame by type or name.
+ *
+ * @param type  type and name of the frame to find, if the exact name is not
+ *              found, a case-insensitive search for the first name
+ *              starting with this string is performed
+ *
+ * @return iterator or end() if not found.
+ */
+FrameCollection::const_iterator FrameCollection::findByExtendedType(
+    const Frame::ExtendedType& type) const
+{
+  Frame frame(type, QLatin1String(""), -1);
   const_iterator it = find(frame);
   if (it == end()) {
-    QString ucName = name.toUpper().remove('/');
-    int len = ucName.length();
-    for (it = begin(); it != end(); ++it) {
-      QString ucFrameName(it->getName().toUpper().remove('/'));
-      if (ucName == ucFrameName.left(len)) {
-        break;
-      }
-      int nlPos = ucFrameName.indexOf("\n");
-      if (nlPos > 0 && ucName == ucFrameName.mid(nlPos + 1, len)) {
-        // Description in TXXX, WXXX, COMM, PRIV matches
-        break;
-      }
-    }
+    it = searchByName(frame.getInternalName());
   }
   return it;
 }
@@ -593,11 +706,26 @@ FrameCollection::const_iterator FrameCollection::findByIndex(int index) const
  */
 QString FrameCollection::getValue(Frame::Type type) const
 {
-  Frame frame(type, "", "", -1);
+  Frame frame(type, QLatin1String(""), QLatin1String(""), -1);
   const_iterator it = find(frame);
   return it != end() ? it->getValue() : QString::null;
 }
 
+/**
+ * Get value by type and name.
+ *
+ * @param type  type and name of the frame to find, if the exact name is not
+ *              found, a case-insensitive search for the first name
+ *              starting with this string is performed
+ *
+ * @return value, QString::null if not found.
+ */
+QString FrameCollection::getValue(const Frame::ExtendedType& type) const
+{
+  const_iterator it = findByExtendedType(type);
+  return it != end() ? it->getValue() : QString::null;
+}
+
 /**
  * Set value by type.
  *
@@ -607,7 +735,7 @@ QString FrameCollection::getValue(Frame::Type type) const
 void FrameCollection::setValue(Frame::Type type, const QString& value)
 {
   if (!value.isNull()) {
-    Frame frame(type, "", "", -1);
+    Frame frame(type, QLatin1String(""), QLatin1String(""), -1);
     iterator it = find(frame);
     if (it != end()) {
       Frame& frameFound = const_cast<Frame&>(*it);
@@ -619,6 +747,33 @@ void FrameCollection::setValue(Frame::Type type, const QString& value)
   }
 }
 
+/**
+ * Set value by type and name.
+ *
+ * @param type  type and name of the frame to find, if the exact name is not
+ *              found, a case-insensitive search for the first name
+ *              starting with this string is performed
+ * @param value value, nothing is done if QString::null
+ */
+void FrameCollection::setValue(const Frame::ExtendedType& type,
+                               const QString& value)
+{
+  if (!value.isNull()) {
+    Frame frame(type, QLatin1String(""), -1);
+    const_iterator it = find(frame);
+    if (it == end()) {
+      it = searchByName(type.getInternalName());
+    }
+    if (it != end()) {
+      Frame& frameFound = const_cast<Frame&>(*it);
+      frameFound.setValueIfChanged(value);
+    } else {
+      frame.setValueIfChanged(value);
+      insert(frame);
+    }
+  }
+}
+
 /**
  * Get integer value by type.
  *
@@ -641,7 +796,7 @@ int FrameCollection::getIntValue(Frame::Type type) const
 void FrameCollection::setIntValue(Frame::Type type, int value)
 {
   if (value != -1) {
-    QString str = value != 0 ? QString::number(value) : QString("");
+    QString str = value != 0 ? QString::number(value) : QLatin1String("");
     setValue(type, str);
   }
 }
@@ -663,7 +818,7 @@ void FrameCollection::markChangedFrames(const FrameCollection& other)
   }
 }
 
-#ifdef DEBUG
+#ifndef QT_NO_DEBUG
 /**
  * Dump contents of frame collection to debug console.
  */
@@ -721,7 +876,7 @@ bool FrameFilter::areAllEnabled() const
 bool FrameFilter::isEnabled(Frame::Type type, const QString& name) const
 {
   if (type <= Frame::FT_LastFrame) {
-    return (m_enabledFrames & (1 << type)) != 0;
+    return (m_enabledFrames & (1ULL << type)) != 0;
   } else if (!name.isEmpty()) {
     std::set<QString>::const_iterator it = m_disabledOtherFrames.find(name);
     return it == m_disabledOtherFrames.end();
@@ -741,9 +896,9 @@ void FrameFilter::enable(Frame::Type type, const QString& name, bool en)
 {
   if (type <= Frame::FT_LastFrame) {
     if (en) {
-      m_enabledFrames |= (1 << type);
+      m_enabledFrames |= (1ULL << type);
     } else {
-      m_enabledFrames &= ~(1 << type);
+      m_enabledFrames &= ~(1ULL << type);
     }
   } else if (!name.isEmpty()) {
     if (en) {
@@ -812,7 +967,7 @@ QString FrameFormatReplacer::getReplacement(const QString& code) const
     const char c = code[0].toLatin1();
     for (unsigned i = 0; i < sizeof(shortToLong) / sizeof(shortToLong[0]); ++i) {
       if (shortToLong[i].shortCode == c) {
-        name = shortToLong[i].longCode;
+        name = QString::fromLatin1(shortToLong[i].longCode);
         break;
       }
     }
@@ -822,16 +977,16 @@ QString FrameFormatReplacer::getReplacement(const QString& code) const
 
   if (!name.isNull()) {
     QString lcName(name.toLower());
-    int fieldWidth = lcName == "track" ? 2 : -1;
-    if (lcName == "year") {
-      name = "date";
-    } else if (lcName == "tracknumber") {
-      name = "track number";
+    int fieldWidth = lcName == QLatin1String("track") ? 2 : -1;
+    if (lcName == QLatin1String("year")) {
+      name = QLatin1String("date");
+    } else if (lcName == QLatin1String("tracknumber")) {
+      name = QLatin1String("track number");
     }
     int len = lcName.length();
-    if (len > 2 && lcName[len - 2] == '.' &&
-        lcName[len - 1] >= '0' && lcName[len - 1] <= '9') {
-      fieldWidth = lcName[len - 1].toLatin1() - '0';
+    if (len > 2 && lcName.at(len - 2) == QLatin1Char('.') &&
+        lcName.at(len - 1) >= QLatin1Char('0') && lcName.at(len - 1) <= QLatin1Char('9')) {
+      fieldWidth = lcName.at(len - 1).toLatin1() - '0';
       lcName.truncate(len - 2);
       name.truncate(len - 2);
     }
@@ -841,18 +996,25 @@ QString FrameFormatReplacer::getReplacement(const QString& code) const
       result = it->getValue();
       if (result.isNull()) {
         // code was found, but value is empty
-        result = "";
+        result = QLatin1String("");
       }
       if (it->getType() == Frame::FT_Picture && result.isEmpty()) {
         QVariant fieldValue = it->getFieldValue(Frame::Field::ID_Data);
         if (fieldValue.isValid() && fieldValue.toByteArray().size() > 0) {
           // If there is a picture without description, return "1", so that
           // an empty value indicates "no picture"
-          result = "1";
+          result = QLatin1String("1");
         }
       }
     }
 
+    if (lcName == QLatin1String("year")) {
+      QRegExp yearRe(QLatin1String("^\\d{4}-\\d{2}"));
+      if (yearRe.indexIn(result) == 0) {
+        result.truncate(4);
+      }
+    }
+
     if (fieldWidth > 0) {
       bool ok;
       int nr = Frame::numberWithoutTotal(result, &ok);
@@ -876,44 +1038,44 @@ QString FrameFormatReplacer::getReplacement(const QString& code) const
 QString FrameFormatReplacer::getToolTip(bool onlyRows)
 {
   QString str;
-  if (!onlyRows) str += "<table>\n";
+  if (!onlyRows) str += QLatin1String("<table>\n");
 
-  str += "<tr><td>%s</td><td>%{title}</td><td>";
+  str += QLatin1String("<tr><td>%s</td><td>%{title}</td><td>");
   str += QCM_translate("Title");
-  str += "</td></tr>\n";
+  str += QLatin1String("</td></tr>\n");
 
-  str += "<tr><td>%l</td><td>%{album}</td><td>";
+  str += QLatin1String("<tr><td>%l</td><td>%{album}</td><td>");
   str += QCM_translate("Album");
-  str += "</td></tr>\n";
+  str += QLatin1String("</td></tr>\n");
 
-  str += "<tr><td>%a</td><td>%{artist}</td><td>";
+  str += QLatin1String("<tr><td>%a</td><td>%{artist}</td><td>");
   str += QCM_translate("Artist");
-  str += "</td></tr>\n";
+  str += QLatin1String("</td></tr>\n");
 
-  str += "<tr><td>%c</td><td>%{comment}</td><td>";
+  str += QLatin1String("<tr><td>%c</td><td>%{comment}</td><td>");
   str += QCM_translate("Comment");
-  str += "</td></tr>\n";
+  str += QLatin1String("</td></tr>\n");
 
-  str += "<tr><td>%y</td><td>%{year}</td><td>";
+  str += QLatin1String("<tr><td>%y</td><td>%{year}</td><td>");
   str += QCM_translate(I18N_NOOP("Year"));
-  str += "</td></tr>\n";
+  str += QLatin1String("</td></tr>\n");
 
-  str += "<tr><td>%t</td><td>%{track}</td><td>";
+  str += QLatin1String("<tr><td>%t</td><td>%{track}</td><td>");
   str += QCM_translate(I18N_NOOP("Track"));
-  str += " &quot;01&quot;</td></tr>\n";
+  str += QLatin1String(" &quot;01&quot;</td></tr>\n");
 
-  str += "<tr><td>%t</td><td>%{track.3}</td><td>";
+  str += QLatin1String("<tr><td>%t</td><td>%{track.3}</td><td>");
   str += QCM_translate(I18N_NOOP("Track"));
-  str += " &quot;001&quot;</td></tr>\n";
+  str += QLatin1String(" &quot;001&quot;</td></tr>\n");
 
-  str += "<tr><td>%T</td><td>%{tracknumber}</td><td>";
+  str += QLatin1String("<tr><td>%T</td><td>%{tracknumber}</td><td>");
   str += QCM_translate(I18N_NOOP("Track"));
-  str += " &quot;1&quot;</td></tr>\n";
+  str += QLatin1String(" &quot;1&quot;</td></tr>\n");
 
-  str += "<tr><td>%g</td><td>%{genre}</td><td>";
+  str += QLatin1String("<tr><td>%g</td><td>%{genre}</td><td>");
   str += QCM_translate("Genre");
-  str += "</td></tr>\n";
+  str += QLatin1String("</td></tr>\n");
 
-  if (!onlyRows) str += "</table>\n";
+  if (!onlyRows) str += QLatin1String("</table>\n");
   return str;
 }
