@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 25 Aug 2007
  *
- * Copyright (C) 2007  Urs Fleisch
+ * Copyright (C) 2007-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -52,17 +52,23 @@ public:
     FT_Arranger,
     FT_Author,
     FT_Bpm,
+    FT_CatalogNumber,
+    FT_Compilation,
     FT_Composer,
     FT_Conductor,
     FT_Copyright,
     FT_Disc,
     FT_EncodedBy,
+    FT_EncoderSettings,
+    FT_EncodingTime,
     FT_Grouping,
+    FT_InitialKey,
     FT_Isrc,
     FT_Language,
     FT_Lyricist,
     FT_Lyrics,
     FT_Media,
+    FT_Mood,
     FT_OriginalAlbum,
     FT_OriginalArtist,
     FT_OriginalDate,
@@ -70,10 +76,18 @@ public:
     FT_Performer,
     FT_Picture,
     FT_Publisher,
+    FT_ReleaseCountry,
     FT_Remixer,
+    FT_SortAlbum,
+    FT_SortAlbumArtist,
+    FT_SortArtist,
+    FT_SortComposer,
+    FT_SortName,
     FT_Subtitle,
     FT_Website,
-    FT_LastFrame = FT_Website,
+    FT_WWWAudioFile,
+    FT_WWWAudioSource,
+    FT_LastFrame = FT_WWWAudioSource,
     FT_Other,
     FT_UnknownFrame
   };
@@ -107,7 +121,12 @@ public:
       ID_PeakVolRight,
       ID_PeakVolLeft,
       ID_TimestampFormat,
-      ID_ContentType
+      ID_ContentType,
+
+      // These are additional fields used by TagLib
+      ID_Price,
+      ID_Date,
+      ID_Seller
     };
 
     /** Text encoding for fields of type ID_TextEnc. */
@@ -118,6 +137,18 @@ public:
       TE_UTF8 = 3
     };
 
+#ifdef Q_CC_MSVC
+  /**
+   * Equality operator.
+   * Needed when building with MSVC and BUILD_SHARED_LIBS.
+   * @param rhs right hand side to compare
+   * @return true if this == rhs.
+   */
+  bool operator==(const Field& rhs) const {
+    return m_id == rhs.m_id && m_value == rhs.m_value;
+  }
+#endif
+
     int m_id;         /**< type of field. */
     QVariant m_value; /**< value of field. */
   };
@@ -125,6 +156,86 @@ public:
   /** list of fields. */
   typedef QList<Field> FieldList;
 
+  /**
+   * Type and name of frame.
+   */
+  class KID3_CORE_EXPORT ExtendedType {
+  public:
+    /**
+     * Constructor.
+     */
+    ExtendedType() : m_type(FT_UnknownFrame) {}
+
+    /**
+     * Constructor.
+     * @param type type
+     * @param name internal name
+     */
+    ExtendedType(Type type, const QString& name) : m_type(type), m_name(name) {}
+
+    /**
+     * Constructor.
+     * @param name internal name
+     */
+    explicit ExtendedType(const QString& name);
+
+    /**
+     * Constructor.
+     * @param type type
+     */
+    explicit ExtendedType(Type type);
+
+    /**
+     * Get name of type.
+     * @return name.
+     */
+    QString getName() const;
+
+    /**
+     * Get translated name of type.
+     * @return name.
+     */
+    QString getTranslatedName() const;
+
+    /**
+     * Get internal name of type.
+     * @return name.
+     */
+    QString getInternalName() const { return m_name; }
+
+    /**
+     * Less than operator.
+     * @param rhs right hand side to compare
+     * @return true if this < rhs.
+     */
+    bool operator<(const ExtendedType& rhs) const {
+      return m_type < rhs.m_type ||
+             (m_type == FT_Other && m_type == rhs.m_type && m_name < rhs.m_name);
+    }
+
+    /**
+     * Equality operator.
+     * @param rhs right hand side to compare
+     * @return true if this == rhs.
+     */
+    bool operator==(const ExtendedType& rhs) const {
+      return m_type == rhs.m_type &&
+             (m_type != FT_Other || m_name == rhs.m_name);
+    }
+
+    /**
+     * Get type
+     * @return type.
+     */
+    Type getType() const { return m_type; }
+
+  private:
+    friend class Frame;
+    Type m_type;
+    QString m_name;
+  };
+
+
   /**
    * Constructor.
    */
@@ -139,6 +250,14 @@ public:
    */
   Frame(Type type, const QString& value, const QString& name, int index);
 
+  /**
+   * Constructor.
+   * @param type  type and internal name
+   * @param value value
+   * @param index index inside tag, -1 if unknown
+   */
+  Frame(const ExtendedType& type, const QString& value, int index);
+
   /**
    * Destructor.
    */
@@ -151,20 +270,45 @@ public:
    * @return true if this < rhs.
    */
   bool operator<(const Frame& rhs) const {
-    return m_type < rhs.m_type || (m_type == FT_Other && m_type == rhs.m_type && m_name < rhs.m_name);
+    return m_extendedType < rhs.m_extendedType;
   }
 
+#ifdef Q_CC_MSVC
+  /**
+   * Equality operator.
+   * Needed when building with MSVC and BUILD_SHARED_LIBS.
+   * @param rhs right hand side to compare
+   * @return true if this == rhs.
+   */
+  bool operator==(const Frame& rhs) const {
+    return m_extendedType == rhs.m_extendedType && m_value == rhs.m_value &&
+      m_fieldList == rhs.m_fieldList;
+  }
+#endif
+
   /**
    * Get type of frame.
    * @return type.
    */
-  Type getType() const { return m_type; }
+  Type getType() const { return m_extendedType.m_type; }
 
   /**
    * Set type of frame.
    * @param type type of frame
    */
-  void setType(Type type) { m_type = type; }
+  void setType(Type type) { m_extendedType.m_type = type; }
+
+  /**
+   * Get type and name of frame.
+   * @return extended type.
+   */
+  ExtendedType getExtendedType() const { return m_extendedType; }
+
+  /**
+   * Set type and name of frame.
+   * @param type extended type of frame
+   */
+  void setExtendedType(const ExtendedType& type) { m_extendedType = type; }
 
   /**
    * Get index of frame.
@@ -180,18 +324,15 @@ public:
 
   /**
    * Get name of frame.
-   *
-   * @param internal true to get internal (non-general) name
-   *
    * @return name.
    */
-  QString getName(bool internal = false) const;
+  QString getName() const { return m_extendedType.getName(); }
 
   /**
-   * Set internal name of frame.
-   * @param name internal (non-general) name
+   * Get internal name of frame.
+   * @return name.
    */
-  void setInternalName(const QString& name) { m_name = name; }
+  QString getInternalName() const { return m_extendedType.getInternalName(); }
 
   /**
    * Get value as string.
@@ -298,38 +439,20 @@ public:
    */
   bool isEqual(const Frame& other) const;
 
-#ifdef DEBUG
+#ifndef QT_NO_DEBUG
   /**
    * Dump contents of frame to debug console.
    */
   void dump() const;
 #endif
 
-  /**
-   * Get name of frame from type.
-   *
-   * @param type type
-   *
-   * @return name.
-   */
-  static const char* getNameFromType(Type type);
-
-  /**
-   * Get type of frame from English name.
-   *
-   * @param name name, spaces and case are ignored
-   *
-   * @return type.
-   */
-  static Type getTypeFromName(QString name);
-
   /**
    * If a frame contains a string list as a value, it is stored in a single
    * string, separated by this special separator character.
    *
    * @return separator character.
    */
-  static char stringListSeparator() { return '|'; }
+  static QLatin1Char stringListSeparator() { return QLatin1Char('|'); }
 
   /**
    * Convert string (e.g. "track/total number of tracks") to number.
@@ -341,20 +464,19 @@ public:
    */
   static int numberWithoutTotal(const QString& str, bool* ok = 0);
 
-private:
-  friend class TaggedFile;
-
   /**
    * Get representation of different frames in multiple files.
    * @return "different" representation.
    */
   static QChar differentRepresentation() { return QChar(0x2260); }
 
-  Type m_type;
+private:
+  friend class TaggedFile;
+
+  ExtendedType m_extendedType;
   int m_index;
   bool m_valueChanged;
   QString m_value;
-  QString m_name;
   FieldList m_fieldList;
 };
 
@@ -404,19 +526,26 @@ public:
   void enable(Frame::Type type, const QString& name = QString(), bool en = true);
 
 private:
-  class not_used { int num_frame_types_check[
-      Frame::FT_LastFrame == 31
-      ? 1 : -1 ]; };
-  enum { FTM_AllFrames = 0xffffffff };
-  // if FTM_AllFrames is not 31, use
-  // enum { FTM_AllFrames = (1 << (Frame::FT_LastFrame + 1)) - 1 };
-  unsigned long m_enabledFrames;
+  static const quint64 FTM_AllFrames = (1ULL << (Frame::FT_LastFrame + 1)) - 1;
+  quint64 m_enabledFrames;
   std::set<QString> m_disabledOtherFrames;
 };
 
 /** Collection of frames. */
 class KID3_CORE_EXPORT FrameCollection : public std::multiset<Frame> {
 public:
+  /**
+   * Default value for quick access frames.
+   */
+  static const quint64 DEFAULT_QUICK_ACCESS_FRAMES =
+      (1ULL << Frame::FT_Title)   |
+      (1ULL << Frame::FT_Artist)  |
+      (1ULL << Frame::FT_Album)   |
+      (1ULL << Frame::FT_Comment) |
+      (1ULL << Frame::FT_Date)    |
+      (1ULL << Frame::FT_Track)   |
+      (1ULL << Frame::FT_Genre);
+
   /**
    * Constructor.
    */
@@ -481,6 +610,17 @@ public:
    */
   const_iterator findByName(const QString& name) const;
 
+  /**
+   * Find a frame by type or name.
+   *
+   * @param type  type and name of the frame to find, if the exact name is not
+   *              found, a case-insensitive search for the first name
+   *              starting with this string is performed
+   *
+   * @return iterator or end() if not found.
+   */
+  const_iterator findByExtendedType(const Frame::ExtendedType& type) const;
+
   /**
    * Find a frame by index.
    *
@@ -499,6 +639,17 @@ public:
    */
   QString getValue(Frame::Type type) const;
 
+  /**
+   * Get value by type and name.
+   *
+   * @param type  type and name of the frame to find, if the exact name is not
+   *              found, a case-insensitive search for the first name
+   *              starting with this string is performed
+   *
+   * @return value, QString::null if not found.
+   */
+  QString getValue(const Frame::ExtendedType& type) const;
+
   /**
    * Set value by type.
    *
@@ -507,6 +658,16 @@ public:
    */
   void setValue(Frame::Type type, const QString& value);
 
+  /**
+   * Set value by type and name.
+   *
+   * @param type  type and name of the frame to find, if the exact name is not
+   *              found, a case-insensitive search for the first name
+   *              starting with this string is performed
+   * @param value value, nothing is done if QString::null
+   */
+  void setValue(const Frame::ExtendedType& type, const QString& value);
+
   /**
    * Get integer value by type.
    *
@@ -630,12 +791,40 @@ public:
    */
   void markChangedFrames(const FrameCollection& other);
 
-#ifdef DEBUG
+#ifndef QT_NO_DEBUG
   /**
    * Dump contents of frame collection to debug console.
    */
   void dump() const;
 #endif
+
+  /**
+   * Set mask containing the bits of all frame types which shall be used as
+   * quick access frames.
+   * @param mask bit mask with bits for quick access frames set, default is
+   * DEFAULT_QUICK_ACCESS_FRAMES.
+   */
+  static void setQuickAccessFrames(quint64 mask) {
+    s_quickAccessFrames = mask;
+  }
+
+private:
+  /**
+   * Search for a frame only by name.
+   *
+   * @param name the name of the frame to find, a case-insensitive search for
+   *             the first name starting with this string is performed
+   *
+   * @return iterator or end() if not found.
+   */
+  const_iterator searchByName(const QString& name) const;
+
+  /**
+   * Bit mask containing the bits of all frame types which shall be used as
+   * quick access frames.
+   * This mask has to be handled like FrameFilter::m_enabledFrames.
+   */
+  static quint64 s_quickAccessFrames;
 };
 
 
