@@ -33,10 +33,10 @@ bool Utils::hasIllegalFileNameCharacters(const QString& fileName)
 {
   static const char illegalChars[] = "<>:\"|?*";
   QString fileNameWithoutDrive(
-        (QDir::isAbsolutePath(fileName) && fileName.mid(1, 2) == ":/")
+      (QDir::isAbsolutePath(fileName) && fileName.mid(1, 2) == QLatin1String(":/"))
         ? fileName.mid(3) : fileName);
   for (const char* chPtr = illegalChars; *chPtr; ++chPtr) {
-    if (fileNameWithoutDrive.contains(*chPtr)) {
+    if (fileNameWithoutDrive.contains(QLatin1Char(*chPtr))) {
       return true;
     }
   }
