@@ -1,12 +1,12 @@
 /**
- * \file main.cpp
+ * \file gui/app/main.cpp
  * Main program.
  *
  * \b Project: Kid3
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2012  Urs Fleisch
+ * Copyright (C) 2003-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,6 +26,7 @@
 
 #include "config.h"
 #include <QFile>
+#include "configstore.h"
 #ifdef CONFIG_USE_KDE
 
 #include <kdeversion.h>
@@ -74,6 +75,9 @@ int main(int argc, char* argv[])
 
     if (args->count()) {
       kid3->confirmedOpenDirectory(args->arg(0));
+    } else if (ConfigStore::s_miscCfg.m_loadLastOpenedFile &&
+               !ConfigStore::s_miscCfg.m_lastOpenedFile.isEmpty()) {
+      kid3->confirmedOpenDirectory(ConfigStore::s_miscCfg.m_lastOpenedFile);
     }
     args->clear();
   }
@@ -105,41 +109,67 @@ int main(int argc, char* argv[])
   Q_INIT_RESOURCE(kid3);
 
   QApplication app(argc, argv);
-  app.setApplicationName("Kid3");
-  QString locale(QLocale::system().name());
+  app.setApplicationName(QLatin1String("Kid3"));
+  QLocale locale;
+
+  QStringList languages(
+#if QT_VERSION >= 0x040800 && !defined Q_OS_WIN32
+        locale.uiLanguages()
+#else
+        locale.name()
+#endif
+        );
 
   // translation file for Qt
-  QTranslator qt_tr(0);
-#if defined WIN32 || defined __APPLE__
+  QTranslator qt_tr;
+  foreach (QString localeName, languages) {
+    if (
+        localeName.startsWith(QLatin1String("en")) ||
+#if defined Q_OS_WIN32 || defined Q_OS_MAC
 #ifdef CFG_TRANSLATIONSDIR
-  if (!qt_tr.load(QString("qt_") + locale, CFG_TRANSLATIONSDIR))
+        qt_tr.load(QLatin1String("qt_") + localeName, QLatin1String(CFG_TRANSLATIONSDIR)) ||
 #endif
-  qt_tr.load( QString("qt_") + locale, "." );
+        qt_tr.load(QLatin1String("qt_") + localeName, QLatin1String("."))
 #else
-  qt_tr.load(QString("qt_") + locale,
-             QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+        qt_tr.load(QLatin1String("qt_") + localeName,
+                   QLibraryInfo::location(QLibraryInfo::TranslationsPath))
 #endif
+        ) {
+      break;
+    }
+  }
   app.installTranslator(&qt_tr);
 
   // translation file for application strings
-  QTranslator kid3_tr(0);
+  QTranslator kid3_tr;
+  foreach (QString localeName, languages) {
+    if (
+        localeName.startsWith(QLatin1String("en")) ||
 #ifdef CFG_TRANSLATIONSDIR
-  if (!kid3_tr.load(QString("kid3_") + locale, CFG_TRANSLATIONSDIR))
+        kid3_tr.load(QLatin1String("kid3_") + localeName, QLatin1String(CFG_TRANSLATIONSDIR)) ||
 #endif
-  kid3_tr.load( QString("kid3_") + locale, "." );
+        kid3_tr.load(QLatin1String("kid3_") + localeName, QLatin1String("."))
+        ) {
+      break;
+    }
+  }
   app.installTranslator(&kid3_tr);
 
-#ifdef __APPLE__
+#ifdef Q_OS_MAC
  QDir dir(QApplication::applicationDirPath());
  dir.cdUp();
- dir.cd("PlugIns");
+ dir.cd(QLatin1String("PlugIns"));
  QApplication::setLibraryPaths(QStringList(dir.absolutePath()));
 #endif
 
   Kid3MainWindow* kid3 = new Kid3MainWindow;
+  kid3->setAttribute(Qt::WA_DeleteOnClose);
   kid3->show();
   if (argc > 1) {
     kid3->confirmedOpenDirectory(QFile::decodeName(argv[1]));
+  } else if (ConfigStore::s_miscCfg.m_loadLastOpenedFile &&
+             !ConfigStore::s_miscCfg.m_lastOpenedFile.isEmpty()) {
+    kid3->confirmedOpenDirectory(ConfigStore::s_miscCfg.m_lastOpenedFile);
   }
   return app.exec();
 }
