@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 11-Jan-2009
  *
- * Copyright (C) 2009-2012  Urs Fleisch
+ * Copyright (C) 2009-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -51,14 +51,14 @@
  */
 static QString getToolTip()
 {
-  QString str = "<table>\n";
+  QString str = QLatin1String("<table>\n");
   str += FrameFormatReplacer::getToolTip(true);
 
-  str += "<tr><td>%ua...</td><td>%u{artist}...</td><td>";
+  str += QLatin1String("<tr><td>%ua...</td><td>%u{artist}...</td><td>");
   str += QCM_translate(I18N_NOOP("Encode as URL"));
-  str += "</td></tr>\n";
+  str += QLatin1String("</td></tr>\n");
 
-  str += "</table>\n";
+  str += QLatin1String("</table>\n");
   return str;
 }
 
@@ -70,14 +70,12 @@ static QString getToolTip()
 BrowseCoverArtDialog::BrowseCoverArtDialog(QWidget* parent) :
   QDialog(parent), m_process(0)
 {
-  setObjectName("BrowseCoverArtDialog");
+  setObjectName(QLatin1String("BrowseCoverArtDialog"));
   setModal(true);
   setWindowTitle(i18n("Browse Cover Art"));
   setSizeGripEnabled(true);
 
   QVBoxLayout* vlayout = new QVBoxLayout(this);
-  vlayout->setMargin(6);
-  vlayout->setSpacing(6);
 
   m_edit = new QTextEdit(this);
   m_edit->setReadOnly(true);
@@ -87,7 +85,6 @@ BrowseCoverArtDialog::BrowseCoverArtDialog(QWidget* parent) :
   m_artistLineEdit = new QLineEdit(artistAlbumBox);
   m_albumLineEdit = new QLineEdit(artistAlbumBox);
   QHBoxLayout* hbox = new QHBoxLayout;
-  hbox->setMargin(2);
   hbox->addWidget(m_artistLineEdit);
   hbox->addWidget(m_albumLineEdit);
   artistAlbumBox->setLayout(hbox);
@@ -106,7 +103,6 @@ BrowseCoverArtDialog::BrowseCoverArtDialog(QWidget* parent) :
         srcbox);
 
   QVBoxLayout* vbox = new QVBoxLayout;
-  vbox->setMargin(2);
   vbox->addWidget(m_formatListEdit);
   srcbox->setLayout(vbox);
   vlayout->addWidget(srcbox);
@@ -114,21 +110,18 @@ BrowseCoverArtDialog::BrowseCoverArtDialog(QWidget* parent) :
           this, SLOT(showPreview()));
 
   QGroupBox* tabbox = new QGroupBox(i18n("&URL extraction"), this);
-  m_matchUrlTable = new ConfigTable(tabbox);
   m_matchUrlTableModel = new ConfigTableModel(tabbox);
   m_matchUrlTableModel->setLabels(
     QStringList() << i18n("Match") << i18n("Picture URL"));
-  m_matchUrlTable->setModel(m_matchUrlTableModel);
+  m_matchUrlTable = new ConfigTable(m_matchUrlTableModel, tabbox);
   m_matchUrlTable->setHorizontalResizeModes(
       m_matchUrlTableModel->getHorizontalResizeModes());
   QVBoxLayout* tablayout = new QVBoxLayout;
-  tablayout->setMargin(2);
   tablayout->addWidget(m_matchUrlTable);
   tabbox->setLayout(tablayout);
   vlayout->addWidget(tabbox);
 
   QHBoxLayout* hlayout = new QHBoxLayout;
-  hlayout->setSpacing(6);
   QPushButton* helpButton = new QPushButton(i18n("&Help"), this);
   helpButton->setAutoDefault(false);
   hlayout->addWidget(helpButton);
@@ -174,15 +167,15 @@ void BrowseCoverArtDialog::showPreview()
   fmt.replaceEscapedChars();
   fmt.replacePercentCodes(FormatReplacer::FSF_SupportUrlEncode);
   m_url = fmt.getString();
-  QString txt("<p><b>");
+  QString txt(QLatin1String("<p><b>"));
   txt += i18n("Click Browse to start");
-  txt += "</b></p><p><tt>";
+  txt += QLatin1String("</b></p><p><tt>");
   txt += ConfigStore::s_miscCfg.m_browser;
-  txt += " ";
+  txt += QLatin1Char(' ');
   txt += m_url;
-  txt += "</tt></p><p><b>";
+  txt += QLatin1String("</tt></p><p><b>");
   txt += i18n("Then drag the picture from the browser to Kid3.");
-  txt += "</b></p>";
+  txt += QLatin1String("</b></p>");
   m_edit->clear();
   m_edit->append(txt);
 }
@@ -221,10 +214,8 @@ void BrowseCoverArtDialog::readConfig()
   setSourceFromConfig();
   m_matchUrlTableModel->setMap(ConfigStore::s_genCfg.m_matchPictureUrlMap);
 
-  if (ConfigStore::s_genCfg.m_browseCoverArtWindowWidth > 0 &&
-      ConfigStore::s_genCfg.m_browseCoverArtWindowHeight > 0) {
-    resize(ConfigStore::s_genCfg.m_browseCoverArtWindowWidth,
-           ConfigStore::s_genCfg.m_browseCoverArtWindowHeight);
+  if (!ConfigStore::s_genCfg.m_browseCoverArtWindowGeometry.isEmpty()) {
+    restoreGeometry(ConfigStore::s_genCfg.m_browseCoverArtWindowGeometry);
   }
 }
 
@@ -238,8 +229,7 @@ void BrowseCoverArtDialog::saveConfig()
   ConfigStore::s_genCfg.m_pictureSourceNames = formats.at(0);
   ConfigStore::s_genCfg.m_pictureSourceUrls = formats.at(1);
   ConfigStore::s_genCfg.m_matchPictureUrlMap = m_matchUrlTableModel->getMap();
-  ConfigStore::s_genCfg.m_browseCoverArtWindowWidth = size().width();
-  ConfigStore::s_genCfg.m_browseCoverArtWindowHeight = size().height();
+  ConfigStore::s_genCfg.m_browseCoverArtWindowGeometry = saveGeometry();
 
   setSourceFromConfig();
 }
@@ -249,7 +239,7 @@ void BrowseCoverArtDialog::saveConfig()
  */
 void BrowseCoverArtDialog::showHelp()
 {
-  ContextHelp::displayHelp("browse_pictures");
+  ContextHelp::displayHelp(QLatin1String("browse_pictures"));
 }
 
 /**
