@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2012  Urs Fleisch
+ * Copyright (C) 2003-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -39,12 +39,13 @@
 #include <QComboBox>
 #include <QLineEdit>
 #include <QTabWidget>
+#include <QListView>
 #include <QSpinBox>
-#include "qtcompatmac.h"
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QGroupBox>
 #include <QStringListModel>
+#include "qtcompatmac.h"
 #ifndef CONFIG_USE_KDE
 #include <QApplication>
 #include <QFontDialog>
@@ -61,6 +62,7 @@
 #include "stringlistedit.h"
 #include "configtable.h"
 #include "commandstablemodel.h"
+#include "checkablestringlistmodel.h"
 #include "contexthelp.h"
 #include "configstore.h"
 
@@ -76,7 +78,7 @@ enum { TextEncodingV1Latin1Index = 13 };
  */
 static QString getTextEncodingV1CodecName(const QString& comboEntry)
 {
-  int braceIdx = comboEntry.indexOf(" (");
+  int braceIdx = comboEntry.indexOf(QLatin1String(" ("));
   return braceIdx == -1 ? comboEntry : comboEntry.left(braceIdx);
 }
 #endif
@@ -90,31 +92,29 @@ static QString getTextEncodingV1CodecName(const QString& comboEntry)
 #ifdef CONFIG_USE_KDE
 ConfigDialog::ConfigDialog(QWidget* parent, QString& caption,
                            KConfigSkeleton* configSkeleton) :
-  KConfigDialog(parent, "configure", configSkeleton)
+  KConfigDialog(parent, QLatin1String("configure"), configSkeleton)
 #else
 ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
   QDialog(parent)
 #endif
 {
-  setObjectName("ConfigDialog");
+  setObjectName(QLatin1String("ConfigDialog"));
   setWindowTitle(caption);
   setSizeGripEnabled(true);
 #ifndef CONFIG_USE_KDE
   QVBoxLayout* topLayout = new QVBoxLayout(this);
-  topLayout->setSpacing(6);
-  topLayout->setMargin(6);
   QTabWidget* tabWidget = new QTabWidget(this);
+  tabWidget->setUsesScrollButtons(false);
 #endif
 
   {
     QWidget* tagsPage = new QWidget;
     QVBoxLayout* vlayout = new QVBoxLayout(tagsPage);
-    vlayout->setMargin(6);
-    vlayout->setSpacing(6);
-    QGroupBox* v1GroupBox = new QGroupBox(i18n("ID3v1"), tagsPage);
+
+    QWidget* tag1Page = new QWidget;
+    QVBoxLayout* tag1Layout = new QVBoxLayout(tag1Page);
+    QGroupBox* v1GroupBox = new QGroupBox(i18n("ID3v1"), tag1Page);
     QGridLayout* v1GroupBoxLayout = new QGridLayout(v1GroupBox);
-    v1GroupBoxLayout->setMargin(2);
-    v1GroupBoxLayout->setSpacing(4);
     m_markTruncationsCheckBox = new QCheckBox(i18n("&Mark truncated fields"), v1GroupBox);
     v1GroupBoxLayout->addWidget(m_markTruncationsCheckBox, 0, 0, 1, 2);
 #if defined HAVE_ID3LIB || defined HAVE_TAGLIB
@@ -183,7 +183,7 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
     const char* const* str = codecs;
     m_textEncodingV1List.clear();
     while (*str) {
-      m_textEncodingV1List += *str++;
+      m_textEncodingV1List += QString::fromLatin1(*str++);
     }
     m_textEncodingV1ComboBox->addItems(m_textEncodingV1List);
     m_textEncodingV1ComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
@@ -191,12 +191,13 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
     v1GroupBoxLayout->addWidget(textEncodingV1Label, 1, 0);
     v1GroupBoxLayout->addWidget(m_textEncodingV1ComboBox, 1, 1);
 #endif
-    vlayout->addWidget(v1GroupBox);
+    tag1Layout->addWidget(v1GroupBox);
+    tag1Layout->addStretch();
 
-    QGroupBox* v2GroupBox = new QGroupBox(i18n("ID3v2"), tagsPage);
+    QWidget* tag2Page = new QWidget;
+    QVBoxLayout* tag2Layout = new QVBoxLayout(tag2Page);
+    QGroupBox* v2GroupBox = new QGroupBox(i18n("ID3v2"), tag2Page);
     QGridLayout* v2GroupBoxLayout = new QGridLayout(v2GroupBox);
-    v2GroupBoxLayout->setMargin(2);
-    v2GroupBoxLayout->setSpacing(4);
     m_totalNumTracksCheckBox = new QCheckBox(i18n("Use &track/total number of tracks format"), v2GroupBox);
     v2GroupBoxLayout->addWidget(m_totalNumTracksCheckBox, 0, 0, 1, 2);
     QLabel* trackNumberDigitsLabel = new QLabel(i18n("Track number &digits:"), v2GroupBox);
@@ -215,11 +216,16 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
     v2GroupBoxLayout->addWidget(textEncodingLabel, 2, 0);
     v2GroupBoxLayout->addWidget(m_textEncodingComboBox, 2, 1);
 #endif
-#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
+#if defined HAVE_TAGLIB && (defined HAVE_ID3LIB || defined HAVE_TAGLIB_ID3V23_SUPPORT)
     QLabel* id3v2VersionLabel = new QLabel(i18n("&Version used for new tags:"), v2GroupBox);
     m_id3v2VersionComboBox = new QComboBox(v2GroupBox);
-    m_id3v2VersionComboBox->insertItem(MiscConfig::ID3v2_3_0, i18n("ID3v2.3.0 (id3lib)"));
-    m_id3v2VersionComboBox->insertItem(MiscConfig::ID3v2_4_0, i18n("ID3v2.4.0 (TagLib)"));
+#ifdef HAVE_ID3LIB
+    m_id3v2VersionComboBox->addItem(i18n("ID3v2.3.0 (id3lib)"), MiscConfig::ID3v2_3_0);
+#endif
+    m_id3v2VersionComboBox->addItem(i18n("ID3v2.4.0 (TagLib)"), MiscConfig::ID3v2_4_0);
+#ifdef HAVE_TAGLIB_ID3V23_SUPPORT
+    m_id3v2VersionComboBox->addItem(i18n("ID3v2.3.0 (TagLib)"), MiscConfig::ID3v2_3_0_TAGLIB);
+#endif
     m_id3v2VersionComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
     id3v2VersionLabel->setBuddy(m_id3v2VersionComboBox);
     v2GroupBoxLayout->addWidget(id3v2VersionLabel, 3, 0);
@@ -228,50 +234,72 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
     trackNumberDigitsLabel->setBuddy(m_trackNumberDigitsSpinBox);
     v2GroupBoxLayout->addWidget(trackNumberDigitsLabel, 4, 0);
     v2GroupBoxLayout->addWidget(m_trackNumberDigitsSpinBox, 4, 1);
-    vlayout->addWidget(v2GroupBox);
+    tag2Layout->addWidget(v2GroupBox);
 #ifdef HAVE_VORBIS
-    QGroupBox* vorbisGroupBox = new QGroupBox(i18n("Ogg/Vorbis"), tagsPage);
-    QLabel* commentNameLabel = new QLabel(i18n("Comment field &name:"), vorbisGroupBox);
+    QGroupBox* vorbisGroupBox = new QGroupBox(i18n("Ogg/Vorbis"), tag2Page);
+    QLabel* commentNameLabel = new QLabel(i18n("Co&mment field name:"), vorbisGroupBox);
     m_commentNameComboBox = new QComboBox(vorbisGroupBox);
     QLabel* pictureNameLabel = new QLabel(i18n("&Picture field name:"), vorbisGroupBox);
     m_pictureNameComboBox = new QComboBox(vorbisGroupBox);
     m_commentNameComboBox->setEditable(true);
     QStringList items;
-    items += "COMMENT";
-    items += "DESCRIPTION";
+    items += QLatin1String("COMMENT");
+    items += QLatin1String("DESCRIPTION");
     m_commentNameComboBox->addItems(items);
     m_commentNameComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
     commentNameLabel->setBuddy(m_commentNameComboBox);
-    m_pictureNameComboBox->addItems(QStringList() << "METADATA_BLOCK_PICTURE" << "COVERART");
+    m_pictureNameComboBox->addItems(QStringList() << QLatin1String("METADATA_BLOCK_PICTURE") << QLatin1String("COVERART"));
     m_pictureNameComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
     pictureNameLabel->setBuddy(m_pictureNameComboBox);
     QGridLayout* vorbisGroupBoxLayout = new QGridLayout(vorbisGroupBox);
-    vorbisGroupBoxLayout->setMargin(2);
-    vorbisGroupBoxLayout->setSpacing(4);
     vorbisGroupBoxLayout->addWidget(commentNameLabel, 0, 0);
     vorbisGroupBoxLayout->addWidget(m_commentNameComboBox, 0, 1);
     vorbisGroupBoxLayout->addWidget(pictureNameLabel, 1, 0);
     vorbisGroupBoxLayout->addWidget(m_pictureNameComboBox, 1, 1);
     vorbisGroupBox->setLayout(vorbisGroupBoxLayout);
-    vlayout->addWidget(vorbisGroupBox);
+    tag2Layout->addWidget(vorbisGroupBox);
 #endif
-    QHBoxLayout* hlayout = new QHBoxLayout;
-    QGroupBox* genresGroupBox = new QGroupBox(i18n("Custom &Genres"), tagsPage);
+    QHBoxLayout* genresQuickAccessLayout = new QHBoxLayout;
+    QGroupBox* genresGroupBox = new QGroupBox(i18n("Custom &Genres"), tag2Page);
     m_onlyCustomGenresCheckBox = new QCheckBox(i18n("&Show only custom genres"), genresGroupBox);
     m_genresEditModel = new QStringListModel(genresGroupBox);
     StringListEdit* genresEdit = new StringListEdit(m_genresEditModel, genresGroupBox);
     QVBoxLayout* vbox = new QVBoxLayout;
-    vbox->setMargin(2);
     vbox->addWidget(m_onlyCustomGenresCheckBox);
     vbox->addWidget(genresEdit);
     genresGroupBox->setLayout(vbox);
-    hlayout->addWidget(genresGroupBox);
+    genresQuickAccessLayout->addWidget(genresGroupBox);
+
+    QGroupBox* quickAccessTagsGroupBox = new QGroupBox(i18n("&Quick Access Tags"));
+    QVBoxLayout* quickAccessTagsLayout = new QVBoxLayout(quickAccessTagsGroupBox);
+    QListView* quickAccessTagsListView = new QListView;
+    m_quickAccessTagsModel = new CheckableStringListModel(quickAccessTagsGroupBox);
+    QStringList unifiedFrameNames;
+    for (int i = Frame::FT_FirstFrame; i< Frame::FT_LastFrame; ++i) {
+      unifiedFrameNames.append(
+          Frame::ExtendedType(static_cast<Frame::Type>(i)).getTranslatedName());
+    }
+    m_quickAccessTagsModel->setStringList(unifiedFrameNames);
+    quickAccessTagsListView->setModel(m_quickAccessTagsModel);
+    quickAccessTagsLayout->addWidget(quickAccessTagsListView);
+    genresQuickAccessLayout->addWidget(quickAccessTagsGroupBox);
+    tag2Layout->addLayout(genresQuickAccessLayout);
+
+    QWidget* tag1AndTag2Page = new QWidget;
+    QVBoxLayout* tag1AndTag2Layout = new QVBoxLayout(tag1AndTag2Page);
     QString id3FormatTitle(i18n("&Tag Format"));
-    m_id3FormatBox = new FormatBox(id3FormatTitle, tagsPage);
-    hlayout->addWidget(m_id3FormatBox);
-    vlayout->addLayout(hlayout);
+    m_id3FormatBox = new FormatBox(id3FormatTitle, tag1AndTag2Page);
+    tag1AndTag2Layout->addWidget(m_id3FormatBox);
+
+    QTabWidget* tagsTabWidget = new QTabWidget;
+    tagsTabWidget->addTab(tag1Page, i18n("Tag &1"));
+    tagsTabWidget->addTab(tag2Page, i18n("Tag &2"));
+    tagsTabWidget->addTab(tag1AndTag2Page, i18n("Tag 1 a&nd Tag 2"));
+    tagsTabWidget->setCurrentIndex(1);
+    vlayout->addWidget(tagsTabWidget);
+
 #ifdef CONFIG_USE_KDE
-    addPage(tagsPage, i18n("Tags"), "applications-multimedia");
+    addPage(tagsPage, i18n("Tags"), QLatin1String("applications-multimedia"));
 #else
     tabWidget->addTab(tagsPage, i18n("&Tags"));
 #endif
@@ -280,22 +308,34 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
   {
     QWidget* filesPage = new QWidget;
     QVBoxLayout* vlayout = new QVBoxLayout(filesPage);
-    vlayout->setMargin(6);
-    vlayout->setSpacing(6);
+    QGroupBox* startupGroupBox = new QGroupBox(i18n("Startup"), filesPage);
+    m_loadLastOpenedFileCheckBox = new QCheckBox(i18n("&Load last-opened files"),
+                                                 startupGroupBox);
+    QVBoxLayout* startupLayout = new QVBoxLayout;
+    startupLayout->addWidget(m_loadLastOpenedFileCheckBox);
+    startupGroupBox->setLayout(startupLayout);
+    vlayout->addWidget(startupGroupBox);
     QGroupBox* saveGroupBox = new QGroupBox(i18n("Save"), filesPage);
     m_preserveTimeCheckBox = new QCheckBox(i18n("&Preserve file timestamp"), saveGroupBox);
     m_markChangesCheckBox = new QCheckBox(i18n("&Mark changes"), saveGroupBox);
+    QLabel* coverFileNameLabel = new QLabel(i18n("F&ilename for cover:"), saveGroupBox);
+    m_coverFileNameLineEdit = new QLineEdit(saveGroupBox);
+    coverFileNameLabel->setBuddy(m_coverFileNameLineEdit);
+    QHBoxLayout* hbox = new QHBoxLayout;
+    hbox->setContentsMargins(2, 0, 2, 0);
+    hbox->addWidget(coverFileNameLabel);
+    hbox->addWidget(m_coverFileNameLineEdit);
     QVBoxLayout* vbox = new QVBoxLayout;
-    vbox->setMargin(2);
     vbox->addWidget(m_preserveTimeCheckBox);
     vbox->addWidget(m_markChangesCheckBox);
+    vbox->addLayout(hbox);
     saveGroupBox->setLayout(vbox);
     vlayout->addWidget(saveGroupBox);
     QString fnFormatTitle(i18n("&Filename Format"));
     m_fnFormatBox = new FormatBox(fnFormatTitle, filesPage);
     vlayout->addWidget(m_fnFormatBox);
 #ifdef CONFIG_USE_KDE
-    addPage(filesPage, i18n("Files"), "document-save");
+    addPage(filesPage, i18n("Files"), QLatin1String("document-save"));
 #else
     tabWidget->addTab(filesPage, i18n("&Files"));
 #endif
@@ -304,14 +344,11 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
   {
     QWidget* actionsPage = new QWidget;
     QVBoxLayout* vlayout = new QVBoxLayout(actionsPage);
-    vlayout->setMargin(6);
-    vlayout->setSpacing(6);
     QGroupBox* browserGroupBox = new QGroupBox(i18n("Browser"), actionsPage);
     QLabel* browserLabel = new QLabel(i18n("Web &browser:"), browserGroupBox);
     m_browserLineEdit = new QLineEdit(browserGroupBox);
     browserLabel->setBuddy(m_browserLineEdit);
     QHBoxLayout* hbox = new QHBoxLayout;
-    hbox->setMargin(2);
     hbox->addWidget(browserLabel);
     hbox->addWidget(m_browserLineEdit);
     browserGroupBox->setLayout(hbox);
@@ -321,18 +358,16 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
     m_playOnDoubleClickCheckBox =
         new QCheckBox(i18n("&Play on double click"), commandsGroupBox);
     m_commandsTableModel = new CommandsTableModel(commandsGroupBox);
-    m_commandsTable = new ConfigTable(commandsGroupBox);
-    m_commandsTable->setModel(m_commandsTableModel);
+    m_commandsTable = new ConfigTable(m_commandsTableModel, commandsGroupBox);
     m_commandsTable->setHorizontalResizeModes(
       m_commandsTableModel->getHorizontalResizeModes());
     QVBoxLayout* commandsLayout = new QVBoxLayout;
-    commandsLayout->setMargin(2);
     commandsLayout->addWidget(m_playOnDoubleClickCheckBox);
     commandsLayout->addWidget(m_commandsTable);
     commandsGroupBox->setLayout(commandsLayout);
     vlayout->addWidget(commandsGroupBox);
 #ifdef CONFIG_USE_KDE
-    addPage(actionsPage, i18n("User Actions"), "preferences-other");
+    addPage(actionsPage, i18n("User Actions"), QLatin1String("preferences-other"));
 #else
     tabWidget->addTab(actionsPage, i18n("&User Actions"));
 #endif
@@ -341,8 +376,6 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
   {
     QWidget* networkPage = new QWidget;
     QVBoxLayout* vlayout = new QVBoxLayout(networkPage);
-    vlayout->setMargin(6);
-    vlayout->setSpacing(6);
     QGroupBox* proxyGroupBox = new QGroupBox(i18n("Proxy"), networkPage);
     m_proxyCheckBox = new QCheckBox(i18n("&Proxy:"), proxyGroupBox);
     m_proxyLineEdit = new QLineEdit(proxyGroupBox);
@@ -355,9 +388,7 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
     proxyPasswordLabel->setBuddy(m_proxyPasswordLineEdit);
     m_proxyPasswordLineEdit->setEchoMode(QLineEdit::Password);
     QVBoxLayout* vbox = new QVBoxLayout;
-    vbox->setMargin(2);
     QHBoxLayout* proxyHbox = new QHBoxLayout;
-    proxyHbox->setMargin(2);
     proxyHbox->addWidget(m_proxyCheckBox);
     proxyHbox->addWidget(m_proxyLineEdit);
     vbox->addLayout(proxyHbox);
@@ -374,7 +405,7 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
     QSpacerItem* vspacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
     vlayout->addItem(vspacer);
 #ifdef CONFIG_USE_KDE
-    addPage(networkPage, i18n("Network"), "preferences-system-network");
+    addPage(networkPage, i18n("Network"), QLatin1String("preferences-system-network"));
 #else
     tabWidget->addTab(networkPage, i18n("&Network"));
 #endif
@@ -385,8 +416,6 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
     QWidget* shortcutsPage = new QWidget;
     m_shortcutsModel = 0;
     QVBoxLayout* vlayout = new QVBoxLayout(shortcutsPage);
-    vlayout->setMargin(6);
-    vlayout->setSpacing(6);
     m_shortcutsTreeView = new QTreeView;
     m_shortcutsTreeView->setSelectionMode(QAbstractItemView::NoSelection);
     m_shortcutsTreeView->setItemDelegateForColumn(
@@ -400,16 +429,12 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
   {
     QWidget* appearancePage = new QWidget;
     QVBoxLayout* vlayout = new QVBoxLayout(appearancePage);
-    vlayout->setMargin(6);
-    vlayout->setSpacing(6);
     QGridLayout* fontStyleLayout = new QGridLayout;
 
     m_useApplicationFontCheckBox = new QCheckBox(i18n("Use custom app&lication font"), appearancePage);
     m_applicationFontButton = new QPushButton(i18n("A&pplication Font..."), appearancePage);
     m_useApplicationStyleCheckBox = new QCheckBox(i18n("Use custom application &style"), appearancePage);
     m_applicationStyleComboBox = new QComboBox(appearancePage);
-    fontStyleLayout->setMargin(0);
-    fontStyleLayout->setSpacing(4);
     fontStyleLayout->addWidget(m_useApplicationFontCheckBox, 0, 0);
     fontStyleLayout->addWidget(m_applicationFontButton, 0, 1);
     fontStyleLayout->addWidget(m_useApplicationStyleCheckBox, 1, 0);
@@ -451,7 +476,7 @@ ConfigDialog::ConfigDialog(QWidget* parent, QString& caption) :
   topLayout->addLayout(hlayout);
 #else
   setButtons(Ok | Cancel | Help);
-  setHelp("configure-kid3");
+  setHelp(QLatin1String("configure-kid3"));
 #endif
 }
 
@@ -476,10 +501,13 @@ void ConfigDialog::setConfig(const ConfigStore* cfg)
   m_id3FormatBox->fromFormatConfig(id3Cfg);
   m_markTruncationsCheckBox->setChecked(miscCfg->m_markTruncations);
   m_totalNumTracksCheckBox->setChecked(miscCfg->m_enableTotalNumberOfTracks);
+  m_loadLastOpenedFileCheckBox->setChecked(miscCfg->m_loadLastOpenedFile);
   m_preserveTimeCheckBox->setChecked(miscCfg->m_preserveTime);
   m_markChangesCheckBox->setChecked(miscCfg->m_markChanges);
+  m_coverFileNameLineEdit->setText(miscCfg->m_defaultCoverFileName);
   m_onlyCustomGenresCheckBox->setChecked(miscCfg->m_onlyCustomGenres);
   m_genresEditModel->setStringList(miscCfg->m_customGenres);
+  m_quickAccessTagsModel->setBitMask(miscCfg->m_quickAccessFrames);
   m_commandsTableModel->setCommandList(miscCfg->m_contextMenuCommands);
 #ifdef HAVE_VORBIS
   int idx = m_commentNameComboBox->findText(miscCfg->m_commentName);
@@ -507,8 +535,9 @@ void ConfigDialog::setConfig(const ConfigStore* cfg)
   m_textEncodingV1ComboBox->setCurrentIndex(textEncodingV1Index);
   m_textEncodingComboBox->setCurrentIndex(miscCfg->m_textEncoding);
 #endif
-#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
-  m_id3v2VersionComboBox->setCurrentIndex(miscCfg->m_id3v2Version);
+#if defined HAVE_TAGLIB && (defined HAVE_ID3LIB || defined HAVE_TAGLIB_ID3V23_SUPPORT)
+  m_id3v2VersionComboBox->setCurrentIndex(
+        m_id3v2VersionComboBox->findData(miscCfg->m_id3v2Version));
 #endif
   m_trackNumberDigitsSpinBox->setValue(miscCfg->m_trackNumberDigits);
   m_browserLineEdit->setText(miscCfg->m_browser);
@@ -560,10 +589,13 @@ void ConfigDialog::getConfig(ConfigStore* cfg) const
   m_id3FormatBox->toFormatConfig(id3Cfg);
   miscCfg->m_markTruncations = m_markTruncationsCheckBox->isChecked();
   miscCfg->m_enableTotalNumberOfTracks = m_totalNumTracksCheckBox->isChecked();
+  miscCfg->m_loadLastOpenedFile = m_loadLastOpenedFileCheckBox->isChecked();
   miscCfg->m_preserveTime = m_preserveTimeCheckBox->isChecked();
   miscCfg->m_markChanges = m_markChangesCheckBox->isChecked();
+  miscCfg->m_defaultCoverFileName = m_coverFileNameLineEdit->text();
   miscCfg->m_onlyCustomGenres = m_onlyCustomGenresCheckBox->isChecked();
   miscCfg->m_customGenres = m_genresEditModel->stringList();
+  miscCfg->m_quickAccessFrames = m_quickAccessTagsModel->getBitMask();
   miscCfg->m_contextMenuCommands = m_commandsTableModel->getCommandList();
 #ifdef HAVE_VORBIS
   miscCfg->m_commentName = m_commentNameComboBox->currentText();
@@ -575,8 +607,9 @@ void ConfigDialog::getConfig(ConfigStore* cfg) const
     getTextEncodingV1CodecName(m_textEncodingV1ComboBox->currentText());
   miscCfg->m_textEncoding = m_textEncodingComboBox->currentIndex();
 #endif
-#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
-  miscCfg->m_id3v2Version = m_id3v2VersionComboBox->currentIndex();
+#if defined HAVE_TAGLIB && (defined HAVE_ID3LIB || defined HAVE_TAGLIB_ID3V23_SUPPORT)
+  miscCfg->m_id3v2Version = m_id3v2VersionComboBox->itemData(
+        m_id3v2VersionComboBox->currentIndex()).toInt();
 #endif
   miscCfg->m_trackNumberDigits = m_trackNumberDigitsSpinBox->value();
   miscCfg->m_browser = m_browserLineEdit->text();
@@ -598,7 +631,7 @@ void ConfigDialog::getConfig(ConfigStore* cfg) const
   }
   if (!m_useApplicationStyleCheckBox->isChecked() ||
       m_applicationStyleComboBox->currentIndex() == 0) {
-    miscCfg->m_style = "";
+    miscCfg->m_style = QLatin1String("");
   } else {
     miscCfg->m_style = m_applicationStyleComboBox->currentText();
   }
@@ -611,7 +644,7 @@ void ConfigDialog::getConfig(ConfigStore* cfg) const
  */
 void ConfigDialog::slotHelp()
 {
-  ContextHelp::displayHelp("configure-kid3");
+  ContextHelp::displayHelp(QLatin1String("configure-kid3"));
 }
 
 #ifndef CONFIG_USE_KDE
@@ -628,7 +661,7 @@ void ConfigDialog::warnAboutAlreadyUsedShortcut(
   m_shortcutAlreadyUsedLabel->setText(
         i18n("The keyboard shortcut '%1' is already assigned to '%2'.").
         arg(key).
-        arg(context + '/' + (action ? action->text().remove('&') : "?")));
+        arg(context + QLatin1Char('/') + (action ? action->text().remove(QLatin1Char('&')) : QLatin1String("?"))));
 }
 
 /**
