@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2007  Urs Fleisch
+ * Copyright (C) 2003-2012  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -49,6 +49,7 @@ class QComboBox;
 class QLineEdit;
 class QSpinBox;
 class QStringListModel;
+class CheckableStringListModel;
 class ConfigStore;
 
 /** Base class for configuration dialog. */
@@ -145,11 +146,14 @@ private:
 #ifndef CONFIG_USE_KDE
   void setShortcutsModel(ShortcutsModel* model);
 #endif
-
+  /** Load last-opened files checkbox */
+  QCheckBox* m_loadLastOpenedFileCheckBox;
   /** Preserve timestamp checkbox */
   QCheckBox* m_preserveTimeCheckBox;
   /** Mark changes checkbox */
   QCheckBox* m_markChangesCheckBox;
+  /** Filename for cover lineedit */
+  QLineEdit* m_coverFileNameLineEdit;
   /** Mark truncated fields checkbox */
   QCheckBox* m_markTruncationsCheckBox;
   /** ID3v1 text encodings */
@@ -168,7 +172,7 @@ private:
   /** ID3v2 text encoding combo box */
   QComboBox* m_textEncodingComboBox;
 #endif
-#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
+#if defined HAVE_TAGLIB && (defined HAVE_ID3LIB || defined HAVE_TAGLIB_ID3V23_SUPPORT)
   /** ID3v2 version combo box */
   QComboBox* m_id3v2VersionComboBox;
 #endif
@@ -182,6 +186,8 @@ private:
   QCheckBox* m_onlyCustomGenresCheckBox;
   /** Model with list of custom genres */
   QStringListModel* m_genresEditModel;
+  /** Model with standard tags selection */
+  CheckableStringListModel* m_quickAccessTagsModel;
   /** Play on double click checkbox */
   QCheckBox* m_playOnDoubleClickCheckBox;
   /** Commands table */
