@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Jun 2009
  *
- * Copyright (C) 2003-2012  Urs Fleisch
+ * Copyright (C) 2003-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -42,11 +42,11 @@
 #include "taggedfile.h"
 #include "qtcompatmac.h"
 #include "config.h"
+#include "configstore.h"
 #ifdef CONFIG_USE_KDE
 #include <kfiledialog.h>
 #else
 #include <QFileDialog>
-#include "configstore.h"
 #endif
 
 /** QTextEdit with label above */
@@ -77,6 +77,13 @@ public:
     m_edit->setPlainText(txt);
   }
 
+  /**
+   * Set focus to text field.
+   */
+  void setFocus() {
+    m_edit->setFocus();
+  }
+
   /**
    * Set label.
    *
@@ -222,12 +229,11 @@ private:
 LabeledTextEdit::LabeledTextEdit(QWidget* parent) :
   QWidget(parent)
 {
-  setObjectName("LabeledTextEdit");
+  setObjectName(QLatin1String("LabeledTextEdit"));
   QVBoxLayout* layout = new QVBoxLayout(this);
   m_label = new QLabel(this);
   m_edit = new QTextEdit(this);
-  layout->setMargin(0);
-  layout->setSpacing(2);
+  layout->setContentsMargins(0, 0, 0, 0);
   m_edit->setAcceptRichText(false);
   layout->addWidget(m_label);
   layout->addWidget(m_edit);
@@ -241,12 +247,11 @@ LabeledTextEdit::LabeledTextEdit(QWidget* parent) :
 LabeledLineEdit::LabeledLineEdit(QWidget* parent) :
   QWidget(parent)
 {
-  setObjectName("LabeledLineEdit");
+  setObjectName(QLatin1String("LabeledLineEdit"));
   QVBoxLayout* layout = new QVBoxLayout(this);
   m_label = new QLabel(this);
   m_edit = new QLineEdit(this);
-  layout->setMargin(0);
-  layout->setSpacing(2);
+  layout->setContentsMargins(0, 0, 0, 0);
   layout->addWidget(m_label);
   layout->addWidget(m_edit);
 }
@@ -260,12 +265,11 @@ LabeledLineEdit::LabeledLineEdit(QWidget* parent) :
 LabeledComboBox::LabeledComboBox(QWidget* parent,
          const char **strlst) : QWidget(parent)
 {
-  setObjectName("LabeledComboBox");
+  setObjectName(QLatin1String("LabeledComboBox"));
   QVBoxLayout* layout = new QVBoxLayout(this);
   m_label = new QLabel(this);
   m_combo = new QComboBox(this);
-  layout->setMargin(0);
-  layout->setSpacing(2);
+  layout->setContentsMargins(0, 0, 0, 0);
   QStringList strList;
   while (*strlst) {
     strList += QCM_translate(*strlst++);
@@ -283,14 +287,13 @@ LabeledComboBox::LabeledComboBox(QWidget* parent,
 LabeledSpinBox::LabeledSpinBox(QWidget* parent) :
   QWidget(parent)
 {
-  setObjectName("LabeledSpinBox");
+  setObjectName(QLatin1String("LabeledSpinBox"));
   QVBoxLayout* layout = new QVBoxLayout(this);
   m_label = new QLabel(this);
   m_spinbox = new QSpinBox(this);
   if (layout && m_label && m_spinbox) {
     m_spinbox->setRange(0, INT_MAX);
-    layout->setMargin(0);
-    layout->setSpacing(2);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_label);
     layout->addWidget(m_spinbox);
   }
@@ -517,15 +520,14 @@ BinaryOpenSave::BinaryOpenSave(QWidget* parent, const Frame::Field& field) :
   QWidget(parent), m_byteArray(field.m_value.toByteArray()),
   m_isChanged(false)
 {
-  setObjectName("BinaryOpenSave");
+  setObjectName(QLatin1String("BinaryOpenSave"));
   QHBoxLayout* layout = new QHBoxLayout(this);
   m_label = new QLabel(this);
   m_clipButton = new QPushButton(i18n("From Clip&board"), this);
   QPushButton* openButton = new QPushButton(i18n("&Import"), this);
   QPushButton* saveButton = new QPushButton(i18n("&Export"), this);
   QPushButton* viewButton = new QPushButton(i18n("&View"), this);
-  layout->setMargin(0);
-  layout->setSpacing(6);
+  layout->setContentsMargins(0, 0, 0, 0);
   layout->addWidget(m_label);
   layout->addWidget(m_clipButton);
   layout->addWidget(openButton);
@@ -546,7 +548,7 @@ void BinaryOpenSave::setClipButtonState()
 {
   QClipboard* cb = QApplication::clipboard();
   m_clipButton->setEnabled(
-    cb && (cb->mimeData()->hasFormat("image/jpeg") ||
+    cb && (cb->mimeData()->hasFormat(QLatin1String("image/jpeg")) ||
            cb->mimeData()->hasImage()));
 }
 
@@ -557,8 +559,8 @@ void BinaryOpenSave::clipData()
 {
   QClipboard* cb = QApplication::clipboard();
   if (cb) {
-    if (cb->mimeData()->hasFormat("image/jpeg")) {
-      m_byteArray = cb->mimeData()->data("image/jpeg");
+    if (cb->mimeData()->hasFormat(QLatin1String("image/jpeg"))) {
+      m_byteArray = cb->mimeData()->data(QLatin1String("image/jpeg"));
       m_isChanged = true;
     } else if (cb->mimeData()->hasImage()) {
       QBuffer buffer(&m_byteArray);
@@ -675,12 +677,16 @@ const char* Mp3FieldControl::getFieldIDString(Frame::Field::Id id) const
     I18N_NOOP("Peak Volume Right"),
     I18N_NOOP("Peak Volume Left"),
     I18N_NOOP("Timestamp Format"),
-    I18N_NOOP("Content Type")
+    I18N_NOOP("Content Type"),
+
+    I18N_NOOP("Price"),
+    I18N_NOOP("Date"),
+    I18N_NOOP("Seller")
   };
   class not_used { int array_size_check[
-      sizeof(idStr) / sizeof(idStr[0]) == Frame::Field::ID_ContentType + 1
+      sizeof(idStr) / sizeof(idStr[0]) == Frame::Field::ID_Seller + 1
       ? 1 : -1 ]; };
-  return idStr[id <= Frame::Field::ID_ContentType ? id : 0];
+  return idStr[id <= Frame::Field::ID_Seller ? id : 0];
 }
 
 /**
@@ -705,6 +711,7 @@ QWidget* TextFieldControl::createWidget(QWidget* parent)
 
   m_edit->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
   m_edit->setText(m_field.m_value.toString());
+  m_edit->setFocus();
   return m_edit;
 }
 
@@ -798,13 +805,13 @@ QWidget* BinFieldControl::createWidget(QWidget* parent)
     m_bos->setDefaultDir(m_taggedFile->getDirname());
   }
   if (m_frame.getType() == Frame::FT_Picture) {
-    m_bos->setDefaultFile("folder.jpg");
+    m_bos->setDefaultFile(ConfigStore::s_miscCfg.m_defaultCoverFileName);
     m_bos->setFilter(
 #ifdef CONFIG_USE_KDE
-          "*.jpg *.jpeg *.png|" +
-          i18n("Images (*.jpg *.jpeg *.png)") + "\n*|" + i18n("All Files (*)")
+          QLatin1String("*.jpg *.jpeg *.png|") +
+          i18n("Images (*.jpg *.jpeg *.png)") + QLatin1String("\n*|") + i18n("All Files (*)")
 #else
-          i18n("Images (*.jpg *.jpeg *.png)") + ";;" + i18n("All Files (*)")
+          i18n("Images (*.jpg *.jpeg *.png)") + QLatin1String(";;") + i18n("All Files (*)")
 #endif
           );
   }
@@ -840,14 +847,12 @@ EditFrameFieldsDialog::EditFrameFieldsDialog(
   const Frame& frame, const TaggedFile* taggedFile) :
   QDialog(parent), m_fields(frame.getFieldList())
 {
-  setObjectName("EditFrameFieldsDialog");
+  setObjectName(QLatin1String("EditFrameFieldsDialog"));
   setModal(true);
   setWindowTitle(caption);
   qDeleteAll(m_fieldcontrols);
   m_fieldcontrols.clear();
   QVBoxLayout* vlayout = new QVBoxLayout(this);
-  vlayout->setSpacing(6);
-  vlayout->setMargin(6);
 
   for (Frame::FieldList::iterator fldIt = m_fields.begin();
        fldIt != m_fields.end();
