@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 May 2006
  *
- * Copyright (C) 2006-2012  Urs Fleisch
+ * Copyright (C) 2006-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -67,14 +67,12 @@ ExportDialog::ExportDialog(QWidget* parent, TextExporter* textExporter) :
   QDialog(parent),
   m_textExporter(textExporter), m_textTableModel(new TextTableModel(this))
 {
-  setObjectName("ExportDialog");
+  setObjectName(QLatin1String("ExportDialog"));
   setModal(true);
   setWindowTitle(i18n("Export"));
   setSizeGripEnabled(true);
 
   QVBoxLayout* vlayout = new QVBoxLayout(this);
-  vlayout->setMargin(6);
-  vlayout->setSpacing(6);
   m_edit = new QTextEdit(this);
   m_edit->setAcceptRichText(false);
   vlayout->addWidget(m_edit);
@@ -100,7 +98,6 @@ ExportDialog::ExportDialog(QWidget* parent, TextExporter* textExporter) :
   vlayout->addWidget(m_formatListEdit);
 
   QHBoxLayout* butlayout = new QHBoxLayout;
-  butlayout->setSpacing(6);
   m_fileButton = new QPushButton(i18n("To F&ile"), this);
   m_fileButton->setAutoDefault(false);
   butlayout->addWidget(m_fileButton);
@@ -129,7 +126,6 @@ ExportDialog::ExportDialog(QWidget* parent, TextExporter* textExporter) :
   vlayout->addLayout(butlayout);
 
   QHBoxLayout* hlayout = new QHBoxLayout;
-  hlayout->setSpacing(6);
   QPushButton* helpButton = new QPushButton(i18n("&Help"), this);
   helpButton->setAutoDefault(false);
   hlayout->addWidget(helpButton);
@@ -237,10 +233,8 @@ void ExportDialog::readConfig()
 
   setFormatFromConfig();
 
-  if (ConfigStore::s_genCfg.m_exportWindowWidth > 0 &&
-      ConfigStore::s_genCfg.m_exportWindowHeight > 0) {
-    resize(ConfigStore::s_genCfg.m_exportWindowWidth,
-           ConfigStore::s_genCfg.m_exportWindowHeight);
+  if (!ConfigStore::s_genCfg.m_exportWindowGeometry.isEmpty()) {
+    restoreGeometry(ConfigStore::s_genCfg.m_exportWindowGeometry);
   }
 }
 
@@ -257,8 +251,7 @@ void ExportDialog::saveConfig()
   ConfigStore::s_genCfg.m_exportFormatHeaders = formats.at(1);
   ConfigStore::s_genCfg.m_exportFormatTracks = formats.at(2);
   ConfigStore::s_genCfg.m_exportFormatTrailers = formats.at(3);
-  ConfigStore::s_genCfg.m_exportWindowWidth = size().width();
-  ConfigStore::s_genCfg.m_exportWindowHeight = size().height();
+  ConfigStore::s_genCfg.m_exportWindowGeometry = saveGeometry();
 
   setFormatFromConfig();
 }
@@ -268,7 +261,7 @@ void ExportDialog::saveConfig()
  */
 void ExportDialog::showHelp()
 {
-  ContextHelp::displayHelp("export");
+  ContextHelp::displayHelp(QLatin1String("export"));
 }
 
 /**
