@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 16 Jan 2008
  *
- * Copyright (C) 2008-2012  Urs Fleisch
+ * Copyright (C) 2008-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -42,16 +42,14 @@
  *
  * @param parent parent widget
  */
-FilterDialog::FilterDialog(QWidget* parent) : QDialog(parent)
+FilterDialog::FilterDialog(QWidget* parent) : QDialog(parent),
+  m_isAbortButton(false)
 {
-  setObjectName("FilterDialog");
-  setModal(true);
+  setObjectName(QLatin1String("FilterDialog"));
   setWindowTitle(i18n("Filter"));
   setSizeGripEnabled(true);
 
   QVBoxLayout* vlayout = new QVBoxLayout(this);
-  vlayout->setMargin(6);
-  vlayout->setSpacing(6);
   m_edit = new QTextEdit(this);
   m_edit->setReadOnly(true);
   m_edit->setTabStopWidth(20);
@@ -67,7 +65,6 @@ FilterDialog::FilterDialog(QWidget* parent) : QDialog(parent)
   vlayout->addWidget(m_formatListEdit);
 
   QHBoxLayout* hlayout = new QHBoxLayout;
-  hlayout->setSpacing(6);
   QPushButton* helpButton = new QPushButton(i18n("&Help"), this);
   helpButton->setAutoDefault(false);
   hlayout->addWidget(helpButton);
@@ -82,16 +79,16 @@ FilterDialog::FilterDialog(QWidget* parent) : QDialog(parent)
                                          QSizePolicy::Minimum);
   hlayout->addItem(hspacer);
 
-  m_applyButton = new QPushButton(i18n("&Apply"), this);
+  m_applyButton = new QPushButton(this);
+  setAbortButton(false);
   QPushButton* closeButton = new QPushButton(i18n("&Close"), this);
   m_applyButton->setAutoDefault(false);
   closeButton->setAutoDefault(false);
   hlayout->addWidget(m_applyButton);
   hlayout->addWidget(closeButton);
-  connect(m_applyButton, SIGNAL(clicked()), this, SLOT(applyFilter()));
+  connect(m_applyButton, SIGNAL(clicked()), this, SLOT(applyOrAbortFilter()));
   connect(closeButton, SIGNAL(clicked()), this, SLOT(reject()));
-  connect(closeButton, SIGNAL(clicked()),
-          &m_fileFilter, SLOT(setAbortFlag()));
+  connect(this, SIGNAL(rejected()), &m_fileFilter, SLOT(abort()));
 
   vlayout->addLayout(hlayout);
 }
@@ -103,16 +100,18 @@ FilterDialog::~FilterDialog()
 {}
 
 /**
- * Apply filter.
+ * Apply or abort filter.
  */
-void FilterDialog::applyFilter()
+void FilterDialog::applyOrAbortFilter()
 {
-  m_edit->clear();
-  m_fileFilter.setFilterExpression(m_formatListEdit->getCurrentFormat(1));
-  m_fileFilter.initParser();
-  m_applyButton->setEnabled(false);
-  emit apply(m_fileFilter);
-  m_applyButton->setEnabled(true);
+  if (m_isAbortButton) {
+    m_fileFilter.abort();
+  } else {
+    m_edit->clear();
+    m_fileFilter.setFilterExpression(m_formatListEdit->getCurrentFormat(1));
+    m_fileFilter.initParser();
+    emit apply(m_fileFilter);
+  }
 }
 
 /**
@@ -131,16 +130,14 @@ void FilterDialog::setFiltersFromConfig()
  */
 void FilterDialog::readConfig()
 {
-  m_fileFilter.clearAbortFlag();
+  m_fileFilter.clearAborted();
   m_edit->clear();
-  m_applyButton->setEnabled(true);
+  setAbortButton(false);
 
   setFiltersFromConfig();
 
-  if (ConfigStore::s_filterCfg.m_windowWidth > 0 &&
-      ConfigStore::s_filterCfg.m_windowHeight > 0) {
-    resize(ConfigStore::s_filterCfg.m_windowWidth,
-           ConfigStore::s_filterCfg.m_windowHeight);
+  if (!ConfigStore::s_filterCfg.m_windowGeometry.isEmpty()) {
+    restoreGeometry(ConfigStore::s_filterCfg.m_windowGeometry);
   }
 }
 
@@ -153,8 +150,7 @@ void FilterDialog::saveConfig()
         &ConfigStore::s_filterCfg.m_filterIdx);
   ConfigStore::s_filterCfg.m_filterNames = formats.at(0);
   ConfigStore::s_filterCfg.m_filterExpressions = formats.at(1);
-  ConfigStore::s_filterCfg.m_windowWidth = size().width();
-  ConfigStore::s_filterCfg.m_windowHeight = size().height();
+  ConfigStore::s_filterCfg.m_windowGeometry = saveGeometry();
 
   setFiltersFromConfig();
 }
@@ -164,7 +160,7 @@ void FilterDialog::saveConfig()
  */
 void FilterDialog::showHelp()
 {
-  ContextHelp::displayHelp("filter");
+  ContextHelp::displayHelp(QLatin1String("filter"));
 }
 
 /**
@@ -173,14 +169,39 @@ void FilterDialog::showHelp()
 void FilterDialog::showFilterEvent(FileFilter::FilterEventType type,
                                    const QString& fileName) {
   switch (type) {
+  case FileFilter::Started:
+    m_edit->append(i18n("Started"));
+    setAbortButton(true);
+    break;
+  case FileFilter::Directory:
+    m_edit->append(QLatin1Char('\t') + fileName);
+    break;
   case FileFilter::ParseError:
-    m_edit->append("parse error");
+    m_edit->append(QLatin1String("parse error"));
     break;
   case FileFilter::FilePassed:
-    m_edit->append(QString("+\t") + fileName);
+    m_edit->append(QLatin1String("+\t") + fileName);
     break;
   case FileFilter::FileFilteredOut:
-    m_edit->append(QString("-\t") + fileName);
+    m_edit->append(QLatin1String("-\t") + fileName);
+    break;
+  case FileFilter::Finished:
+    m_edit->append(i18n("Finished"));
+    setAbortButton(false);
+    break;
+  case FileFilter::Aborted:
+    m_edit->append(i18n("Aborted"));
+    setAbortButton(false);
     break;
   }
 }
+
+/**
+ * Set button to Start or Abort.
+ * @param enableAbort true to set Abort button
+ */
+void FilterDialog::setAbortButton(bool enableAbort)
+{
+  m_isAbortButton = enableAbort;
+  m_applyButton->setText(m_isAbortButton ? i18n("A&bort") : i18n("&Apply"));
+}
