@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2012  Urs Fleisch
+ * Copyright (C) 2003-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -101,7 +101,7 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
   m_trackDataModel(trackDataModel), m_importers(importers),
   m_musicBrainzClient(mbClient)
 {
-  setObjectName("ImportDialog");
+  setObjectName(QLatin1String("ImportDialog"));
   setModal(true);
   setWindowTitle(caption);
   setSizeGripEnabled(true);
@@ -114,8 +114,6 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
 #endif
 
   QVBoxLayout* vlayout = new QVBoxLayout(this);
-  vlayout->setSpacing(6);
-  vlayout->setMargin(6);
 
   m_trackDataTable = new QTableView(this);
   m_trackDataTable->setModel(m_trackDataModel);
@@ -123,8 +121,13 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
   m_trackDataTable->setItemDelegateForColumn(
         m_trackDataModel->columnForFrameType(Frame::FT_Genre),
         new FrameItemDelegate(this));
+#if QT_VERSION >= 0x050000
+  m_trackDataTable->verticalHeader()->setSectionsMovable(true);
+  m_trackDataTable->horizontalHeader()->setSectionsMovable(true);
+#else
   m_trackDataTable->verticalHeader()->setMovable(true);
   m_trackDataTable->horizontalHeader()->setMovable(true);
+#endif
   m_trackDataTable->horizontalHeader()->setContextMenuPolicy(
         Qt::CustomContextMenu);
   connect(m_trackDataTable->verticalHeader(), SIGNAL(sectionMoved(int, int, int)),
@@ -134,22 +137,31 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
       this, SLOT(showTableHeaderContextMenu(QPoint)));
   vlayout->addWidget(m_trackDataTable);
 
-  QWidget* butbox = new QWidget(this);
-  QHBoxLayout* butlayout = new QHBoxLayout(butbox);
-  butlayout->setMargin(0);
-  butlayout->setSpacing(6);
-  QPushButton* fileButton = new QPushButton(i18n("From F&ile/Clipboard..."),
-                                            butbox);
+  QHBoxLayout* accuracyLayout = new QHBoxLayout;
+  QLabel* accuracyLabel = new QLabel(i18n("Accuracy:"));
+  accuracyLayout->addWidget(accuracyLabel);
+  m_accuracyPercentLabel = new QLabel(QLatin1String("-"));
+  m_accuracyPercentLabel->setMinimumWidth(
+        m_accuracyPercentLabel->fontMetrics().width(QLatin1String("100%")));
+  accuracyLayout->addWidget(m_accuracyPercentLabel);
+  QLabel* coverArtLabel = new QLabel(i18n("Cover Art:"));
+  accuracyLayout->addWidget(coverArtLabel);
+  m_coverArtUrlLabel = new QLabel(QLatin1String(" -"));
+  accuracyLayout->addWidget(m_coverArtUrlLabel);
+  accuracyLayout->addStretch();
+  vlayout->addLayout(accuracyLayout);
+
+  QHBoxLayout* butlayout = new QHBoxLayout;
+  QPushButton* fileButton = new QPushButton(i18n("From F&ile/Clipboard..."));
   fileButton->setAutoDefault(false);
   butlayout->addWidget(fileButton);
-  QPushButton* tagsButton = new QPushButton(i18n("From T&ags..."),
-                                            butbox);
+  QPushButton* tagsButton = new QPushButton(i18n("From T&ags..."));
   tagsButton->setAutoDefault(false);
   butlayout->addWidget(tagsButton);
-  QPushButton* serverButton = new QPushButton(i18n("&From Server:"), butbox);
+  QPushButton* serverButton = new QPushButton(i18n("&From Server:"));
   serverButton->setAutoDefault(false);
   butlayout->addWidget(serverButton);
-  m_serverComboBox = new QComboBox(butbox);
+  m_serverComboBox = new QComboBox;
   m_serverComboBox->setEditable(false);
   foreach (const ServerImporter* si, m_importers) {
     m_serverComboBox->addItem(QCM_translate(si->name()));
@@ -161,20 +173,20 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
   QSpacerItem* butspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                          QSizePolicy::Minimum);
   butlayout->addItem(butspacer);
-  QLabel* destLabel = new QLabel(butbox);
+  QLabel* destLabel = new QLabel;
   destLabel->setText(i18n("D&estination:"));
   butlayout->addWidget(destLabel);
-  m_destComboBox = new QComboBox(butbox);
+  m_destComboBox = new QComboBox;
   m_destComboBox->setEditable(false);
   m_destComboBox->addItem(i18n("Tag 1"), TrackData::TagV1);
   m_destComboBox->addItem(i18n("Tag 2"), TrackData::TagV2);
   m_destComboBox->addItem(i18n("Tag 1 and Tag 2"), TrackData::TagV2V1);
   destLabel->setBuddy(m_destComboBox);
   butlayout->addWidget(m_destComboBox);
-  QToolButton* revertButton = new QToolButton(butbox);
+  QToolButton* revertButton = new QToolButton;
   revertButton->setIcon(
 #ifdef CONFIG_USE_KDE
-        KIcon("document-revert")
+        KIcon(QLatin1String("document-revert"))
 #else
         QCM_QIcon_fromTheme("document-revert")
 #endif
@@ -183,33 +195,30 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
   connect(revertButton, SIGNAL(clicked()),
           this, SLOT(changeTagDestination()));
   butlayout->addWidget(revertButton);
-  vlayout->addWidget(butbox);
+  vlayout->addLayout(butlayout);
 
-  QWidget* matchBox = new QWidget(this);
-  QHBoxLayout* matchLayout = new QHBoxLayout(matchBox);
-  matchLayout->setMargin(0);
-  matchLayout->setSpacing(6);
+  QHBoxLayout* matchLayout = new QHBoxLayout;
   m_mismatchCheckBox = new QCheckBox(
-    i18n("Check maximum allowable time &difference (sec):"), matchBox);
+    i18n("Check maximum allowable time &difference (sec):"));
   matchLayout->addWidget(m_mismatchCheckBox);
-  m_maxDiffSpinBox = new QSpinBox(matchBox);
+  m_maxDiffSpinBox = new QSpinBox;
   m_maxDiffSpinBox->setMaximum(9999);
   matchLayout->addWidget(m_maxDiffSpinBox);
   QSpacerItem* matchSpacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                              QSizePolicy::Minimum);
   matchLayout->addItem(matchSpacer);
-  QLabel* matchLabel = new QLabel(i18n("Match with:"), matchBox);
+  QLabel* matchLabel = new QLabel(i18n("Match with:"));
   matchLayout->addWidget(matchLabel);
-  QPushButton* lengthButton = new QPushButton(i18n("&Length"), matchBox);
+  QPushButton* lengthButton = new QPushButton(i18n("&Length"));
   lengthButton->setAutoDefault(false);
   matchLayout->addWidget(lengthButton);
-  QPushButton* trackButton = new QPushButton(i18n("T&rack"), matchBox);
+  QPushButton* trackButton = new QPushButton(i18n("T&rack"));
   trackButton->setAutoDefault(false);
   matchLayout->addWidget(trackButton);
-  QPushButton* titleButton = new QPushButton(i18n("&Title"), matchBox);
+  QPushButton* titleButton = new QPushButton(i18n("&Title"));
   titleButton->setAutoDefault(false);
   matchLayout->addWidget(titleButton);
-  vlayout->addWidget(matchBox);
+  vlayout->addLayout(matchLayout);
 
   connect(fileButton, SIGNAL(clicked()), this, SLOT(fromText()));
   connect(tagsButton, SIGNAL(clicked()), this, SLOT(fromTags()));
@@ -420,10 +429,8 @@ void ImportDialog::clear()
     }
   }
 
-  if (ConfigStore::s_genCfg.m_importWindowWidth > 0 &&
-      ConfigStore::s_genCfg.m_importWindowHeight > 0) {
-    resize(ConfigStore::s_genCfg.m_importWindowWidth,
-           ConfigStore::s_genCfg.m_importWindowHeight);
+  if (!ConfigStore::s_genCfg.m_importWindowGeometry.isEmpty()) {
+    restoreGeometry(ConfigStore::s_genCfg.m_importWindowGeometry);
   }
 
   showPreview();
@@ -442,6 +449,12 @@ void ImportDialog::showPreview()
   m_trackDataTable->scrollToTop();
   m_trackDataTable->resizeColumnsToContents();
   m_trackDataTable->resizeRowsToContents();
+
+  int accuracy = m_trackDataModel->calculateAccuracy();
+  m_accuracyPercentLabel->setText(accuracy >= 0 && accuracy <= 100
+                                  ? QString::number(accuracy) + QLatin1Char('%') : QLatin1String("-"));
+  QString coverArtUrl = m_trackDataModel->getTrackData().getCoverArtUrl();
+  m_coverArtUrlLabel->setText(coverArtUrl.isEmpty() ? QLatin1String("-") : coverArtUrl);
 }
 
 /**
@@ -460,7 +473,7 @@ TrackData::TagVersion ImportDialog::getDestination() const
  */
 void ImportDialog::showHelp()
 {
-  ContextHelp::displayHelp("import");
+  ContextHelp::displayHelp(QLatin1String("import"));
 }
 
 /**
@@ -476,8 +489,7 @@ void ImportDialog::saveConfig()
                          ConfigStore::s_genCfg.m_maxTimeDifference);
   ConfigStore::s_genCfg.m_importVisibleColumns = m_columnVisibility;
 
-  ConfigStore::s_genCfg.m_importWindowWidth = size().width();
-  ConfigStore::s_genCfg.m_importWindowHeight = size().height();
+  ConfigStore::s_genCfg.m_importWindowGeometry = saveGeometry();
 }
 
 /**
