@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 21 Mar 2004
  *
- * Copyright (C) 2004-2012  Urs Fleisch
+ * Copyright (C) 2004-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -55,7 +55,7 @@
 RenDirDialog::RenDirDialog(QWidget* parent, DirRenamer* dirRenamer) :
   QWizard(parent), m_taggedFile(0), m_dirRenamer(dirRenamer)
 {
-  setObjectName("RenDirDialog");
+  setObjectName(QLatin1String("RenDirDialog"));
   setModal(true);
   setWindowTitle(i18n("Rename Directory"));
   setSizeGripEnabled(true);
@@ -97,9 +97,6 @@ void RenDirDialog::setupMainPage(QWidget* page, QVBoxLayout* vlayout)
     return;
   }
 
-  vlayout->setSpacing(6);
-  vlayout->setMargin(6);
-
   QHBoxLayout* actionLayout = new QHBoxLayout;
   m_actionComboBox = new QComboBox(page);
   m_tagversionComboBox = new QComboBox(page);
@@ -119,7 +116,7 @@ void RenDirDialog::setupMainPage(QWidget* page, QVBoxLayout* vlayout)
   m_formatComboBox = new QComboBox(page);
   QStringList strList;
   for (const char** sl = MiscConfig::s_defaultDirFmtList; *sl != 0; ++sl) {
-    strList += *sl;
+    strList += QString::fromLatin1(*sl);
   }
   m_formatComboBox->addItems(strList);
   m_formatComboBox->setEditable(true);
@@ -238,7 +235,7 @@ void RenDirDialog::saveConfig()
  */
 void RenDirDialog::showHelp()
 {
-  ContextHelp::displayHelp("rename-directory");
+  ContextHelp::displayHelp(QLatin1String("rename-directory"));
 }
 
 /**
@@ -260,37 +257,31 @@ void RenDirDialog::clearPreview()
 {
   if (m_edit) {
     m_edit->clear();
+    m_edit->setLineWrapMode(QTextEdit::NoWrap);
   }
 }
 
 /**
  * Display action preview.
+ *
+ * @param actionStrs description of action
  */
-void RenDirDialog::displayPreview()
+void RenDirDialog::displayActionPreview(const QStringList& actionStrs)
 {
-  m_edit->clear();
-  m_edit->setLineWrapMode(QTextEdit::NoWrap);
-  QFontMetrics metrics = fontMetrics();
-  int typeWidth = -1;
-  foreach (const QStringList& actionStrs, m_dirRenamer->describeActions()) {
-    QString str = actionStrs.at(0);
-    int width = metrics.width(str);
-    if (typeWidth < width) {
-      typeWidth = width;
-    }
-    if (actionStrs.size() > 1) {
-      str += '\t';
-      str += actionStrs.at(1);
-    }
-    if (actionStrs.size() > 2) {
-      str += "\n\t";
-      str += actionStrs.at(2);
-    }
-    m_edit->append(str);
+  QString str = actionStrs.at(0);
+  int width = fontMetrics().width(str) + 8;
+  if (m_edit->tabStopWidth() < width) {
+    m_edit->setTabStopWidth(width);
   }
-  if (typeWidth > 0) {
-    m_edit->setTabStopWidth(typeWidth + 8);
+  if (actionStrs.size() > 1) {
+    str += QLatin1Char('\t');
+    str += actionStrs.at(1);
   }
+  if (actionStrs.size() > 2) {
+    str += QLatin1String("\n\t");
+    str += actionStrs.at(2);
+  }
+  m_edit->append(str);
 }
 
 /**
@@ -299,12 +290,9 @@ void RenDirDialog::displayPreview()
 void RenDirDialog::pageChanged()
 {
   if (currentId() == 1) {
-    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     clearPreview();
     setDirRenamerConfiguration();
     emit actionSchedulingRequested();
-    displayPreview();
-    QApplication::restoreOverrideCursor();
   }
 }
 
@@ -313,6 +301,6 @@ void RenDirDialog::pageChanged()
  */
 void RenDirDialog::reject()
 {
-  m_dirRenamer->setAbortFlag();
+  m_dirRenamer->abort();
   QWizard::reject();
 }
