@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2006
  *
- * Copyright (C) 2006-2011  Urs Fleisch
+ * Copyright (C) 2006-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -48,14 +48,12 @@
  * @param parent  parent widget
  */
 ServerImportDialog::ServerImportDialog(QWidget* parent) : QDialog(parent),
-    m_serverComboBox(0), m_cgiLineEdit(0), m_additionalTagsCheckBox(0),
-    m_coverArtCheckBox(0), m_source(0)
+    m_serverComboBox(0), m_cgiLineEdit(0), m_standardTagsCheckBox(0),
+    m_additionalTagsCheckBox(0), m_coverArtCheckBox(0), m_source(0)
 {
-  setObjectName("ServerImportDialog");
+  setObjectName(QLatin1String("ServerImportDialog"));
 
   QVBoxLayout* vlayout = new QVBoxLayout(this);
-  vlayout->setSpacing(6);
-  vlayout->setMargin(6);
 
   QHBoxLayout* findLayout = new QHBoxLayout;
   m_artistLineEdit = new QComboBox(this);
@@ -91,8 +89,10 @@ ServerImportDialog::ServerImportDialog(QWidget* parent) : QDialog(parent),
   vlayout->addLayout(serverLayout);
 
   QHBoxLayout* hlayout = new QHBoxLayout;
+  m_standardTagsCheckBox = new QCheckBox(i18n("&Standard Tags"), this);
   m_additionalTagsCheckBox = new QCheckBox(i18n("&Additional Tags"), this);
   m_coverArtCheckBox = new QCheckBox(i18n("C&over Art"), this);
+  hlayout->addWidget(m_standardTagsCheckBox);
   hlayout->addWidget(m_additionalTagsCheckBox);
   hlayout->addWidget(m_coverArtCheckBox);
   vlayout->addLayout(hlayout);
@@ -169,7 +169,7 @@ void ServerImportDialog::setImportSource(ServerImporter* source)
       if (m_source->serverList()) {
         QStringList strList;
         for (const char** sl = m_source->serverList(); *sl != 0; ++sl) {
-          strList += *sl;
+          strList += QString::fromLatin1(*sl);
         }
         m_serverComboBox->clear();
         m_serverComboBox->addItems(strList);
@@ -181,9 +181,11 @@ void ServerImportDialog::setImportSource(ServerImporter* source)
       m_cgiLineEdit->hide();
     }
     if (m_source->additionalTags()) {
+      m_standardTagsCheckBox->show();
       m_additionalTagsCheckBox->show();
       m_coverArtCheckBox->show();
     } else {
+      m_standardTagsCheckBox->hide();
       m_additionalTagsCheckBox->hide();
       m_coverArtCheckBox->hide();
     }
@@ -223,7 +225,7 @@ QString ServerImportDialog::getServer() const
   if (m_serverComboBox) {
     QString server(m_serverComboBox->currentText());
     if (server.isEmpty() && m_source) {
-      server = m_source->defaultServer();
+      server = QString::fromLatin1(m_source->defaultServer());
     }
     return server;
   } else {
@@ -259,7 +261,7 @@ QString ServerImportDialog::getCgiPath() const
   if (m_cgiLineEdit) {
     QString cgi(m_cgiLineEdit->text());
     if (cgi.isEmpty() && m_source) {
-      cgi = m_source->defaultCgiPath();
+      cgi = QString::fromLatin1(m_source->defaultCgiPath());
     }
     return cgi;
   } else {
@@ -279,6 +281,31 @@ void ServerImportDialog::setCgiPath(const QString& cgi)
   }
 }
 
+/**
+ * Get standard tags option.
+ *
+ * @return true if standard tags are enabled.
+ */
+bool ServerImportDialog::getStandardTags() const
+{
+  return m_standardTagsCheckBox ?
+    m_standardTagsCheckBox->checkState() == Qt::Checked
+    : false;
+}
+
+/**
+ * Set standard tags option.
+ *
+ * @param enable true if standard tags are enabled
+ */
+void ServerImportDialog::setStandardTags(bool enable)
+{
+  if (m_standardTagsCheckBox) {
+    m_standardTagsCheckBox->setCheckState(
+      enable ? Qt::Checked : Qt::Unchecked);
+  }
+}
+
 /**
  * Get additional tags option.
  *
@@ -338,10 +365,10 @@ void ServerImportDialog::getImportSourceConfig(ServerImporterConfig* cfg) const
 {
   cfg->m_server = getServer();
   cfg->m_cgiPath = getCgiPath();
+  cfg->m_standardTags = getStandardTags();
   cfg->m_additionalTags = getAdditionalTags();
   cfg->m_coverArt = getCoverArt();
-  cfg->m_windowWidth = size().width();
-  cfg->m_windowHeight = size().height();
+  cfg->m_windowGeometry = saveGeometry();
 }
 
 /**
@@ -366,10 +393,11 @@ void ServerImportDialog::setArtistAlbum(const QString& artist, const QString& al
     ServerImporterConfig* cf = m_source->config();
     setServer(cf->m_server);
     setCgiPath(cf->m_cgiPath);
+    setStandardTags(cf->m_standardTags);
     setAdditionalTags(cf->m_additionalTags);
     setCoverArt(cf->m_coverArt);
-    if (cf->m_windowWidth > 0 && cf->m_windowHeight > 0) {
-      resize(cf->m_windowWidth, cf->m_windowHeight);
+    if (!cf->m_windowGeometry.isEmpty()) {
+      restoreGeometry(cf->m_windowGeometry);
     }
   }
 
@@ -428,6 +456,7 @@ void ServerImportDialog::slotFindFinished(const QByteArray& searchStr)
 void ServerImportDialog::slotAlbumFinished(const QByteArray& albumStr)
 {
   if (m_source) {
+    m_source->setStandardTags(getStandardTags());
     m_source->setAdditionalTags(getAdditionalTags());
     m_source->setCoverArt(getCoverArt());
     m_source->parseAlbumResults(albumStr);
@@ -467,6 +496,6 @@ void ServerImportDialog::requestTrackList(const QModelIndex& index)
 void ServerImportDialog::showHelp()
 {
   if (m_source && m_source->helpAnchor()) {
-    ContextHelp::displayHelp(m_source->helpAnchor());
+    ContextHelp::displayHelp(QString::fromLatin1(m_source->helpAnchor()));
   }
 }
