@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 8 Apr 2003
  *
- * Copyright (C) 2003-2011  Urs Fleisch
+ * Copyright (C) 2003-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -113,7 +113,7 @@ public:
    * Constructor.
    */
   PictureDblClickHandler(Kid3Application* app, IFrameEditor* frameEditor) :
-    m_app(app), m_frameEditor(frameEditor) {}
+    QObject(app), m_app(app), m_frameEditor(frameEditor) {}
   virtual ~PictureDblClickHandler() {}
 
 protected:
@@ -161,9 +161,7 @@ bool PictureDblClickHandler::eventFilter(QObject* obj, QEvent* event)
 Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
  : QSplitter(parent), m_app(app)
 {
-  setObjectName("Kid3Form");
-  const int margin = 6;
-  const int spacing = 2;
+  setObjectName(QLatin1String("Kid3Form"));
 
   if (!s_collapsePixmap) {
     s_collapsePixmap = new QPixmap((const char**)collapse_xpm);
@@ -190,12 +188,14 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   scrollView->setWidget(m_rightHalfVBox);
   scrollView->setWidgetResizable(true);
   QVBoxLayout* rightHalfLayout = new QVBoxLayout(m_rightHalfVBox);
-  rightHalfLayout->setSpacing(2);
-  rightHalfLayout->setMargin(2);
+  rightHalfLayout->setSpacing(0);
 
   m_fileButton = new QToolButton(m_rightHalfVBox);
   m_fileButton->setIcon(*s_collapsePixmap);
   m_fileButton->setAutoRaise(true);
+#ifdef Q_OS_MAC
+  m_fileButton->setStyleSheet(QLatin1String("border: 0;"));
+#endif
   m_fileLabel = new QLabel(i18n("F&ile"), m_rightHalfVBox);
   QHBoxLayout* fileButtonLayout = new QHBoxLayout;
   fileButtonLayout->addWidget(m_fileButton);
@@ -206,8 +206,6 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   m_fileWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
   rightHalfLayout->addWidget(m_fileWidget);
   QGridLayout* fileLayout = new QGridLayout(m_fileWidget);
-  fileLayout->setMargin(margin);
-  fileLayout->setSpacing(spacing);
 
   m_nameLabel = new QLabel(i18n("Name:"), m_fileWidget);
   fileLayout->addWidget(m_nameLabel, 0, 0);
@@ -269,6 +267,9 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   m_tag1Button = new QToolButton(m_rightHalfVBox);
   m_tag1Button->setIcon(*s_collapsePixmap);
   m_tag1Button->setAutoRaise(true);
+#ifdef Q_OS_MAC
+  m_tag1Button->setStyleSheet(QLatin1String("border: 0;"));
+#endif
   m_tag1Label = new QLabel(i18n("Tag &1"), m_rightHalfVBox);
   QHBoxLayout* tag1ButtonLayout = new QHBoxLayout;
   tag1ButtonLayout->addWidget(m_tag1Button);
@@ -280,8 +281,6 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   rightHalfLayout->addWidget(m_tag1Widget, 100);
 
   QHBoxLayout* idV1HBoxLayout = new QHBoxLayout(m_tag1Widget);
-  idV1HBoxLayout->setMargin(margin);
-  idV1HBoxLayout->setSpacing(spacing);
   m_framesV1Table = new FrameTable(m_app->frameModelV1(), m_tag1Widget);
   m_framesV1Table->setSelectionModel(m_app->getFramesV1SelectionModel());
   idV1HBoxLayout->addWidget(m_framesV1Table, 100);
@@ -311,6 +310,9 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   m_tag2Button = new QToolButton(m_rightHalfVBox);
   m_tag2Button->setIcon(*s_collapsePixmap);
   m_tag2Button->setAutoRaise(true);
+#ifdef Q_OS_MAC
+  m_tag2Button->setStyleSheet(QLatin1String("border: 0;"));
+#endif
   m_tag2Label = new QLabel(i18n("Tag &2"), m_rightHalfVBox);
   QHBoxLayout* tag2ButtonLayout = new QHBoxLayout;
   tag2ButtonLayout->addWidget(m_tag2Button);
@@ -321,8 +323,6 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   rightHalfLayout->addWidget(m_tag2Widget, 100);
 
   QHBoxLayout* idV2HBoxLayout = new QHBoxLayout(m_tag2Widget);
-  idV2HBoxLayout->setMargin(margin);
-  idV2HBoxLayout->setSpacing(spacing);
   m_framesV2Table = new FrameTable(m_app->frameModelV2(), m_tag2Widget);
   m_framesV2Table->setSelectionModel(m_app->getFramesV2SelectionModel());
   idV2HBoxLayout->addWidget(m_framesV2Table);
@@ -346,7 +346,10 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
     new QPushButton(i18n("Remove"), m_tag2Widget);
   buttonsV2VBoxLayout->addWidget(removeV2PushButton);
 
-  buttonsV2VBoxLayout->insertSpacing(-1, 8);
+  QFrame* frameLine = new QFrame;
+  frameLine->setFrameShape(QFrame::HLine);
+  frameLine->setFrameShadow(QFrame::Sunken);
+  buttonsV2VBoxLayout->addWidget(frameLine);
 
   QPushButton* editFramesPushButton =
     new QPushButton(i18n("Edit"), m_tag2Widget);
@@ -432,7 +435,7 @@ Kid3Form::~Kid3Form()
  */
 void Kid3Form::dragEnterEvent(QDragEnterEvent* ev)
 {
-  if (ev->mimeData()->hasFormat("text/uri-list") ||
+  if (ev->mimeData()->hasFormat(QLatin1String("text/uri-list")) ||
       ev->mimeData()->hasImage())
     ev->acceptProposedAction();
 }
@@ -457,7 +460,7 @@ void Kid3Form::dropEvent(QDropEvent* ev)
     m_app->openDrop(text);
   } else {
     text = urls.first().toString();
-    if (text.startsWith("http://")) {
+    if (text.startsWith(QLatin1String("http://"))) {
       m_app->dropUrl(text);
     }
   }
@@ -561,7 +564,7 @@ void Kid3Form::dirSelected(const QModelIndex& index)
   QString dirPath = index.data(QFileSystemModel::FilePathRole).toString();
   if (!dirPath.isEmpty()) {
     m_dirListBox->setEntryToSelect(
-        dirPath.endsWith("..") ? index.parent() : QModelIndex());
+        dirPath.endsWith(QLatin1String("..")) ? index.parent() : QModelIndex());
     mainWin()->updateCurrentSelection();
     mainWin()->confirmedOpenDirectory(dirPath);
   }
@@ -589,7 +592,7 @@ void Kid3Form::setTagFormatV1(const QString& str)
 {
   QString txt = i18n("Tag &1");
   if (!str.isEmpty()) {
-    txt += ": ";
+    txt += QLatin1String(": ");
     txt += str;
   }
   m_tag1Label->setText(txt);
@@ -604,7 +607,7 @@ void Kid3Form::setTagFormatV2(const QString& str)
 {
   QString txt = i18n("Tag &2");
   if (!str.isEmpty()) {
-    txt += ": ";
+    txt += QLatin1String(": ");
     txt += str;
   }
   m_tag2Label->setText(txt);
@@ -728,6 +731,22 @@ void Kid3Form::setFocusV2()
   m_framesV2Table->setFocus();
 }
 
+/**
+ * Set focus on file list.
+ */
+void Kid3Form::setFocusFileList()
+{
+  m_fileListBox->setFocus();
+}
+
+/**
+ * Set focus on directory list.
+ */
+void Kid3Form::setFocusDirList()
+{
+  m_dirListBox->setFocus();
+}
+
 /**
  * Get the items from a combo box.
  *
@@ -822,27 +841,27 @@ void Kid3Form::setDetailInfo(const TaggedFile::DetailInfo& info)
   QString str;
   if (info.valid) {
     str = info.format;
-    str += ' ';
+    str += QLatin1Char(' ');
     if (info.bitrate > 0 && info.bitrate < 999) {
-      if (info.vbr) str += "VBR ";
+      if (info.vbr) str += QLatin1String("VBR ");
       str += QString::number(info.bitrate);
-      str += " kbps ";
+      str += QLatin1String(" kbps ");
     }
     if (info.sampleRate > 0) {
       str += QString::number(info.sampleRate);
-      str += " Hz ";
+      str += QLatin1String(" Hz ");
     }
     switch (info.channelMode) {
       case TaggedFile::DetailInfo::CM_Stereo:
-        str += "Stereo ";
+        str += QLatin1String("Stereo ");
         break;
       case TaggedFile::DetailInfo::CM_JointStereo:
-        str += "Joint Stereo ";
+        str += QLatin1String("Joint Stereo ");
         break;
       default:
         if (info.channels > 0) {
           str += QString::number(info.channels);
-          str += " Channels ";
+          str += QLatin1String(" Channels ");
         }
     }
     if (info.duration > 0) {
@@ -850,7 +869,7 @@ void Kid3Form::setDetailInfo(const TaggedFile::DetailInfo& info)
     }
   }
   if (!str.isEmpty()) {
-    str = i18n("F&ile") + ": " + str;
+    str = i18n("F&ile") + QLatin1String(": ") + str;
   } else {
     str = i18n("F&ile");
   }
@@ -873,6 +892,30 @@ void Kid3Form::deselectAllFiles()
   m_fileListBox->clearSelection();
 }
 
+/**
+ * Select all files in the current directory.
+ */
+void Kid3Form::selectAllInDirectory()
+{
+  QModelIndex parent = m_fileListBox->currentIndex();
+  const QAbstractItemModel* model = parent.model();
+  if (parent.isValid() && model) {
+    if (!model->hasChildren(parent)) {
+      parent = parent.parent();
+    }
+    QItemSelection selection;
+    for (int row = 0; row < model->rowCount(parent); ++row) {
+      QModelIndex index = model->index(row, 0, parent);
+      if (!model->hasChildren(index)) {
+        selection.append(QItemSelectionRange(index));
+      }
+    }
+    if (QItemSelectionModel* selModel = m_fileListBox->selectionModel()) {
+      selModel->select(selection, QItemSelectionModel::Select);
+    }
+  }
+}
+
 /**
  * Set the root index of the directory and file lists.
  *
@@ -894,26 +937,30 @@ void Kid3Form::initActions()
 {
   QString ctx(i18n("Filename"));
   ShortcutsModel* sm = m_app->getConfigStore()->getShortcutsModel();
-  initAction(i18n("From Tag 1"), "filename_from_v1", this, SLOT(fnFromID3V1()), ctx, sm);
-  initAction(i18n("From Tag 2"), "filename_from_v2", this, SLOT(fnFromID3V2()), ctx, sm);
-  initAction(i18n("Focus"), "filename_focus", this, SLOT(setFocusFilename()), ctx, sm);
+  initAction(i18n("From Tag 1"), QLatin1String("filename_from_v1"), this, SLOT(fnFromID3V1()), ctx, sm);
+  initAction(i18n("From Tag 2"), QLatin1String("filename_from_v2"), this, SLOT(fnFromID3V2()), ctx, sm);
+  initAction(i18n("Focus"), QLatin1String("filename_focus"), this, SLOT(setFocusFilename()), ctx, sm);
   ctx = i18n("Tag 1");
-  initAction(i18n("From Filename"), "v1_from_filename", m_app, SLOT(getTagsFromFilenameV1()), ctx, sm);
-  initAction(i18n("From Tag 2"), "v1_from_v2", m_app, SLOT(copyV2ToV1()), ctx, sm);
-  initAction(i18n("Copy"), "v1_copy", m_app, SLOT(copyTagsV1()), ctx, sm);
-  initAction(i18n("Paste"), "v1_paste", m_app, SLOT(pasteTagsV1()), ctx, sm);
-  initAction(i18n("Remove"), "v1_remove", m_app, SLOT(removeTagsV1()), ctx, sm);
-  initAction(i18n("Focus"), "v1_focus", this, SLOT(setFocusV1()), ctx, sm);
+  initAction(i18n("From Filename"), QLatin1String("v1_from_filename"), m_app, SLOT(getTagsFromFilenameV1()), ctx, sm);
+  initAction(i18n("From Tag 2"), QLatin1String("v1_from_v2"), m_app, SLOT(copyV2ToV1()), ctx, sm);
+  initAction(i18n("Copy"), QLatin1String("v1_copy"), m_app, SLOT(copyTagsV1()), ctx, sm);
+  initAction(i18n("Paste"), QLatin1String("v1_paste"), m_app, SLOT(pasteTagsV1()), ctx, sm);
+  initAction(i18n("Remove"), QLatin1String("v1_remove"), m_app, SLOT(removeTagsV1()), ctx, sm);
+  initAction(i18n("Focus"), QLatin1String("v1_focus"), this, SLOT(setFocusV1()), ctx, sm);
   ctx = i18n("Tag 2");
-  initAction(i18n("From Filename"), "v2_from_filename", m_app, SLOT(getTagsFromFilenameV2()), ctx, sm);
-  initAction(i18n("From Tag 1"), "v2_from_v1", m_app, SLOT(copyV1ToV2()), ctx, sm);
-  initAction(i18n("Copy"), "v2_copy", m_app, SLOT(copyTagsV2()), ctx, sm);
-  initAction(i18n("Paste"), "v2_paste", m_app, SLOT(pasteTagsV2()), ctx, sm);
-  initAction(i18n("Remove"), "v2_remove", m_app, SLOT(removeTagsV2()), ctx, sm);
-  initAction(i18n("Edit"), "frames_edit", this, SLOT(editFrame()), ctx, sm);
-  initAction(i18n("Add"), "frames_add", this, SLOT(addFrame()), ctx, sm);
-  initAction(i18n("Delete"), "frames_delete", this, SLOT(deleteFrame()), ctx, sm);
-  initAction(i18n("Focus"), "v2_focus", this, SLOT(setFocusV2()), ctx, sm);
+  initAction(i18n("From Filename"), QLatin1String("v2_from_filename"), m_app, SLOT(getTagsFromFilenameV2()), ctx, sm);
+  initAction(i18n("From Tag 1"), QLatin1String("v2_from_v1"), m_app, SLOT(copyV1ToV2()), ctx, sm);
+  initAction(i18n("Copy"), QLatin1String("v2_copy"), m_app, SLOT(copyTagsV2()), ctx, sm);
+  initAction(i18n("Paste"), QLatin1String("v2_paste"), m_app, SLOT(pasteTagsV2()), ctx, sm);
+  initAction(i18n("Remove"), QLatin1String("v2_remove"), m_app, SLOT(removeTagsV2()), ctx, sm);
+  initAction(i18n("Edit"), QLatin1String("frames_edit"), this, SLOT(editFrame()), ctx, sm);
+  initAction(i18n("Add"), QLatin1String("frames_add"), this, SLOT(addFrame()), ctx, sm);
+  initAction(i18n("Delete"), QLatin1String("frames_delete"), this, SLOT(deleteFrame()), ctx, sm);
+  initAction(i18n("Focus"), QLatin1String("v2_focus"), this, SLOT(setFocusV2()), ctx, sm);
+  ctx = i18n("File List");
+  initAction(i18n("Focus"), QLatin1String("filelist_focus"), this, SLOT(setFocusFileList()), ctx, sm);
+  ctx = i18n("Directory List");
+  initAction(i18n("Focus"), QLatin1String("dirlist_focus"), this, SLOT(setFocusDirList()), ctx, sm);
 }
 
 void Kid3Form::initAction(const QString& text, const QString& name,
