@@ -257,6 +257,16 @@ public slots:
    */
   void setFocusV2();
 
+  /**
+   * Set focus on file list.
+   */
+  void setFocusFileList();
+
+  /**
+   * Set focus on directory list.
+   */
+  void setFocusDirList();
+
   /**
    * Select all files.
    */
@@ -267,6 +277,11 @@ public slots:
    */
   void deselectAllFiles();
 
+  /**
+   * Select all files in the current directory.
+   */
+  void selectAllInDirectory();
+
   /**
    * Set the root index of the directory and file lists.
    *
