@@ -43,6 +43,7 @@ class RecentFilesMenu;
 /** Base class for main window. */
 typedef QMainWindow Kid3MainWindowBaseClass;
 #endif
+#include <QDateTime>
 #include "iframeeditor.h"
 #include "trackdata.h"
 #include "kid3api.h"
@@ -53,6 +54,7 @@ class Kid3Form;
 class Kid3Application;
 class TaggedFile;
 class ImportDialog;
+class BatchImportDialog;
 class ExportDialog;
 class BrowseCoverArtDialog;
 class RenDirDialog;
@@ -61,10 +63,11 @@ class RenDirDialog;
 class FilterDialog;
 class FileFilter;
 class QImage;
+class QProgressDialog;
 class DownloadDialog;
 class PlaylistDialog;
 class PlaylistConfig;
-#ifdef HAVE_PHONON
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 class PlayToolBar;
 #endif
 class ConfigStore;
@@ -277,6 +280,11 @@ public slots:
    */
   void slotImport();
 
+  /**
+   * Batch import.
+   */
+  void slotBatchImport();
+
   /**
    * Browse album cover artwork.
    */
@@ -317,7 +325,7 @@ public slots:
    */
   void slotFilter();
 
-#ifdef HAVE_PHONON
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Play audio file.
    */
@@ -346,6 +354,11 @@ public slots:
    */
   void deleteFile();
 
+  /**
+   * Expand the file list.
+   */
+  void expandFileList();
+
 private slots:
   /**
    * Update ID3v2 tags in GUI controls from file displayed in frame list.
@@ -359,13 +372,20 @@ private slots:
    */
   void updateModificationState();
 
-#ifdef HAVE_PHONON
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /**
    * Show play tool bar.
    */
   void showPlayToolBar();
 #endif
 
+  /**
+   * Expand item if it is a directory.
+   *
+   * @param index index of file in file proxy model
+   */
+  void expandNextDirectory(const QPersistentModelIndex& index);
+
 private:
   /**
    * Save all changed files.
@@ -377,9 +397,12 @@ private:
   /**
    * If anything was modified, save after asking user.
    *
-   * @return FALSE if user canceled.
+   * @param doNotRevert if true, modifications are not reverted, this can be
+   * used to skip the possibly long process if the application is not be closed
+   *
+   * @return false if user canceled.
    */
-  bool saveModified();
+  bool saveModified(bool doNotRevert = false);
 
   /**
    * Set window title with information from directory, filter and modification
@@ -412,6 +435,8 @@ private:
   Kid3Application* m_app;
   /** Import dialog */
   ImportDialog* m_importDialog;
+  /** Batch import dialog */
+  BatchImportDialog* m_batchImportDialog;
   /** Browse cover art dialog */
   BrowseCoverArtDialog* m_browseCoverArtDialog;
   /** Export dialog */
@@ -426,10 +451,13 @@ private:
   DownloadDialog* m_downloadDialog;
   /** Playlist dialog */
   PlaylistDialog* m_playlistDialog;
-#ifdef HAVE_PHONON
+  /** Progress dialog */
+  QProgressDialog* m_progressDialog;
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /** Play toolbar */
   PlayToolBar* m_playToolBar;
 #endif
+  QDateTime m_expandFileListStartTime;
 
 #ifdef CONFIG_USE_KDE
   /** Actions */
