@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 05 Sep 2007
  *
- * Copyright (C) 2007-2011  Urs Fleisch
+ * Copyright (C) 2007-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -42,11 +42,18 @@
 FrameTable::FrameTable(FrameTableModel* model, QWidget* parent) :
   QTableView(parent), m_currentEditor(0)
 {
-  setObjectName("FrameTable");
+  setObjectName(QLatin1String("FrameTable"));
   setModel(model);
   setSelectionMode(SingleSelection);
+#if QT_VERSION >= 0x050000
+  horizontalHeader()->setSectionResizeMode(FrameTableModel::CI_Value, QHeaderView::Stretch);
+#else
   horizontalHeader()->setResizeMode(FrameTableModel::CI_Value, QHeaderView::Stretch);
-  horizontalHeader()->hide();
+#endif
+  // Set a small height instead of hiding the header, so that the column
+  // widths can still be resized by the user.
+  horizontalHeader()->setFixedHeight(2);
+  horizontalHeader()->setStyleSheet(QLatin1String("color: rgba(0, 0, 0, 0);"));
   verticalHeader()->hide();
   if (model->isId3v1()) {
     bool insertTemporaryRow = model->rowCount() < 1;
@@ -57,14 +64,18 @@ FrameTable::FrameTable(FrameTableModel* model, QWidget* parent) :
       model->removeRow(0);
   }
   // Set width of first column
-  int width = fontMetrics().width(i18n("Track Number") + "WW");
+  int width = fontMetrics().width(i18n("WWW Audio Source") + QLatin1String("WW"));
   QStyleOptionButton option;
   option.initFrom(this);
   width += style()->subElementRect(
     QStyle::SE_ViewItemCheckIndicator, &option, this).width();
   setColumnWidth(FrameTableModel::CI_Enable, width);
 
+#if QT_VERSION >= 0x050000
+  horizontalHeader()->setSectionResizeMode(FrameTableModel::CI_Value, QHeaderView::Stretch);
+#else
   horizontalHeader()->setResizeMode(FrameTableModel::CI_Value, QHeaderView::Stretch);
+#endif
   setItemDelegate(new FrameItemDelegate(this));
   setEditTriggers(AllEditTriggers);
   viewport()->installEventFilter(this); // keep track of editors
@@ -113,7 +124,7 @@ bool FrameTable::eventFilter(QObject*, QEvent* event)
 
 /**
  * Commit data from the current editor.
- * This is used to avoid loosing the changes in open editors e.g. when
+ * This is used to avoid losing the changes in open editors e.g. when
  * the file is changed using Alt-Up or Alt-Down.
  *
  * @return true if data was committed.
