@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 04 Jan 2009
  *
- * Copyright (C) 2009-2012  Urs Fleisch
+ * Copyright (C) 2009-2013  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -37,7 +37,7 @@
  */
 PictureLabel::PictureLabel(QWidget* parent) : QLabel(parent), m_pixmapHash(0)
 {
-  setObjectName("PictureLabel");
+  setObjectName(QLatin1String("PictureLabel"));
   setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
   setWordWrap(true);
   clearPicture();
@@ -65,7 +65,6 @@ int PictureLabel::heightForWidth(int w) const
 void PictureLabel::clearPicture()
 {
   const char* const msg = I18N_NOOP("Drag album\nartwork\nhere");
-  setMargin(6);
   setText(QCM_translate(msg));
 }
 
@@ -87,7 +86,7 @@ void PictureLabel::setData(const QByteArray* data)
       QPixmap scaledPm = pm.scaled(width(), height(), Qt::KeepAspectRatio);
       if (!scaledPm.isNull()) {
         m_pixmapHash = hash;
-        setMargin(0);
+        setContentsMargins(0, 0, 0, 0);
         setPixmap(scaledPm);
         return;
       }
